# encoding: utf-8

# File:	clients/edirectory.ycp
# Package:	Configuration of edirectory
# Summary:	Module file
#
# $Id: edirectory.ycp,v 1.1.2.19 2005/06/28 20:51:39 rhaslam Exp $
#
# Main file for edirectory configuration. Uses all other files.
module Yast
  class EdirectoryClient < Client
    def main
      Yast.import "UI"

      textdomain "novell-edirectory"

      # The main ()
      Yast.import "Package"
      Yast.import "Progress"
      Yast.import "Report"
      Yast.import "Summary"
      Yast.import "Mode"
      Yast.import "Stage"
      Yast.import "ProductControl"
      Yast.import "CommandLine"
      Yast.import "NovellAddonInstall"
      Yast.include self, "novell-edirectory/complex.rb"
      Yast.include self, "novell-edirectory/wizards.rb"

      @cmdline_description = {
        "id"         => "edirectory",
        "help"       => _("Configuration of eDirectory"),
        "guihandler" => fun_ref(method(:EdirectoryCompleteSequence), "any ()"),
        "initialize" => fun_ref(Edirectory.method(:Read), "symbol ()"),
        "finish"     => fun_ref(Edirectory.method(:Write), "symbol ()"),
        "actions"    => {},
        "options"    => {},
        "mappings"   => {}
      }

      Builtins.y2milestone("----------------------------------------")
      Builtins.y2milestone("eDirectory (edirectory) module started")

      # is this proposal or not?
      @propose = false
      @upgrade = false
      @args = WFM.Args
      if Ops.greater_than(Builtins.size(@args), 0)
        if Ops.is_path?(WFM.Args(0)) && WFM.Args(0) == path(".propose")
          Builtins.y2milestone("Using PROPOSE mode")
          @propose = true
        elsif Ops.is_path?(WFM.Args(0)) && WFM.Args(0) == path(".upgrade")
          Builtins.y2milestone("Using UPGRADE mode")
          @upgrade = true
        end
      end

      @eDirSoftwareInstalled = Edirectory.SoftwareInstalled
      Builtins.y2milestone(
        "eDirectory software installed = %1",
        @eDirSoftwareInstalled
      )
      @ret = nil

      if @propose
        if Ops.get(NovellAddonInstall.products_to_configure, "edirectory", true)
          @ret = EdirectoryAutoSequence()
        else
          @ret = :next
        end
        Builtins.y2milestone("eDirectory:ran EdirectoryAutoSequence()")
      elsif @upgrade
        if Ops.get(NovellAddonInstall.products_to_configure, "edirectory", true)
          @ret = EdirectoryAutoUpgradeSequence()
        else
          @ret = :next
        end
        Builtins.y2milestone("eDirectory:ran EdirectoryAutoUpgradeSequence()")
      elsif Stage.cont
        if @eDirSoftwareInstalled
          # DIB does not exist do Edirectory
          @ret = EdirectoryCompleteSequence()
          Builtins.y2milestone("eDirectory:ran EdirectoryCompleteSequence()")
        end
      else
        @ret = CommandLine.Run(@cmdline_description)
        Builtins.y2milestone(
          "eDirectory:ran CommandLine::Run: %1",
          @cmdline_description
        )
      end

      Builtins.y2milestone("eDirectory:ret=%1", @ret)

      # Finish
      Builtins.y2milestone("eDirectory module (edirectory) finished")
      Builtins.y2milestone("----------------------------------------")

      deep_copy(@ret) 
      # EOF
    end
  end
end

Yast::EdirectoryClient.new.main
