# encoding: utf-8

# -------------------------------------------------------------------------------
# (C) Copyright 2019 - 2022 Micro Focus or one of its affiliates.
#
# The only warranties for products and services of Micro Focus and its affiliates
# and licensors (“Micro Focus”) are as may be set forth in the express warranty
# statements accompanying such products and services. Nothing herein should be
# construed as constituting an additional warranty. Micro Focus shall not be
# liable for technical or editorial errors or omissions contained herein. The
# information contained herein is subject to change without notice.
#
# Except as specifically indicated otherwise, this document contains confidential
# information and a valid license is required for possession, use or copying. If
# this work is provided to the U.S. Government, consistent with FAR 12.211 and
# 12.212, Commercial Computer Software, Computer Software Documentation, and
# Technical Data for Commercial Items  are licensed to the U.S. Government under
# vendor's standard commercial license.
# -------------------------------------------------------------------------------

# File:	clients/edirectory_proposal.ycp
# Package:	Configuration of edirectory
# Summary:	Proposal function dispatcher.
# Authors:	Anas Nashif <nashif@suse.de>
#
# $Id: edirectory_proposal.ycp,v 1.1.2.7 2005/07/27 20:19:49 rhaslam Exp $
#
# Proposal function dispatcher for edirectory configuration.
# See source/installation/proposal/proposal-API.txt
module Yast
  class EdirectoryProposalClient < Client
    def main

      textdomain "novell-edirectory"

      Yast.import "Edirectory"
      Yast.import "Progress"
      Yast.import "NovellLDAP"
      Yast.import "NovellUtils"
      Yast.import "NovellPatterns"
      Yast.import "NovellAddonInstall"

      # The main ()
      Builtins.y2milestone("----------------------------------------")
      Builtins.y2milestone("eDirectory proposal started")

      @func = Convert.to_string(WFM.Args(0))
      @param = Convert.to_map(WFM.Args(1))
      @ret = {}

      Builtins.y2milestone("eDirectory proposal function: %1", @func)

      # create a textual proposal
      if @func == "MakeProposal"
        @proposal = ""
        @warning = ""
        @warning_level = nil
        @force_reset = Ops.get_boolean(@param, "force_reset", false)

        Builtins.y2milestone(
          "eDirectory:MakeProposal:force_reset: %1, proposal_valid: %2",
          @force_reset,
          Edirectory.proposal_valid
        )
        if @force_reset || !Edirectory.proposal_valid
          Edirectory.proposal_valid = true

          NovellUtils.ResetEdirAskUserFlag # We are generating a new proposal, so we start fresh.

          @progress_orig = Progress.set(false)
          Edirectory.Read
          # generate the proposed values

          @tree_type = Edirectory.ProposeTreeType
          @server_list = Ops.get_list(
            NovellLDAP.Settings,
            "CONFIG_LDAP_SERVERS_LIST",
            []
          )
          @replica_server = ""
          @admin_name = Ops.get_string(
            NovellLDAP.Settings,
            "CONFIG_LDAP_ADMIN_CONTEXT",
            ""
          )

          if !NovellLDAP.LocalAddressExists(@server_list)
            @local_server = {
              "CONFIG_LDAP_SERVER_IP"   => Ops.get(
                Convert.convert(
                  NovellUtils.GetAllStaticIPAddrs,
                  :from => "list",
                  :to   => "list <string>"
                ),
                0,
                ""
              ),
              "CONFIG_LDAP_PORT"        => 389,
              "CONFIG_LDAP_SECURE_PORT" => 636
            }
            @server_list = Builtins.add(@server_list, @local_server)
            @hostname = NovellUtils.GetHostnameFQDN
            if @hostname != "" || @hostname != nil
              @local_server = {
                "CONFIG_LDAP_SERVER_IP"   => NovellUtils.CleanUpString(@hostname),
                "CONFIG_LDAP_PORT"        => 389,
                "CONFIG_LDAP_SECURE_PORT" => 636
              }
              @server_list = Builtins.add(@server_list, @local_server)
            end
          end

          if !Mode.update && !Mode.autoupgrade
            if @tree_type == "existing"
              @remote_servers = NovellLDAP.GetRemoteServers(@server_list)
              @replica_server = Ops.get_string(
                Ops.get(@remote_servers, 0, {}),
                "CONFIG_LDAP_SERVER_IP",
                ""
              )
            end

            # save the proposed values
            Ops.set(
              Edirectory.EdirSettings,
              "CONFIG_EDIR_TREE_TYPE",
              @tree_type
            )
            Ops.set(
              Edirectory.EdirSettings,
              "CONFIG_EDIR_REPLICA_SERVER",
              @replica_server
            )
            Ops.set(
              Edirectory.EdirSettings,
              "CONFIG_EDIR_SERVER_CONTEXT",
              NovellUtils.GetContextNDS(@admin_name)
            )
            #           Edirectory::EdirSettings["CONFIG_EDIR_NTP_SERVERS"] = [];  // this must be chosen explicitly (#249973)
            Ops.set(
              Edirectory.EdirSettings,
              "CONFIG_EDIR_NTP_USE_LOCAL_CLOCK",
              "no"
            )
          end

          Ops.set(NovellLDAP.Settings, "CONFIG_LDAP_SERVERS_LIST", @server_list)

          if !Mode.update && !Mode.autoupgrade
            if Edirectory.xad_packages_installed &&
                Ops.get_string(
                  Edirectory.EdirSettings,
                  "XAD_SERVICE_CONFIGURED",
                  "no"
                ) == "yes"
              # Propose XAD configuration...
              @xad_settings = Edirectory.ProposeXadSettings
              Ops.set(
                Edirectory.EdirSettings,
                "XAD_SERVICE_CONFIGURED",
                Ops.get_string(@xad_settings, "XAD_SERVICE_CONFIGURED", "no")
              )
              Ops.set(
                Edirectory.EdirSettings,
                "XAD_DOMAIN_TYPE",
                Ops.get_string(@xad_settings, "XAD_DOMAIN_TYPE", "forest")
              )
              Ops.set(
                Edirectory.EdirSettings,
                "XAD_DOMAIN_NAME",
                Ops.get_string(@xad_settings, "XAD_DOMAIN_NAME", "")
              )
              Ops.set(
                Edirectory.EdirSettings,
                "XAD_CONFIG_DNS",
                Ops.get_string(@xad_settings, "XAD_CONFIG_DNS", "no")
              )
              Ops.set(
                Edirectory.EdirSettings,
                "XAD_WINS_SERVER",
                Ops.get_string(@xad_settings, "XAD_WINS_SERVER", "")
              )
              Ops.set(
                Edirectory.EdirSettings,
                "XAD_SITE_NAME",
                Ops.get_string(@xad_settings, "XAD_SITE_NAME", "")
              )
              Ops.set(
                Edirectory.EdirSettings,
                "XAD_NETBIOS",
                Ops.get_string(@xad_settings, "XAD_NETBIOS", "")
              )
              Ops.set(
                Edirectory.EdirSettings,
                "XAD_FOREST_ROOT",
                Ops.get_string(@xad_settings, "XAD_FOREST_ROOT", "")
              )
              @server_context = Ops.get_string(
                @xad_settings,
                "CONFIG_EDIR_SERVER_CONTEXT",
                ""
              )
              @admin_context = Ops.get_string(
                @xad_settings,
                "CONFIG_LDAP_ADMIN_CONTEXT",
                ""
              )
              @xad_admin_context = Ops.get_string(
                @xad_settings,
                "XAD_LDAP_ADMIN_CONTEXT",
                ""
              )
              if @server_context != nil && @server_context != ""
                # server context changed...
                Ops.set(
                  Edirectory.EdirSettings,
                  "CONFIG_EDIR_SERVER_CONTEXT",
                  @server_context
                )
              end
              if @xad_admin_context != nil && @xad_admin_context != ""
                Ops.set(
                  Edirectory.EdirSettings,
                  "XAD_LDAP_ADMIN_CONTEXT",
                  @xad_admin_context
                )
              end
              if @admin_context != nil && @admin_context != ""
                Ops.set(
                  NovellLDAP.Settings,
                  "CONFIG_LDAP_ADMIN_CONTEXT",
                  @admin_context
                )
              end
            end
          end
          Progress.set(@progress_orig)
        end
        @sum = Edirectory.Summary
        @proposal = Ops.get_string(@sum, 0, "")
        @ret = NovellAddonInstall.ConstructProposal("edirectory", @proposal)
      # validate the current values
      elsif @func == "ValidateValues"
        @ret = { "errors" => false }
        if !Mode.update && !Mode.autoupgrade
          if Ops.get_string(
              NovellLDAP.Settings,
              "CONFIG_LDAP_ADMIN_CONTEXT",
              ""
            ) == "" ||
              Ops.get_string(
                NovellLDAP.Settings,
                "CONFIG_LDAP_ADMIN_PASSWORD",
                ""
              ) == "" ||
              Edirectory.ValidateXadSettings == false
            Ops.set(@ret, "errors", true)
          end # For upgrade, we need to validate a different set of values.
        else
          if Ops.get_string(
              Edirectory.EdirSettings,
              "XAD_SERVICE_CONFIGURED",
              ""
            ) != "yes"
            if Ops.get_string(
                NovellLDAP.Settings,
                "CONFIG_LDAP_ADMIN_CONTEXT",
                ""
              ) == "" ||
                Ops.get_string(
                  NovellLDAP.Settings,
                  "CONFIG_LDAP_ADMIN_PASSWORD",
                  ""
                ) == "" ||
                Ops.get_string(
                  Edirectory.EdirSettings,
                  "CONFIG_EDIR_OLD_NDSCONF_FILE",
                  ""
                ) == ""
              Ops.set(@ret, "errors", true)
            end
          else
            if Ops.get_string(
                NovellLDAP.Settings,
                "CONFIG_LDAP_ADMIN_CONTEXT",
                ""
              ) == "" &&
                Ops.get_string(
                  NovellLDAP.Settings,
                  "XAD_TREE_ADMIN_CONTEXT",
                  ""
                ) == "" ||
                Ops.get_string(
                  NovellLDAP.Settings,
                  "CONFIG_LDAP_ADMIN_PASSWORD",
                  ""
                ) == "" &&
                  Ops.get_string(
                    NovellLDAP.Settings,
                    "XAD_TREE_ADMIN_PASSWORD",
                    ""
                  ) == "" ||
                Ops.get_string(
                  Edirectory.EdirSettings,
                  "CONFIG_EDIR_OLD_NDSCONF_FILE",
                  ""
                ) == ""
              Ops.set(@ret, "errors", true)
            end
          end
        end
      # run the module
      elsif @func == "AskUser"
        Builtins.sleep(750)
        @chosen_id = Ops.get(@param, "chosen_id")
        Builtins.y2milestone("eDirectory proposal changing id %1", @chosen_id)

        # Configure now
        if @chosen_id == "edirectory--configure_now"
          Ops.set(NovellAddonInstall.products_to_configure, "edirectory", true)
          @ret = { "workflow_sequence" => :next }
        elsif @chosen_id == "edirectory--configure_later"
          Ops.set(NovellAddonInstall.products_to_configure, "edirectory", false)
          @ret = { "workflow_sequence" => :next }
        else
          if @chosen_id != nil # this means the user clicked on the "edirectory" link on the proposal screens in order to walk through the GUI again.
            NovellUtils.SetEdirAskUserFlag
          end # Edir values may change, so we need to make other products recompute default values.

          @stored = Edirectory.ExportSettings
          @seq = nil
          if Mode.update || Mode.autoupgrade
            @seq = Convert.to_symbol(
              WFM.CallFunction("edirectory", [path(".upgrade")])
            )
          else
            @seq = Convert.to_symbol(
              WFM.CallFunction("edirectory", [path(".propose")])
            )
          end
          Edirectory.Import(@stored) if @seq != :next
          Builtins.y2debug("stored=%1", @stored)
          Builtins.y2debug("seq=%1", @seq)
          @ret = { "workflow_sequence" => @seq }
        end
      # create titles
      elsif @func == "Description"
        # Determine if we should be in the proposal screen or not.
        @force_proposal = Ops.get_boolean(@param, "force_proposal", false)
        @isSelected = NovellPatterns.IsPatternInstalled("novell-edirectory") # FIXME: is this needed anymore?
        @isSelected = @isSelected &&
          NovellAddonInstall.IsProductSelected("edirectory")
        Builtins.y2milestone(
          "Proposal:IsSelected:novell-edirectory: %1",
          @isSelected
        )
        if @isSelected || @force_proposal
          @ret = {
            # Rich text title for Edirectory in proposals
            "rich_text_title" => _(
              "eDirectory"
            ),
            # Menu title for Edirectory in proposals
            "menu_title"      => _(
              "&eDirectory"
            ),
            "id"              => "edirectory"
          }
        else
          @ret = {}
        end
      # write the proposal
      elsif @func == "Write"
        @write_ret = Edirectory.Write
        while @write_ret == :again || @write_ret == :again_up
          # run the edirectory dialog workflow.
          @stored = Edirectory.ExportSettings
          @seq = nil
          if Mode.update || Mode.autoupgrade
            @seq = Convert.to_symbol(
              WFM.CallFunction("edirectory", [path(".upgrade")])
            )
          else
            @seq = Convert.to_symbol(
              WFM.CallFunction("edirectory", [path(".propose")])
            )
          end
          Edirectory.Import(@stored) if @seq != :next # restore the previous settings.
          @write_ret = Edirectory.Write # Try the eDirectory config again
        end
        Progress.Finish
      else
        Builtins.y2error("unknown function: %1", @func)
      end

      # Finish
      Builtins.y2debug("ret=%1", @ret)
      Builtins.y2milestone("Edirectory proposal finished")
      Builtins.y2milestone("----------------------------------------")
      deep_copy(@ret)

      # EOF
    end
  end
end

Yast::EdirectoryProposalClient.new.main
