# encoding: utf-8

# -------------------------------------------------------------------------------
# (C) Copyright 2019 - 2022 Micro Focus or one of its affiliates.
#
# The only warranties for products and services of Micro Focus and its affiliates
# and licensors (“Micro Focus”) are as may be set forth in the express warranty
# statements accompanying such products and services. Nothing herein should be
# construed as constituting an additional warranty. Micro Focus shall not be
# liable for technical or editorial errors or omissions contained herein. The
# information contained herein is subject to change without notice.
#
# Except as specifically indicated otherwise, this document contains confidential
# information and a valid license is required for possession, use or copying. If
# this work is provided to the U.S. Government, consistent with FAR 12.211 and
# 12.212, Commercial Computer Software, Computer Software Documentation, and
# Technical Data for Commercial Items  are licensed to the U.S. Government under
# vendor's standard commercial license.
# -------------------------------------------------------------------------------

# File:	clients/edirectory_upgrade.ycp
# Package:	Configuration of edirectory
# Summary:	upgrade function dispatcher.
# Authors:	Mark Clark <mclark@novell.com>
#
# $Id: edirectory_upgrade.ycp,v 1.1.2.10 2005/03/11 21:20:32 mclark Exp $
#
# upgrade function dispatcher for edirectory configuration.
module Yast
  class EdirectoryUpgradeClient < Client
    def main

      textdomain "novell-edirectory"

      Yast.import "NovellAddonInstall"

      # The main ()
      Builtins.y2milestone("----------------------------------------")
      Builtins.y2milestone("Edirectory upgrade check started")

      @func = Convert.to_string(WFM.Args(0))
      @param = Convert.to_map(WFM.Args(1))
      @ret = {}

      # return the status of this product
      if @func == "Info_oes2015_sp1"
        @cfg_file = "/etc/sysconfig/novell/edir_oes2015_sp1" # OES 2015 config file path
        @ret = NovellAddonInstall.ReadConfigFileSettings(@cfg_file)
      elsif @func == "Info_oes2018"
        @cfg_file = "/etc/sysconfig/novell/edir_oes2018" # OES 2018 config file path
        @ret = NovellAddonInstall.ReadConfigFileSettings(@cfg_file)
      elsif @func == "Info_oes2018_sp1"
        @cfg_file = "/etc/sysconfig/novell/edir_oes2018_sp1" # OES 2018 SP1 config file path
        @ret = NovellAddonInstall.ReadConfigFileSettings(@cfg_file)
      elsif @func == "Info_oes2018_sp2"
        @cfg_file = "/etc/sysconfig/novell/edir_oes2018_sp2" # OES 2018 SP2 config file path
        @ret = NovellAddonInstall.ReadConfigFileSettings(@cfg_file)
      elsif @func == "Info_oes2018_sp3"
        @cfg_file = "/etc/sysconfig/novell/edir_oes2018_sp3" # OES 2018 SP3 config file path
        @ret = NovellAddonInstall.ReadConfigFileSettings(@cfg_file)
      elsif @func == "Info_oes"
        @cfg_file = "/etc/sysconfig/novell/edir" # OES 2022 and onward config file path
        @ret = NovellAddonInstall.ReadConfigFileSettings(@cfg_file)
      elsif @func == "Translate"
        @cfg_file = "/etc/sysconfig/novell/edir" # OES 2022 and onward config file path
        @ret = NovellAddonInstall.ReadConfigFileSettings(@cfg_file)
      else
        Builtins.y2error("unknown function: %1", @func)
      end

      # Finish
      Builtins.y2debug("ret=%1", @ret)
      Builtins.y2milestone("Edirectory upgrade check finished")
      Builtins.y2milestone("----------------------------------------")
      deep_copy(@ret)

      # EOF
    end
  end
end

Yast::EdirectoryUpgradeClient.new.main
