# encoding: utf-8

# File:        clients/edirectory_preconfig.ycp
# Package:     novell-common
# Summary:     Prepare for the OES configuration summary
# Authors:     Michael G. Fritch <mgfritch@novell.com>
#
# $Id: edirectory_preconfig.ycp,v 1.1.2.18 2005/05/04 22:10:11 mclark Exp $
#
# eDirectory/LDAP configuration needed before reaching the OES configuration summary
#
module Yast
  class InstEdirectoryPreconfigClient < Client
    def main

      textdomain "novell-edirectory"

      Builtins.y2milestone("----------------------------------------")
      Builtins.y2milestone("edirectory_preconfig started")


      Yast.import "NovellAddonInstall"
      Yast.import "Edirectory"
      Yast.import "NovellUtils"
      Yast.import "FileUtils"

      @ret = :auto

      @args = Convert.to_map(WFM.Args(0)) # going backwards?
      return @ret if Ops.get_boolean(@args, "going_back", false) == true
      if FileUtils.Exists("/var/lib/YaST2/OES11_AUTOUPGRADE")
        Builtins.y2milestone("inst_edir_preconfig: autoyast upgrade mode")
        return @ret
      end

      NovellUtils.ResetEdirAskUserFlag # Get rid of any residual flag file on the system.

      @edir_info = NovellAddonInstall.GetProductInfo("edirectory")
      @use_edirectory_workflow = NovellAddonInstall.IsProductSelected(
        "edirectory"
      ) &&
        Ops.get_boolean(@edir_info, "SERVICE_CONFIGURED", false) == false # Should the eDirectory or OesLdap workflow dialogs be displayed?

      # Decide which proposal to use....
      @proposal_module = "oes-ldap_proposal"
      @proposal_module = "edirectory_proposal" if @use_edirectory_workflow

      # Read in the appropriate settings by calling MakeProposal
      @proposal_info = Convert.to_map(
        WFM.CallFunction(
          @proposal_module,
          [
            "MakeProposal",
            { "force_reset" => false, "language_changed" => false }
          ]
        )
      )
      Builtins.y2milestone(
        "%1 MakeProposal returned: %2",
        @proposal_module,
        @proposal_info
      )

      # do all the setting have valid values (is the proposal valid)?
      @proposal_valid = false
      if Ops.get_symbol(@proposal_info, "warning_level", :blocker) == nil
        @proposal_valid = true
      end


      if @proposal_valid == false || Edirectory.rerun_workflow == true
        Edirectory.rerun_workflow = true
        # ask for the eDirectory/OesLdap settings that cannot be defaulted (avoid a blocker in the configuartion summary)
        @proposal_askuser = Convert.to_map(
          WFM.CallFunction(
            @proposal_module,
            ["AskUser", { "force_reset" => false, "language_changed" => false }]
          )
        )
        Builtins.y2milestone(
          "%1 AskUser returned: %2",
          @proposal_module,
          @proposal_askuser
        )

        @ret = Ops.get_symbol(@proposal_askuser, "workflow_sequence")
      end

      # Finish
      Builtins.y2milestone("edirectory_preconfig finished")
      Builtins.y2milestone("----------------------------------------")

      @ret 

      # EOF
    end
  end
end

Yast::InstEdirectoryPreconfigClient.new.main
