# encoding: utf-8

# -------------------------------------------------------------------------------
# (C) Copyright 2019 - 2022 Micro Focus or one of its affiliates.
#
# The only warranties for products and services of Micro Focus and its affiliates
# and licensors (“Micro Focus”) are as may be set forth in the express warranty
# statements accompanying such products and services. Nothing herein should be
# construed as constituting an additional warranty. Micro Focus shall not be
# liable for technical or editorial errors or omissions contained herein. The
# information contained herein is subject to change without notice.
#
# Except as specifically indicated otherwise, this document contains confidential
# information and a valid license is required for possession, use or copying. If
# this work is provided to the U.S. Government, consistent with FAR 12.211 and
# 12.212, Commercial Computer Software, Computer Software Documentation, and
# Technical Data for Commercial Items  are licensed to the U.S. Government under
# vendor's standard commercial license.
# -------------------------------------------------------------------------------

# File:	include/novell-edirectory/helps.ycp
# Package:	Configuration of edirectory
# Summary:	Help texts of all the dialogs
# Authors:	Mark Clark <mclark@novell.com>, Denise Jewkes <dburrell@novell.com>
#
# $Id: helps.ycp,v 1.1.2.15 2005/10/24 21:26:43 rhaslam Exp $
module Yast
  module NovellEdirectoryHelpsInclude
    def initialize_novell_edirectory_helps(include_target)
      textdomain "novell-edirectory"

      # All helps are here
      @HELPS = {
        # Express install help
        "express_install"                   => _(
          "<p><b><big>Configured SLP Directory Agents</big></b><br>\n" +
            "Specify the hostname or IP address of an external server, and SLP scopes on which a SLP Directory Agent is running.</p>\n" +
            "<p>If you choose not to enter the SLP details, multicast SLP mode is chosen by default.</p>\n" +
            "<p><b>Note: </b>To configure the current server as the DA server, use the Custom Configuration.</p>\n"
        ) +
          _(
            "<p><b><big>Network Time Protocol (NTP) Server</big></b><br>\n" +
              "Specify the IP address or DNS hostname of an NTP server. For the first server in a tree, we recommend specifying a reliable, external time source, or you can specify Local Clock in the field to use the server hardware clock.</p>\n" +
              "<p>For servers joining a tree, specify the same external NTP time source that the tree is using, or specify the IP address / DNS hostname of a configured time source in the tree. A time source in the tree should be running time services for 15 minutes or more before connecting to it, or the time synchronization request for the installation fails.</p>\n" +
              "<p>If the time source server is NetWare 5.0 or earlier, you must specify an alternate NTP time source, or the time synchronization request fails. For more information, see the <i>OES 2018 SP3 Planning and Implementation Guide</i>.</p>\n"
          ) +
          _(
            "<p><b><big>Choose whether to install into an existing eDirectory tree or create a new tree.</big></b></p>\n"
          ) +
          _(
            "<p><b><big>New Tree</big></b><br>\nCreates a new tree. Use this option if this is the first server to go into the tree or if this server requires a separate tree. Keep in mind that this server will have the master replica for the new tree, and that users must log into this new tree to access its resources.</p>\n"
          ) +
          _(
            "<p><b><big>Existing Tree</big></b><br>\nIncorporates this server into an existing eDirectory tree. This server might not have a replica copied to it depending on the tree configuration. See the eDirectory documentation for details.</p>\n"
          ) +
          _("<p><b>Note: </b>The New Tree option is not available because this OES server is configured either with NCS or LUM and a remote eDirectory tree.</p>\n"
           ) +
           _("<p>In the Existing Tree section, if you change the eDirectory details, you must reconfigure the services on this server.</p>\n"
            ) +
          _(
            "<p><b><big>eDirectory Tree Name</big></b><br>\nSpecify the name of the eDirectory tree you want to create or the name of the tree you want to install this sever into. If you are creating a new tree, specify a unique tree name.</p>\n"
          ) +
          _(
            "<p><b><big>IP Address of an Existing eDirectory Server with a Replica</big></b><br>\n" +
              "Specify the IP address / hostname of an existing eDirectory server that is part of the eDirectory tree you are installing this server into.</p>\n" +
              "<p>Click Validate to verify the status of the eDirectory server. If the validation is unsuccessful, do not proceed with the installation.</p>\n"
          ) +
          # New Tree Dialog 1/3
          _(
            "<p><b><big>FDN Admin Name with Context</big></b><br>\n" +
              "Specify the name of the administrative user for the new tree. This is the fully distinguished name of a User object that will be created with full administrative rights in the new directory.</p>\n" +
              "<p>When specifying a context, you can use LDAP (comma delimited) or NDAP (dot delimited) format.</p>\n"
          ) +
          # New Tree Dialog 2/3
          _(
            "<p><b><big>Admin Password</big></b><br>\nSpecify the eDirectory administrator's password. This is the password of the user specified in the prior field.</p>\n"
          ) +
          # New Tree Dialog 3/3
          _(
            "<p><b><big>Verify Admin Password</big></b><br>\nRetype the password to verify that you previously typed the intended password.</p>\n"
          ) +
          # Context/Ports Dialog 1/6
          _(
            "<p><b><big>Enter Server Context</big></b><br>\n" +
              "Specify the location of the new server object in the eDirectory tree.</p>\n" +
              "<p>When specifying a context, you can use LDAP (comma delimited) or NDAP (dot delimited) format.</p>\n"
          ),
        # New OR Existing Tree Dialog 1/7
        "new_or_existing"                   => _(
          "<p>Choose whether to install into an existing \neDirectory tree or create a new tree.</p>\n"
        ) +
          # New OR Existing Tree Dialog 2/7
          _(
            "<p><b><big>New Tree</big></b><br>\nCreates a new tree. Use this option if this is the first server to go into the tree or if this server requires a separate tree. Keep in mind that this server will have the master replica for the new tree, and that users must log into this new tree to access its resources.</p>\n"
          ) +
          # New OR Existing Tree Dialog 3/7
          _(
            "<p><b><big>Existing Tree</big></b><br>\nIncorporates this server into an existing eDirectory tree. This server might not have a replica copied to it depending on the tree configuration. See the eDirectory documentation for details.</p>\n"
          ) +
          _("<p><b>Note: </b>The New Tree option is not available because this OES server is configured either with NCS or LUM and a remote eDirectory tree.</p>\n"
           ) +
           _("<p>In the Existing Tree section, if you change the eDirectory details, you must reconfigure the services on this server.</p>\n"
            ) +
          # New OR Existing Tree Dialog 4/7
          _(
            "<p><b><big>eDirectory Tree Name</big></b><br>\nSpecify the name of the eDirectory tree you want to create or the name of the tree you want to install this sever into. If you are creating a new tree, specify a unique tree name.</p>\n"
          ) +
          # New OR Existing Tree Dialog 5/7
          _(
            "<p><b><big>Use eDirectory Certificates for HTTPS Services</big></b><br>\n" +
              "Most OES services that provide HTTPS connectivity are configured by default to use the self-signed common server certificate created by YaST. Self-signed certificates provide minimal security and limited trust, so you should consider using eDirectory certificates instead.</p>\n" +
              "\n" +
              "<p>Selecting this option causes eDirectory to automatically back up the currently installed certificate and key files and replace them with files created by the eDirectory Organizational CA (or Tree CA).</p>\n" +
              "<p>For new server installations, this option is enabled by default and is recommended for the increased security it provides.</p>\n" +
              "<p>For add-on installations and upgrades to existing servers, this option is not selected by default. This prevents any certificates that you might have installed from a third-party CA from being accidentally backed up and overwritten. However, if you have not installed third-party certificates and your services are using the YaST-generated certificates, we recommend that you select this option for increased security.</p>\n" +
              "<p>For more information on certificate management and this option, see 'Security' in the <i>OES 2018 SP3: Planning and Implementation Guide.<i></p>\n"
          ) +
          # New OR Existing Tree Dialog 6/7
          _(
            "<p><b><big>Require TLS for Simple Binds with Password</big></b><br>\nTLS or Transport Layer Security allows for connections to be encrypted in the Session layer.</p>\n"
          ) +
          # New OR Existing Tree Dialog 7/7
          _(
            "<p><b><big>Install SecretStore</big></b><br>\nSecretStore(SS) is an eDirectory based security product.</p>\n"
          ) +
          # New OR Existing Tree Dialog 7/7
          _(
            "<p><b><big>Enable NMAS-based login for LDAP authentication</big></b><br>\nThis enforces the use of a single-secure password for all Novell and partner products. This universal password is managed by the Secure Password Manager of the NMAS module.</p>\n"
          ),
        # xad Existing Tree Dialog 1/5
        "xad_existing"                      => _(
          "<p><b><big>Existing eDirectory Tree Name</big></b><br>\nThe eDirectory tree in which the domain is being configured.</p>\n"
        ) +
          # xad Existing Tree Dialog 2/5
          _(
            "<p><b><big>Use eDirectory Certificates for HTTPS Services</big></b><br>\n" +
              "Most OES services that provide HTTPS connectivity are configured by default to use the self-signed common server certificate created by YaST. Self-signed certificates provide minimal security and limited trust, so you should consider using eDirectory certificates instead.</p>\n" +
              "\n" +
              "<p>Selecting this option causes eDirectory to automatically back up the currently installed certificate and key files and replace them with files created by the eDirectory Organizational CA (or Tree CA).</p>\n" +
              "<p>For new server installations, this option is enabled by default and is recommended for the increased security it provides.</p>\n" +
              "<p>For add-on installations and upgrades to existing servers, this option is not selected by default. This prevents any certificates that you might have installed from a third-party CA from being accidentally backed up and overwritten. However, if you have not installed third-party certificates and your services are using the YaST-generated certificates, we recommend that you select this option for increased security.</p>\n" +
              "<p>For more information on certificate management and this option, see 'Security' in the <i>OES 2018 SP3: Planning and Implementation Guide.<i></p>\n"
          ) +
          # xad Existing Tree Dialog 3/5
          _(
            "<p><b><big>Require TLS for Simple Binds with Password</big></b><br>\nTLS or Transport Layer Security allows for connections to be encrypted in the Session layer.</p>\n"
          ) +
          # xad Existing Tree Dialog 4/5
          _(
            "<p><b><big>Install SecretStore</big></b><br>\nSecretStore(SS) is an eDirectory based security product.</p>\n"
          ) +
          # New OR Existing Tree Dialog 5/5
          _(
            "<p><b><big>Enable NMAS-based login for LDAP authentication</big></b><br>\nThis enforces the use of a single-secure password for all Novell and partner products. This universal password is managed by the Secure Password Manager of the NMAS module.</p>\n"
          ),
        # New Tree Dialog 1/3
        "new_tree"                          => _(
          "<p><b><big>FDN Admin Name with Context</big></b><br>\n" +
            "Specify the name of the administrative user for the new tree. This is the fully distinguished name of a User object that will be created with full administrative rights in the new directory.</p>\n" +
            "<p>When specifying a context, you can use LDAP (comma delimited) or NDAP (dot delimited) format.</p>\n"
        ) +
          # New Tree Dialog 2/3
          _(
            "<p><b><big>Admin Password</big></b><br>\nSpecify the eDirectory administrator's password. This is the password of the user specified in the prior field.</p>\n"
          ) +
          # New Tree Dialog 3/3
          _(
            "<p><b><big>Verify Admin Password</big></b><br>\nRetype the password to verify that you previously typed the intended password.</p>\n"
          ),
        # Existing Tree New Forest Dialog 1/3
        "exist_tree_new_forest"             => _(
          "<p><b><big>FDN Domain Admin Name with Context</big></b><br>\nDisplays the name of the administrative user for the new tree. This is the fully distinguished name of a User object that will be created with full administrative rights in the new directory.</p>\n"
        ) +
          # Existing Tree New Forest Dialog 2/3
          _(
            "<p><b><big>Domain Admin Password</big></b><br>\nSpecify the eDirectory administrator's password. This is the password of the user specified in the prior field.</p>\n"
          ) +
          # Existing Tree New Forest Dialog 3/3
          _(
            "<p><b><big>Verify Domain Admin Password</big></b><br>\nRetype the password to verify that you previously typed the intended password.</p>\n"
          ),
        # Existing Tree Dialog A 1/1
        "existing_tree_a"                   => _(
          "<p><b><big>IP Address of an Existing eDirectory Server with a Replica</big></b><br>\n" +
            "Specify the IP address / hostname of an existing eDirectory server that is part of the eDirectory tree you are installing this server into.</p>\n" +
            "<p>Click Validate to verify the status of the eDirectory server. If the validation is unsuccessful, do not proceed with the installation.</p>\n"
        ),
        # Existing Tree Dialog DSFW A 1/1
        "existing_tree_dsfw_a"              => _(
          "<p><b><big>IP Address of an Existing eDirectory Server with a Replica</big></b><br>\n" +
            "Specify the IP address / hostname of an existing eDirectory server that is part of the eDirectory tree you are installing the first domain controller into.</p>\n" +
            "<p>Click Validate to verify the status of the eDirectory server. If the validation is unsuccessful, do not proceed with the installation.</p>\n"
        ),
        # Existing Tree Dialog B 1/5
        "existing_tree"                     => _(
          "<p><b><big>Enter NCP Port on the Existing Server</big></b><br>\n" +
            "Specify the NCP port number of the existing server. The default NCP port for most eDirectory servers is 524.\n" +
            "</p>\n"
        ) +
          # Existing Tree Dialog 2/5
          _(
            "<p><b><big>Enter LDAP Port on the Existing Server</big></b><br>\nSpecify the LDAP port number of the existing eDirectory server specified in the prior field. The default LDAP port for most eDirectory servers is 389.</p>\n"
          ) +
          # Existing Tree Dialog 3/5
          _(
            "<p><b><big>Enter Secure LDAP Port on the Existing Server</big></b><br>\nSpecify the secure LDAP port number of the existing eDirectory server specified in the prior field. The default secure LDAP port for most eDirectory servers is 636.</p>\n"
          ) +
          # Existing Tree Dialog 4/5
          _(
            "<p><b><big>FDN of the tree administrator</big></b><br>\n" +
              "Specify the Admin name and context of the Admin user in the existing eDirectory tree you are installing this server into. This is the fully distinguished name of the user object with administrative rights to eDirectory.</p>\n" +
              "<p>When specifying a context, you can use LDAP (comma delimited) or NDAP (dot delimited) format.</p>\n"
          ) +
          # Existing Tree Dialog 5/5
          _(
            "<p><b><big>Admin Password</big></b><br>\nSpecify the eDirectory administrator's password. This is the password of the user specified as Admin in the prior field.</p>\n"
          ),
        # Context/Ports Dialog 1/6
        "contextAndPorts"                   => _(
          "<p><b><big>Enter Server Context</big></b><br>\n" +
            "Specify the location of the new server object in the eDirectory tree.</p>\n" +
            "<p>When specifying a context, you can use LDAP (comma delimited) or NDAP (dot delimited) format.</p>\n" +
            "<p><b>Warning: Avoid editing this field if this server is being added to a Domain Services for Windows tree/domain.</b></p>\n"
        ) +
          # Context/Ports Dialog 2/6
          _(
            "<p><b><big>Enter Directory Information Base (DIB) Location</big></b><br>\nSpecify a location for the eDirectory database. The default path is /var/opt/novell/eDirectory/data/dib, but you can use this option to change the location if you expect the number of objects in your tree to be large and the current file system does not have sufficient space.</p>\n"
          ) +
          # Context/Ports Dialog 3/6
          _(
            "<p><b><big>Enter LDAP Port</big></b><br>\nSpecify the LDAP port number this server will use to service LDAP requests. The default LDAP port is 389.</p>\n"
          ) +
          # Context/Ports Dialog 4/6
          _(
            "<p><b><big>Enter Secure LDAP Port</big></b><br>\nSpecify secure LDAP port number this server will use to service LDAP requests. The default secure LDAP port is 636.</p>\n"
          ) +
          # Context/Ports Dialog 5/6
          _(
            "<p><b><big>Enter iMonitor Port</big></b><br>\nSpecify the port this server will use to provide access to the iMonitor application. iMonitor lets you monitor and diagnose all servers in your eDirectory tree from any location on your network where a Web browser is available. The default iMonitor port is 8028.</p>\n"
          ) +
          # Context/Ports Dialog 6/6
          _(
            "<p><b><big>Enter Secure iMonitor Port</big></b><br>\nSpecify the secure port this server will use to provide access to the iMonitor application. The default secure iMonitor port is 8030.</p>\n"
          ),
        # NTP dialog help 1/1
        "NTP"                               => _(
          "<p><b><big>Network Time Protocol (NTP) Servers</big></b><br>\n" +
            "Specify the IP address or DNS hostname of an NTP server. For the first server in a tree, we recommend specifying a reliable, external time source, or you can specify Local Clock in the field to use the server hardware clock.</p>\n" +
            "<p>For servers joining a tree, specify the same external NTP time source that the tree is using, or specify the IP address of a configured time source in the tree. A time source in the tree should be running time services for 15 minutes or more before connecting to it, or the time synchronization request for the installation fails.</p>\n" +
            "<p>If the time source server is NetWare 5.0 or earlier, you must specify an alternate NTP time source, or the time synchronization request fails. For more information, see the <i>OES 2018 SP3 Planning and Implementation Guide</i>.</p>\n" +
            "<p>To add an NTP server, click Add.</p>\n"
        ),
        # SLP dialog help 1/9
        "SLP"                               => _(
          "<p><b><big>IMPORTANT:</big></b> If the tree where you are installing this server has or will have more than three servers, you must configure SLP.</p>\n"
        ) +
          # SLP dialog help 2/9
          _(
            "<p><b><big>Use Multicast to Access SLP</big></b><br>\nSends SLP requests to multiple servers using the Service Location General Multicast Address (224.0.1.22). All Service Agents holding service information that satisfies the request unicast the reply directly to the requesting User Agent. Use this option if no Directory Agents are available.</p>\n"
          ) +
          # SLP dialog help 3/9
          _(
            "<p><b><big>Configure SLP to Use an Existing Directory Agent</big></b><br>\nConfigures SLP to use an existing Directory Agent in your network. A Directory Agent stores and disseminates service information for the network.</p>\n"
          ) +
          # SLP dialog help 4/9
          _(
            "<p><b><big>Configure as Directory Agent</big></b><br>\nThis option allows the current server to become a DA server.</p>\n"
          ) +
          # SLP dialog help 5/9
          _(
            "<p><b><big>Synchronize Service Registrations with other Directory Agents</big></b><br>\nThis option enables SLP to query statically configured Directory Agents for registrations.</p>\n"
          ) +
          # SLP dialog help 6/9
          _(
            "<p><b><big>Backup SLP Registrations</big></b><br>\nThis option lets the SLP server choose to periodically backup all registrations.</p>\n"
          ) +
          # SLP dialog help 7/9
          _(
            "<p><b><big>Backup Interval in Seconds</big></b><br>\nThis option lets the SLP server know how frequently a backup is done.</p>\n"
          ) +
          # SLP dialog help 8/9
          _(
            "<p><b><big>Service Location Protocol Scopes</big></b><br>\n" +
              "Specify the scope a User Agent (UA) or Service Agent (SA) is allowed when making requests or when registering services, or specify the scope a Directory Agent (DA) must support. The default value is DEFAULT.\n" +
              "<p>Use commas with no space to separate each scope. For example, net.slp.useScopes = myScope1,myScope2,myScope3</p>\n"
          ) +
          # SLP dialog help 9/9
          _(
            "<p><b><big>Configured SLP Directory Agents</big></b><br>\n" +
              "Specify the hostname or IP address of one or more external servers on which a SLP Directory Agent is running.</p>\n" +
              "<p>To add an agent, click <b>Add</b>. In the SLP DA Server field, specify a server's DNS name or IP address, then click <b>Add</b>.</p> \n" +
              "<p>To remove an agent, select one or more agents to remove, then click <b>Delete</b>.</p>\n"
          ),
        # Read dialog help 1/2
        "read"                              => _(
          "<p><b><big>Initializing eDirectory Configuration</big></b><br>\nPlease wait...</p>\n"
        ) +
          # Read dialog help 2/2
          _(
            "<p><b><big>Aborting Initialization:</big></b><br>\nSafely stop the configuration utility by clicking <b>Abort</b> now.</p>\n"
          ),
        # Write dialog help 1/2
        "write"                             => _(
          "<p><b><big>Saving eDirectory Configuration</big></b><br>\nPlease wait...</p>\n"
        ) +
          # Write dialog help 2/2
          _(
            "<p><b><big>Aborting Saving:</big></b><br>\n" +
              "Stop the save procedure by clicking <b>Abort</b>.\n" +
              "This opens an additional dialog that indicates whether it is safe to do so.</p>\n"
          ),
        "d1"                                => _(
          "<p><b><big>LDAP server IP address or DNS Name</big></b><br>\nSpecify the IP address or DNS name of the LDAP server.</p>\n"
        ),
        "d2"                                => _(
          "<p><b><big>Admin Name with Context</big></b><br>\n" +
            "Specify the LDAP Admin name with context. This is the fully distinguished name of a User object with administrative rights to eDirectory.</p>\n" +
            "<p>When specifying a context, you can use LDAP (comma delimited) or NDAP (dot delimited) format.</p>\n"
        ) +
          _(
            "<p><b><big>Admin Password</big></b><br>\nSpecify the LDAP Admin password. This is the password of the user specified as the LDAP Admin.</p>\n"
          ) +
          _(
            "<p><b><big>Enter LDAP Port</big></b><br>\nSpecify the LDAP port number this server uses to communicate with other servers. The default is 389.</p>\n"
          ) +
          _(
            "<p><b><big>Enter Secure LDAP Port</big></b><br>\nSpecify the secure LDAP port number this server uses to communicate with other servers. The default is 636.</p>\n"
          ),
        # Upgrade Server Dialog with no replica IP 1/1
        "existing_local_no_replica"         => _(
          "<p><b><big>IP Address of an Existing eDirectory Server with a Replica</big></b><br>\n" +
            "Specify the IP address of an existing eDirectory server that is part of the eDirectory tree you are upgrading this server into.</p>\n" +
            "<p>If you are installing Domain Services for Windows and you will be installing an additional Domain Controller, enter IP address of the existing domain controller.</p>\n" +
            "<p>Click Validate to verify the status of the eDirectory server. If the validation is unsuccessful, do not proceed with the installation.</p>\n"
        ),
        # Upgrade Server Dialog 1/4
        "existing_local"                    => _(
          "<p><b><big>FDN Admin Name with Context</big></b><br>\n" +
            "Specify the name and context for user Admin on the local eDirectory tree. This is the fully distinguished name of the user object with administrative rights to eDirectory.</p>\n" +
            "<p>When specifying a context, you can use LDAP (comma delimited) or NDAP (dot delimited) format.</p>\n"
        ) +
          # Upgrade Server Dialog 2/4
          _(
            "<p><b><big>Admin Password</big></b><br>\nSpecify the password for the eDirectory administrator. This is the password of the user specified as Admin.</p>\n"
          ) +
          # Upgrade Server Dialog 3/4
          _(
            "<p><b><big>Path to nds.conf File</big></b><br>\nSpecify the path to the existing nds.conf of the eDirectory being upgraded.</p>\n"
          ) +
          # Upgrade Server Dialog 4/4
          _(
            "<p><b><big>Use eDirectory Certificates for HTTPS Services</big></b><br>\n" +
              "Most OES services that provide HTTPS connectivity are configured by default to use the self-signed common server certificate created by YaST. Self-signed certificates provide minimal security and limited trust, so you should consider using eDirectory certificates instead.</p>\n" +
              "\n" +
              "<p>Selecting this option causes eDirectory to automatically back up the currently installed certificate and key files and replace them with files created by the eDirectory Organizational CA (or Tree CA).</p>\n" +
              "<p>For new server installations, this option is enabled by default and is recommended for the increased security it provides.</p>\n" +
              "<p>For add-on installations and upgrades to existing servers, this option is not selected by default. This prevents any certificates that you might have installed from a third-party CA from being accidentally backed up and overwritten. However, if you have not installed third-party certificates and your services are using the YaST-generated certificates, we recommend that you select this option for increased security.</p>\n" +
              "<p>For more information on certificate management and this option, see 'Security' in the <i>OES 2018 SP3 Planning and Implementation Guide.<i></p>\n"
          ),
        # DSFW Upgrade Server Dialog 1/1
        "dsfw_upgrade"                      => _(
          "<p><b><big>Domain Admin Password</big></b><br>\nSpecify the password for the Domain Administrator.</p>\n"
        ),
        # NMAS Login Methods 1/10
        "nmas_login_methods"                => _(
          "<p><b><big>Novell Modular Authentication Services</big></b>\nChoose the login methods that you want to install into eDirectory by selecting the appropriate check boxes.</p>\n"
        ) +
          # NMAS Login Methods 2/10
          _(
            "<p>If you want to install all of the login methods into eDirectory, click <b>Select All</b>.</p>\n<p>If you want to clear all selections, click <b>Deselect All</b>.</p>\n"
          ) +
          # NMAS Login Methods 3/10
          _(
            "<p><b>IMPORTANT:</b> The NMAS client software must be installed on each client workstation where you want to use the NMAS login methods. The NMAS client software is included with the Novell Client software.</p>\n"
          ) +
          # NMAS Login Methods 4/10
          _(
            "<p><b>CertMutual</b><br>\nThe Certificate Mutual login method implements the Simple Authentication and Security Layer (SASL) EXTERNAL mechanism, which uses SSL certificates to provide client authentication to eDirectory through LDAP.</p>\n"
          ) +
          # NMAS Login Methods 5/10
          _(
            "<p><b>Challenge Response</b><br>\nThe Challenge-Response login method works with the Identity Manager password self-service process. This method allows either an administrator or a user to define a password challenge question and a response, which are saved in the password policy. Then, when users forget their passwords, they can reset their own passwords by providing the correct response to the challenge question.</p>\n"
          ) +
          # NMAS Login Methods 6/10
          _(
            "<p><b>DIGEST-MD5</b><br>\nThe Digest MD5 login method implements the Simple Authentication and Security Layer (SASL) DIGEST-MD5 mechanism as a means of authenticating the user to eDirectory through LDAP.</p>\n"
          ) +
          # NMAS Login Methods 7/10
          _(
            "<p><b>NDS</b><br>\nThe NDS login method provides secure password challenge-response user authentication to eDirectory. This method supports the traditional NDS password when the NMAS client is in use. Reinstallation is necessary only if the NDS login method object has been removed from the directory.</p>\n"
          ) +
          # NMAS Login Methods 8/10
          _(
            "<p><b>Simple Password</b><br>\nThe Simple Password NMAS login method provides password authentication to eDirectory. The Simple Password is a more flexible but less secure alternative to the NDS password. Simple Passwords are stored in a secret store on the user object.</p>\n"
          ) +
          # NMAS Login Methods 9/10
          _(
            "<p><b>SASL GSSAPI</b><br>\n" +
              "The SASL GSSAPI login method implements the Generic Security Services Application Program Interface (GSSAPI) authentication using the Simple Authentication and Security Layer (SASL) that enables users to authenticate to eDirectory through LDAP using a Kerberos ticket.\n" +
              "</p>"
          ) +
          # NMAS Login Methods 10/10
          _(
            "<p>For more information on these login methods, see Managing Login and Post-Login Methods and Sequences in the <i>Novell Modular Authentication Services (NMAS) Administration Guide</i>.\n</p>"
          ),
        # New OR Existing Tree Dialog Novell Domain Services for Windows 1/7
        "new_or_existing_ndsw"              => _(
          "<p>Choose whether to install into an existing eDirectory tree or create a new tree.</p>\n"
        ) +
          # New OR Existing Tree Dialog Novell Domain Services for Windows 2/7
          _(
            "<p><b><big>New Tree</big></b><br>\nCreates a new eDirectory tree. Use this option if this is the first server to go into the tree or if this server requires a separate tree. Keep in mind that this server will have the master replica for the new tree, and that users must log into this new tree to access its resources.</p>\n"
          ) +
          # New OR Existing Tree Dialog Novell Domain Services for Windows 3/7
          _(
            "<p><b><big>Existing Tree</big></b><br>\nIncorporates this server into an existing eDirectory tree.</p>\n"
          ) +
          # New OR Existing Tree Dialog Novell Domain Services for Windows 4/7
          _(
            "<p><b><big>Tree Name</big></b><br>\nSpecify the name of the eDirectory tree you want to create or the name of the tree you want to install this server into. If you are creating a new tree, the name must be unique.</p>\n"
          ) +
          # New OR Existing Tree Dialog Novell Domain Services for Windows 5/7
          _(
            "<p><b><big>Use eDirectory Certificates for HTTPS Services</big></b><br>\n" +
              "Most OES services that provide HTTPS connectivity are configured by default to use the self-signed common server certificate created by YaST. Self-signed certificates provide minimal security and limited trust, so you should consider using eDirectory certificates instead.</p>\n" +
              "<p>Selecting this option causes eDirectory to automatically back up the currently installed certificate and key files and replace them with files created by the eDirectory Organizational CA (or Tree CA).</p>\n" +
              "<p>For new server installations, this option is enabled by default and is recommended for the increased security it provides.</p>\n" +
              "<p>For add-on installations and upgrades to existing servers, this option is not selected by default. This prevents any certificates that you might have installed from a third-party CA from being accidentally backed up and overwritten. However, if you have not installed third-party certificates and your services are using the YaST-generated certificates, we recommend that you select this option for increased security.</p>\n" +
              "<p>For more information on certificate management and this option, see 'Security' in the <i>OES 2018 SP3: Planning and Implementation Guide.<i></p>\n"
          ) +
          # New OR Existing Tree Dialog Novell Domain Services for Windows 6/7
          _(
            "<p><b><big>Require TLS for Simple Binds with Password</big></b><br>\n" +
              "TLS or Transport Layer Security allows for connections to be encrypted in the Session layer.</p>\n" +
              " "
          ) +
          # New OR Existing Tree Dialog Novell Domain Services for Windows 7/7
          _(
            "<p><b><big>Configure Domain Services for Windows</big></b><br>\n" +
              "If you want to configure this server for Domain Services for Windows in the eDirectory tree, select this option now. It is not possible to reconfigure it for Domain Services for Windows after eDirectory has already been installed and configured.</p>\n" +
              " "
          ),
        # eDirectory Configuration for Novell Domain Services for Windows 1/2
        "eDir_conf_ndsw"                    => _(
          "<p>Select the type of Domain Services for Windows configuration you want.</p>\n"
        ) +
          # eDirectory Configuration for Novell Domain Services for Windows 2/2
          _(
            "<p><b><big>Select Server Type:</big></b><br>\n" +
              "Select one of the following options:</p>\n" +
              "<p><b>New Domain Services for Windows Forest:</b> Creates a new Domain Services for Windows forest which acts as forest root domain and primary domain controller for that domain.</p>\n" +
              "<p><b>New Domain in an Existing Domain Services for Windows Forest:</b> Creates a new domain in an existing Domain Services for Windows forest.</p>\n" +
              "<p><b>New Domain Controller in an Existing Domain Services for Windows Domain:</b> Creates a new domain controller in an existing Domain Services for Windows domain.</p>\n" +
              "<p><b>Express Install:</b> Express Install minimizes the number of configuration screens and assigns default values for certain configuration parameters.</p>\n" +
              "<p>On selecting this option, the local server configuration, NMAS, SLP, DNS, and common proxy screens will not be displayed. Instead, default values will be selected.</p>\n"
          ),
        # eDirectory Configuration for Novell Domain Services for Windows 1/6
        "eDir_conf_ndsw_2"                  => _(
          "<p>Verify Domain Name Service (DNS) information.</p>\n"
        ) +
          # eDirectory Configuration for Novell Domain Services for Windows 2/6
          _(
            "<p><b><big>DNS Name for New Domain</big></b><br>\n" +
              "The DNS name for the new domain is automatically populated based on the Hostname and DNS configuration settings.</p> \n" +
              "<p><b>Note:</b> You must ensure that hostname in the properties of the active ethernet conroller is an FQDN. For example, if the hostname is dc1 and the domain name is dsfw.com then the hostname in YaST>Network Devices>Network Settings>Hostname/DNS tab of the active ethernet controller must be dc1.dsfw.com. You can modify the hostname of the active ethernet controller by using the Edit option in the Overview tab of LAN settings in YaST.</p>\n"
          ) +
          # eDirectory Configuration for Novell Domain Services for Windows 3/6
          _(
            "<p><b><big>Configure this server as a DNS Server</big></b><br>\n" +
              "If you want this server to be a DNS server for the domain, select this option.</p>\n" +
              "<p>If this option is not selected, you must ensure that a DNS server that contains the domain names for Domain Services for Windows is available somewhere in the network.</p>\n"
          ) +
          # eDirectory Configuration for NDSW NetBIOS Name New forest 4/6
          _(
            "<p><b><big>NetBIOS Domain Name</big></b><br>\n" +
              "The domain NetBIOS name is automatically populated based on the domain name of the server. By default, this is the domain context name without the parent context. For example, for the domain dsfw.com, the default NetBIOS name is DSFW.</p>\n" +
              "<p>By default, this is the domain context name without the parent context. For example, in the domain cn=central,dc=example,dc=com, the default NetBIOS name is central.</p>\n"
          ) +
          # eDirectory Configuration for Novell Domain Services for Windows 5/6
          _(
            "<p><b><big>Configure this server as a WINS Server</big></b><br>\n" +
              "If you want this server to be a WINS  server for the domain, select this option.</p>\n" +
              "<p>Configuring a DSfW server as a WINS server enables you to prevent duplicate workstation names in a domain. If a client is configured to use a WINS server, before joining a domain, the administrator will be alerted that a workstation with the same name already exists in the domain.</p>\n" +
              "<p>You can configure only one DSfW domain controller as a WINS server in a domain. If the domain already has a WINS server configured, this option is disabled.</p>\n"
          ) +
          # eDirectory Configuration for Novell Domain Services for Windows 6/6
          _(
            "<p><b><big>Site Name of Domain Controller</big></b><br>\n" +
              "This field is populated with the default site name that is created when you configure the first domain controller.</p>\n" +
              "<p>Specify the name of the site that the domain controller is associated with or Browse to select the name.</p>\n"
          ),
        # eDirectory Configuration for NDSW NetBIOS Name New Domain 1/3
        "eDir_conf_ndsw_netbios_domain"     => _(
          "<p>The following fields are automatically populated.</p>\n"
        ) +
          # eDirectory Configuration for NDSW NetBIOS Name New Domain 2/3
          _(
            "<p><b><big>Forest Root Domain</big></b><br>\nThe forest root domain is the first domain in the first tree of the Domain Services for Windows forest. The forest root has no parent, and it provides the LDAP entry point to Domain Services for Windows.</p>\n"
          ) +
          # eDirectory Configuration for NDSW NetBIOS Name New Domain 3/3
          _(
            "<p><b><big>Parent Domain</big></b><br>\nThe parent domain is the domain superior to the domain being configured..</p>\n"
          ),
        # eDirectory Configuration for NDSW NetBIOS Name New Domain Controller 1/2
        "eDir_conf_ndsw_netbios_controller" => _(
          "<p>Specify the information required to create a context for this server in the new domain or as a new domain controller in a Domain Services for Windows forest.</p>\n"
        ) +
          # eDirectory Configuration for NDSW NetBIOS Name New Domain Controller 2/2
          _(
            "<p><b><big>Forest Root Domain</big></b><br>\n" +
              "Specify the name of the forest root domain that you want to create this domain or domain controller in.</p>\n" +
              "<p>The forest root domain is the first domain in the first tree of the Domain Services for Windows forest. The forest root has no parent, and it provides the LDAP entry point to Domain Services for Windows.</p>\n"
          ),
        # eDirectory Configuration for NDSW NetBIOS Name New forest 1/2
        "eDir_conf_ndsw_netbios_forest"     => _(
          "<p>Specify the information required to create a context for this server in the new domain or as a new domain controller in a Domain Services for Windows forest.</p>\n"
        ) +
          # eDirectory Configuration for NDSW NetBIOS Name New forest 2/2
          _(
            "<p><b><big>Domain NetBIOS Name</big></b><br>\n" +
              "Specify a NetBIOS name for the Domain Services for Windows domain, or specify the NetBIOS name for the Domain Services for Windows domain you are installing this domain or controller into.</p>\n" +
              "<p>By default, this is the domain context name without the parent context. For example, in the domain cn=central,dc=example,dc=com, the default NetBIOS name is central.</p>\n"
          ),
        # eDirectory Configuration for NDSW Specify Administrator Password  1/3
        "eDir_conf_ndsw_administrator_pw"   => _(
          "<p><b><big>Forest Root Domain</big></b><br>\nName of the forest root domain. This is the first domain in the DSFW forest.</p>\n"
        ) +
          # eDirectory Configuration for NDSW Specify Administrator Password  2/3
          _(
            "<p><b><big>Existing Domain Administrator Name</big></b><br>\nThe admin user with administrative rights to the domain to which the additional domain controller is being added to.</p>\n"
          ) +
          # eDirectory Configuration for NDSW Specify Administrator Password  3/3
          _(
            "<p><b><big>Specify Administrator Password</big></b><br>\nSpecify the domain administrator password.</p>\n"
          ),
        # eDirectory Configuration for NDSW IP Address of Parent Domain 1/5
        "eDir_conf_ndsw_ip_parent_domain"   => _(
          "<p><b><big>Parent Domain Adminstrator Name</big></b><br>\nName and context for the parent domain administrator that you are creating this domain in. This field is automatically populated.</p>\n"
        ) +
          # eDirectory Configuration for NDSW IP Address of Parent Domain 2/5
          _(
            "<p><b><big>Admin Password</big></b><br>\nSpecify the password for the Administrator account of the parent domain.</p>\n"
          ) +
          # eDirectory Configuration for NDSW Specify Administrator Password  3/5
          _(
            "<p><b><big>New Domain Administrator Name</big></b><br>\nName and context of the Administrator account. This is the Administrator you are entering the password for. You will use this account to log in to the Domain Services for Windows domain. This field is automatically populated.</p>\n"
          ) +
          # eDirectory Configuration for NDSW Specify Administrator Password  4/5
          _(
            "<p><b><big>Specify Administrator Password</big></b><br>\nSpecify a password for the Administrator account shown in the previous field.</p>\n"
          ) +
          # eDirectory Configuration for NDSW Specify Administrator Password  5/5
          _(
            "<p><b><big>Verify Administrator Password</big></b><br>\nRetype the password to verify that you previously typed the intended password.</p>\n"
          ),
        # eDirectory Configuration for NDSW Name Map 1/6
        "eDir_conf_ndsw_namemap"            => _(
          "<p>Use this dialog to optionally map the new domain to an existing eDirectory container.</p>\n"
        ) +
          # eDirectory Configuration for NDSW Name Map 3/6
          _(
            "<p><b><big>Enter the FDN of the Container That Needs to Be Mapped As (Domain Name)</big></b><br>\n" +
              "Browse or specify the fully distinguished, typeful name of the existing eDirectory container that you want to be mapped.</p>\n" +
              "<p>Only O, OU, and containers derived from LoginProperties can be mapped. Mapping Country and Locality objects is not supported.</p>\n"
          ) +
          # eDirectory Configuration for NDSW Name Map 6/6
          _(
            "<p><b><big>Retain existing Novell Password Policies on Users</big></b><br>\nKeep any existing user password policies.</p>\n"
          ),
        # Context/Ports Dialog for Novell Domain Services for Windows 1/6
        "contextAndPorts_ndsw"              => _(
          "<p>Specify the configuration for the local server in the eDirectory tree.</p>\n"
        ) +
          # Context/Ports Dialog for Novell Domain Services for Windows 2/6
          _(
            "<p><b><big>Server Context</big></b><br>\nThe system object's context for the DSFW domain that is being configured.</p>\n"
          ) +
          # Context/Ports Dialog for Novell Domain Services for Windows 3/6
          _(
            "<p><b><big>Enter Directory Information Base (DIB) Location</big></b><br>\nSpecify a location for the eDirectory database. The default path is /var/opt/novell/eDirectory/data/dib, but you can use this option to change the location if you expect the number of objects in your tree to be large and if the current file system does not have sufficient space.</p>\n"
          ) +
          # Context/Ports Dialog for Novell Domain Services for Windows 4/6
          _(
            "<p><b><big>LDAP and Secure LDAP Ports</big></b><br>\nThe LDAP and secure LDAP port numbers this server will use to service LDAP requests are shown.</p>\n"
          ) +
          # Context/Ports Dialog for Novell Domain Services for Windows 5/6
          _(
            "<p><b><big>Enter iMonitor Port</big></b><br>\nSpecify the port this server will use to provide access to the iMonitor application. iMonitor lets you monitor and diagnose all servers in your eDirectory tree from any location on your network where a Web browser is available. The default iMonitor port is 8028.</p>\n"
          ) +
          # Context/Ports Dialog for Novell Domain Services for Windows 6/6
          _(
            "<p><b><big>Enter Secure iMonitor Port</big></b><br>\nSpecify the secure port this server will use to provide access to the iMonitor application. The default secure iMonitor port is 8030.</p>\n"
          ),
        # DNS Services Configure help 1/1
        "configure_dns_0"                   => _(
          "<p><b><big>OES DNS Services Configuration</big></b><br>\nUse this dialog to specify options for configuring a DNS server that is integrated with eDirectory on this server.</p>\n"
        ),
        # DNS Services Configure help 1/3
        "configure_dns4"                    => _(
          "<p><b><big>Get Context Information from Existing DNS Server</big></b><br>\nIf you are configuring DNS in an existing tree where DNS is already configured, select the 'Get context and proxy user information from existing DNS server' check box. Specify the IP address of an NCP server hosting the existing DNS server and click Retrieve. This will fetch the contexts of the Locator, Root Server Info, Group.</p>\n"
        ) +
          # DNS Services Configure help 2/3
          _(
            "<p><b><big>OES DNS Services Locator Object Context</big></b><br>\n" +
              "Specify the context for the DNS Locator object.<br>For example: ou=dns,o=microfocus</p>\n" +
              "<p>The Locator object contains global defaults, DHCP options, and a list of all DNS and DHCP servers, subnets, and zones in the tree.</p>\n"
          ) +
          # DNS Services Configure help 3/3
          _(
            "<p><b><big>OES DNS Services Group Object Context</big></b><br>\n" +
              "Specify the context for the DNS Group object.<br>For example: ou=dns,o=microfocus</p>\n" +
              "<p>This object is used to grant DNS servers the necessary rights to other data within the eDirectory tree.</p>\n"
          ),
        # DNS Services Configure help 1/9
        "configure_dns"                     => _(
          "<p><b><big>Get Context Information from Existing DNS Server</big></b><br>\nIf you are configuring DNS in an existing tree where DNS is already configured, select the 'Get context and proxy user information from existing DNS server' check box. Specify the IP address of an NCP server hosting the existing DNS server and click Retrieve. This will fetch the contexts of the Locator, Root Server Info, Group.</p>\n"
        ) +
          # DNS Services Configure help 2/9
          _(
            "<p><b><big>OES DNS Services Locator Object Context</big></b><br>\n" +
              "Specify the context for the DNS Locator object.<br>For example: ou=dns,o=microfocus</p>\n" +
              "<p>The Locator object contains global defaults, DHCP options, and a list of all DNS and DHCP servers, subnets, and zones in the tree.</p>\n"
          ) +
          # DNS Services Configure help 3/9
          _(
            "<p><b><big>OES DNS Services Root Server Info Context</big></b><br>\n" +
              "Specify the context for the DNS Services root server.<br>For example: ou=OESSystemObjects,dc=dsfw,dc=com</p>\n" +
              "<p>The RootSrvrInfo Zone is an eDirectory container object that contains resource records for the DNS root servers</p>\n"
          ) +
          # DNS Services Configure help 4/9
          _(
            "<p><b><big>OES DNS Services Group Object Context</big></b><br>\n" +
              "Specify the context for the DNS Group object.<br>For example: ou=dns,o=microfocus</p>\n" +
              "<p>This object is used to grant DNS servers the necessary rights to other data within the eDirectory tree.</p>\n"
          ) +
          # DNS Services Configure help 5/9
          _(
            "<p><b><big>Proxy User for DNS Management</big></b><br>\n" +
              "Specify the fully distinguished, typeful name of an eDirectory user that will be used for DNS management. <br>For example: cn=dns-admin,dc=dsfw,dc=com</p>\n" +
              "<p>This user is used to authenticate to eDirectory to access information for DNS during runtime. The user must have eDirectory read, write, and browse rights under the specified context.</p>\n"
          ) +
          # DNS Services Configure help 6/9
          _(
            "<p><b><big>Specify Password for Proxy User</big></b><br>\nSpecify the password of the proxy user that you specified for accessing DNS.</p>\n"
          ) +
          # DNS Services Configure help 7/9
          _(
            "<p><b><big>Verify Password for Proxy User</big></b><br>\nRetype the password to verify that you previously typed the correct password.</p>\n"
          ) +
          # DNS Services Configure help 8/9
          _(
            "<p><b><big>Use Secure LDAP Port</big></b><br>\nThe Use Secure LDAP Port is selected by default to ensure that the data transferred by this service is secure and private. If you deselect this option, the transferred data is in clear text format.</p>\n"
          ) +
          # DNS Services Configure help 9/9
          _(
            "<p><b><big>Credential Storage Location</big></b><br>\nSpecify the Credential Storage Location as OCS or local file based format.</p>\n"
          ),
        # Proxy User Dialog 1/8
        "proxy_user"                        => _(
          "<p><b><big>OES Common Proxy User Information</big></b><br>\nUse this screen to set the default common proxy user for the services that require proxy users.</p>\n"
        ) +
          # Proxy User Dialog 2/8
          _(
            "<p><b><big>Use Common Proxy User as Default for OES Products</big></b><br>\nSelecting this option allows the current user to be used as the default proxy user for services that require proxy users.</p>\n"
          ) +
          # Proxy User Dialog 3/8
          _(
            "<p><b><big>OES Common Proxy User Name</big></b><br>\nThis is the default common proxy user for the services that require proxy users. The user is created if it does not exist in the eDirectory. This value cannot be changed.</p>\n"
          ) +
          # Proxy User Dialog 4/8
          _(
            "<p><b><big>OES Common Proxy User Context</big></b><br>\nSpecify the context for the common proxy user name above. This context is created if it does not exist in the eDirectory.</p>\n"
          ) +
          # Proxy User Dialog 5/8
          _(
            "<p><b><big>OES Common Proxy User Password</big></b><br>\nSpecify the proxy user's password. Note: If there is a specific password policy configured, ensure that you enter a password that complies with it.</p>\n"
          ) +
          # Proxy User Dialog 6/8
          _(
            "<p><b><big>Verify OES Common Proxy User Password</big></b><br>\nRetype the password to verify that you typed the correct password.</p>\n"
          ) +
          # Proxy User Dialog 7/8
          _(
            "<p><b><big>Assign Common Proxy Password Policy to Proxy User</big></b><br>\nSelect this box to assign the user to the common proxy password policy.</p>\n"
          ) +
          # Proxy User Dialog 8/8
          _(
            "<p><b><big>Note:</big></b><br>\nIf all fields are disabled, then all services will use their own proxy user.</p>\n"
          )
      } 


      # EOF
    end
  end
end
