# encoding: utf-8

# File:	include/novell-edirectory/wizards.ycp
# Package:	Configuration of edirectory
# Summary:	Wizards definitions
# Authors:	Anas Nashif <nashif@suse.de>
#
# $Id: wizards.ycp,v 1.1.2.21 2005/09/01 17:39:37 rhaslam Exp $
module Yast
  module NovellEdirectoryWizardsInclude
    def initialize_novell_edirectory_wizards(include_target)
      Yast.import "UI"

      textdomain "novell-edirectory"

      Yast.import "Sequencer"
      Yast.import "Wizard"

      Yast.include include_target, "novell-edirectory/dialogs.rb"
    end

    # This is the sequence for installing eDirectory
    # @return sequence result
    def EdirectorySequence
      aliases = {
        "xad_or_edir"      => lambda { DoXadorEdirDialogs() },
        "new_or_existing"  => lambda { NewOrExistingDialog() },
        "xad_existing"     => lambda { XadExistingDialog() },
        "xad_domain_type"  => lambda { XadDomainChoiceDialog() },
        "xad_domain_admin" => lambda { XadDomainAdminDialog() },
        "xad_admin"        => lambda { ExistingTreeNewForestAdminDialog() },
        "xad_dns"          => lambda { XadDnsDialog() },
        "xad_dns_remote"   => lambda { XadDnsRemoteDialog() },
        "xad_domain_name"  => lambda { XadDomainAndNetbiosDialog() },
        "xad_netbios"      => lambda { XadNetBIOSDialog() },
        "parent_domain"    => lambda { XadParentDomainDialog() },
        "new_tree"         => lambda { NewTreeDialog() },
        "existing_tree"    => lambda { ExistingTreeDialog() },
        "name-mapping"     => lambda { XadNameMappingDialog() },
        "ports"            => lambda { ContextAndPortsDialog() },
        "ntp"              => lambda { NTPDialog() },
        "slp"              => lambda { SLPDialog() },
        "nmas"             => lambda { NMASOptionsDialog() },
        "proxy_user"       => lambda { ProxyUserDialog() }
      }

      sequence = {
        "ws_start"         => "xad_or_edir",
        "xad_or_edir"      => { :edir => "slp", :xad => "xad_domain_type" },
        "new_or_existing"  => {
          :abort    => :abort,
          :new      => "new_tree",
          :existing => "existing_tree",
          :next     => "new_tree",
          :edir     => "slp"
        },
        "xad_domain_type"  => {
          :abort => :abort,
          :next  => "new_or_existing",
          :xad   => "xad_existing"
        },
        "xad_domain_name"  => {
          :abort  => :abort,
          :next   => "xad_admin",
          :ntp    => "ntp",
          :xaddc  => "xad_domain_admin",
          :parent => "parent_domain"
        },
        "xad_existing"     => { :abort => :abort, :next => "existing_tree" },
        "xad_dns"          => { :abort => :abort, :next => :next },
        "xad_admin"        => { :abort => :abort, :next => "ntp" },
        "xad_dns_remote"   => { :abort => :abort, :next => :next },
        "xad_netbios"      => {
          :abort   => :abort,
          :next    => :next,
          :mapping => "name-mapping"
        },
        "xad_domain_admin" => { :abort => :abort, :next => "ntp" },
        "new_tree"         => {
          :abort => :abort,
          :xad   => "xad_domain_name",
          :next  => "ports"
        },
        "existing_tree"    => {
          :abort => :abort,
          :later => :next,
          :xad   => "xad_domain_name",
          :next  => "ports"
        },
        "parent_domain"    => { :abort => :abort, :next => "ntp" },
        "name-mapping"     => { :abort => :abort, :next => "ntp" },
        "ports"            => {
          :abort => :abort,
          :xad   => "slp",
          :next  => "ntp",
          :edir  => "nmas"
        },
        "ntp"              => {
          :abort => :abort,
          :xad   => "ports",
          :next  => "slp",
          :edir  => "new_or_existing"
        },
        "slp"              => {
          :abort => :abort,
          :next  => "nmas",
          :edir  => "ntp"
        },
        "nmas"             => { :abort => :abort, :next => "proxy_user" },
        "proxy_user"       => {
          :abort  => :abort,
          :next   => :next,
          :local  => "xad_dns",
          :remote => "xad_dns_remote"
        }
      }

      Wizard.CreateDialog
      Wizard.SetDesktopIcon("edirectory")

      ret = Sequencer.Run(aliases, sequence)

      UI.CloseDialog
      deep_copy(ret)
    end

    # This is the sequence for upgrading eDirectory
    # @return sequence result
    def EdirectoryUpgradeSequence
      aliases = { "upgrade" => lambda { UpgradeServerDialog() }, "nmas" => lambda(
      ) do
        NMASOptionsDialog()
      end }
      sequence = {
        "ws_start" => "upgrade",
        "upgrade"  => { :abort => :abort, :next => "nmas" },
        "nmas"     => { :abort => :abort, :next => :next, :xad => :next }
      }
      Wizard.CreateDialog
      Wizard.SetDesktopIcon("edirectory")

      ret = Sequencer.Run(aliases, sequence)

      UI.CloseDialog
      deep_copy(ret)
    end

    # Complete Sequence for Edirectory
    # @return sequence result
    def EdirectoryCompleteSequence
      aliases = {
        "read"    => [lambda { ReadDialog() }, true],
        "main"    => lambda { EdirectorySequence() },
        "upgrade" => lambda { EdirectoryUpgradeSequence() },
        "write"   => lambda { WriteDialog() }
      }

      sequence = {
        "ws_start" => "read",
        "read"     => {
          :abort   => :abort,
          :upgrade => "upgrade",
          :next    => "main"
        },
        "main"     => { :abort => :abort, :next => "write" },
        "upgrade"  => { :abort => :abort, :next => "write" },
        "write"    => {
          :abort    => :abort,
          :again    => "main",
          :again_up => "upgrade",
          :next     => :next
        }
      }

      Wizard.CreateDialog
      Wizard.SetDesktopIcon("edirectory")

      ret = Sequencer.Run(aliases, sequence)

      UI.CloseDialog
      deep_copy(ret)
    end

    # LDAPSequence()
    #
    # This is the sequence for acquiring the
    # default LDAP information for a service
    #

    def LDAPSequence
      aliases = { "ldap_servers" => WFM.call("oes-ldap") }

      sequence = {
        "ws_start"     => "ldap_servers",
        "ldap_servers" => { :abort => :abort, :next => :next }
      }

      Sequencer.Run(aliases, sequence)
    end

    # Whole configuration of LDAP defaults
    # @return sequence result
    def LDAPCompleteSequence
      aliases =
        #        "write"          : ``(WriteDialog()) // FIXME: why is this commented out???
        { "read" => lambda { ReadDialog() }, "main" => lambda { LDAPSequence() } }

      sequence = {
        "ws_start" => "main",
        "main"     => { :abort => :abort, :next => :next }
      }

      Wizard.CreateDialog
      Wizard.SetDesktopIcon("edirectory")

      ret = Sequencer.Run(aliases, sequence)

      UI.CloseDialog
      deep_copy(ret)
    end

    # Whole configuration of eDirectory but without reading and writing.
    # For use with autoinstallation and other modes.
    # @return sequence result
    def EdirectoryAutoSequence
      # Initialization dialog caption
      caption = _("eDirectory Configuration")
      # Initialization dialog contents
      contents = Label(_("Initializing..."))

      Wizard.CreateDialog
      Wizard.SetDesktopIcon("edirectory")
      Wizard.SetContentsButtons(
        caption,
        contents,
        "",
        Label.BackButton,
        Label.NextButton
      )

      ret = EdirectorySequence()

      UI.CloseDialog
      deep_copy(ret)
    end

    # Whole configuration of eDirectory but without reading and writing.
    # For use with upgrades from OES 1.0 to OES 2.0.
    # @return sequence result
    def EdirectoryAutoUpgradeSequence
      # Initialization dialog caption
      caption = _("eDirectory Upgrade Configuration")
      # Initialization dialog contents
      contents = Label(_("Initializing..."))

      Wizard.CreateDialog
      Wizard.SetDesktopIcon("edirectory")
      Wizard.SetContentsButtons(
        caption,
        contents,
        "",
        Label.BackButton,
        Label.NextButton
      )

      ret = EdirectoryUpgradeSequence()

      UI.CloseDialog
      deep_copy(ret)
    end
  end
end
