# encoding: utf-8

# -------------------------------------------------------------------------------
# (C) Copyright 2019 - 2022 Micro Focus or one of its affiliates.
#
# The only warranties for products and services of Micro Focus and its affiliates
# and licensors (“Micro Focus”) are as may be set forth in the express warranty
# statements accompanying such products and services. Nothing herein should be
# construed as constituting an additional warranty. Micro Focus shall not be
# liable for technical or editorial errors or omissions contained herein. The
# information contained herein is subject to change without notice.
#
# Except as specifically indicated otherwise, this document contains confidential
# information and a valid license is required for possession, use or copying. If
# this work is provided to the U.S. Government, consistent with FAR 12.211 and
# 12.212, Commercial Computer Software, Computer Software Documentation, and
# Technical Data for Commercial Items  are licensed to the U.S. Government under
# vendor's standard commercial license.
# -------------------------------------------------------------------------------

# File:	include/novell-edirectory/dialogs.ycp
# Package:	Configuration of edirectory
# Summary:	Dialogs definitions
#
# $Id: dialogs.ycp,v 1.1.2.69 2005/10/28 23:08:51 rhaslam Exp $
module Yast
  module NovellEdirectoryDialogsInclude
    def initialize_novell_edirectory_dialogs(include_target)
      Yast.import "UI"

      textdomain "novell-edirectory"

      Yast.import "EdirUtils"
      Yast.import "NovellUtils"
      Yast.import "NovellValidators"
      Yast.import "Edirectory"
      Yast.import "NovellLDAP"
      Yast.import "NovellLDAPUI"
      Yast.import "NovellLdapBrowser"
      Yast.import "Mode"
      Yast.import "Stage"
      Yast.import "Service"
      Yast.import "Label"
      Yast.import "Wizard"
      Yast.import "IP"
      Yast.import "Package"
      Yast.import "Popup"
      Yast.import "Report"
      Yast.import "ProductControl"
      Yast.import "Progress"
      Yast.import "Hostname"
      Yast.import "FileUtils"
      Yast.import "Address"

      Yast.include include_target, "novell-edirectory/helps.rb"
      Yast.include include_target, "novell-edirectory/complex.rb"
    end

    # NewOrExistingDialog
    #
    # @return dialog result
    def NewOrExistingDialog
      Builtins.y2milestone("Entering Edirectory NewOrExistingDialog()")

      # Establish a default setting for TREE TYPE
      tree_type = Ops.get_string(
        Edirectory.EdirSettings,
        "CONFIG_EDIR_TREE_TYPE",
        ""
      )
      if tree_type != "new" && tree_type != "existing"
        tree_type = Edirectory.ProposeTreeType
      end

      tree_name = Ops.get_string(
        NovellLDAP.Settings,
        "CONFIG_LDAP_TREE_NAME",
        ""
      )
      tree_name = Builtins.toupper(tree_name)
      tt = tree_type == "new" ? :new : :existing

      overwriteCerts = Ops.get_string(
        Edirectory.EdirSettings,
        "CONFIG_EDIR_OVERWRITE_CERT_FILES",
        ""
      )
      overwriteCerts = "yes" if overwriteCerts == nil || overwriteCerts == ""

      overwrite_certs = true # always true by default but can be deselected.
      overwrite_certs = false if Builtins.tolower(overwriteCerts) == "no"

      tlsForSimpleBinds = Ops.get_string(
        Edirectory.EdirSettings,
        "CONFIG_EDIR_TLS_FOR_SIMPLE_BINDS",
        "yes"
      )
      if tlsForSimpleBinds == nil || tlsForSimpleBinds == ""
        tlsForSimpleBinds = "yes"
      end

      tls_binds = true
      tls_binds = false if Builtins.tolower(tlsForSimpleBinds) == "no"

      configureSecretStore = Ops.get_string(
        Edirectory.EdirSettings,
        "CONFIG_EDIR_CONFIGURE_SECRETSTORE",
        "yes"
      )
      dosecretstore = true
      dosecretstore = false if Builtins.tolower(configureSecretStore) == "no"

      universal = true
      universalStore = Ops.get_string(
        Edirectory.EdirSettings,
        "CONFIG_EDIR_CONFIGURE_UNIVERSALSTORE",
        "yes"
      )
      universal = false  if Builtins.tolower(universalStore) == "no"

      # If Express install selected

      if NovellUtils.edir_quick_install
        # Edirectory configure1 dialog caption
        caption = _("Express Installation")
        ret = nil
        serverContext = Ops.get_string(
          Edirectory.EdirSettings,
          "CONFIG_EDIR_SERVER_CONTEXT",
          ""
        )
        adminName = Ops.get_string(
          NovellLDAP.Settings,
          "CONFIG_LDAP_ADMIN_CONTEXT",
          ""
        )
        adminPassword = Ops.get_string(
          NovellLDAP.Settings,
          "CONFIG_LDAP_ADMIN_PASSWORD",
          ""
        )
        adminPassword2 = adminPassword
        serverContextPrompt = _("Enter Server &Context")
        doServerContextValidation = true
        backServerContext = Ops.get_string(
          Edirectory.EdirSettings,
          "BACK_CONFIG_EDIR_SERVER_CONTEXT",
          ""
        )
        serverStr = _(
          "&IP Address / Hostname of an existing eDirectory server with a replica"
        )
        replica_address = Ops.get_string(
          Edirectory.EdirSettings,
          "CONFIG_EDIR_REPLICA_SERVER",
          ""
        )
        server_list = Ops.get_list(
          NovellLDAP.Settings,
          "CONFIG_LDAP_SERVERS_LIST",
          []
        )
        replica_server = NovellLDAP.GetAddressServer(
          replica_address,
          server_list
        )
        port = Ops.get_integer(replica_server, "CONFIG_LDAP_PORT", 389)
        port = 389 if port == nil || Ops.less_or_equal(port, 0)
        secure_port = Ops.get_integer(
          replica_server,
          "CONFIG_LDAP_SECURE_PORT",
          636
        )
        if secure_port == nil || Ops.less_or_equal(secure_port, 0)
          secure_port = 636
        end
        ncpport = Builtins.tointeger(
          Ops.get_integer(
            Edirectory.EdirSettings,
            "CONFIG_EDIR_EXISTING_NCP_PORT",
            524
          )
        )
        ncpport = 524 if ncpport == nil || Ops.less_or_equal(ncpport, 0)
        backServerContext = "" if backServerContext == nil

        serverContext = backServerContext if backServerContext != ""

        # IP or DNS of a Valid NTP time server
        timeserver_list = Ops.get_list(
          Edirectory.EdirSettings,
          "CONFIG_EDIR_NTP_SERVERS",
          []
        )
        timeserver = Ops.get(timeserver_list, 0, "")
        slpserver_list = Ops.get_list(
          Edirectory.EdirSettings,
          "CONFIG_EDIR_SLP_DA",
          []
        )
        slpserver = Ops.get(slpserver_list, 0, "")

        slpScopes = Ops.get_string(
          Edirectory.EdirSettings,
          "CONFIG_EDIR_SLP_SCOPES",
          "DEFAULT"
        )

        dibLocation = Ops.get_string(
         Edirectory.EdirSettings,
         "CONFIG_EDIR_DIB_LOCATION",
         "/var/opt/novell/eDirectory/data/dib"
        )

        Builtins.y2milestone("Starting values %1, %2", tt, tree_name)
        contents = HVSquash(
          VBox(
            HBox(
              TextEntry(
                Id(:slpserver),
                Opt(:notify),
                _("&SLP Server"),
                slpserver
              ),
              TextEntry(
                Id(:slpScopes),
                Opt(:notify),
                _("&SLP Scopes"),
                slpScopes
              )
            ),
            TextEntry(
              Id(:timeserver),
              Opt(:notify),
              _("&NTP Time Server"),
              timeserver
            ),
            Left(Label(_("New or Existing Tree"))),
            RadioButtonGroup(
              Id(:mode),
              Opt(:notify),
              HBox(
                HSpacing(2),
                Left(
                  RadioButton(
                    Id(:new),
                    Opt(:notify),
                    _("N&ew Tree"),
                    tt == :new
                  )
                ),
                Left(
                  RadioButton(
                    Id(:existing),
                    Opt(:notify),
                    _("E&xisting Tree"),
                    tt == :existing
                  )
                ),
                HSpacing(4),
              )
            ),
            TextEntry(Id(:tree_name), _("eDirectory &Tree Name"), tree_name),
            HBox(
              TextEntry(Id(:replica_address), serverStr, replica_address),
              VBox(Label(""), PushButton(Id(:test), _("&Validate")))
            ),
            TextEntry(
              Id(:adminName),
              Opt(:notify),
              _("&FDN of the tree administrator (e.g. cn=admin,o=microfocus)"),
              adminName
            ),
            HBox(
              Left(Password(Id(:pw1), _("Admin &Password"), adminPassword)),
              Left(
                Password(Id(:pw2), _("&Verify Admin Password"), adminPassword2)
              )
            ),
            HBox(
              TextEntry(Id(:serverContext), serverContextPrompt, serverContext),
              VBox(Label(""), PushButton(Id(:browse), _("Browse")))
            ),
            TextEntry(
              Id(:dibLoc),
              _("&Directory Information Base (DIB) Location"),
              dibLocation
            )
          )
        )

        Wizard.SetContentsButtons(
          caption,
          contents,
          Ops.get_string(@HELPS, "express_install", ""),
          Label.BackButton,
          Label.NextButton
        )
        if tree_type == "existing"
          UI.ChangeWidget(Id(:replica_address), :Enabled, true)
          UI.ChangeWidget(Id(:replica_address), :value, replica_address)
          UI.ChangeWidget(Id(:pw2), :Enabled, false)
          UI.ChangeWidget(Id(:browse), :Enabled, true)
          UI.ChangeWidget(Id(:test), :Enabled, true)
        elsif tree_type == "new"
          UI.ChangeWidget(Id(:replica_address), :Enabled, false)
          UI.ChangeWidget(Id(:pw2), :Enabled, true)
          UI.ChangeWidget(Id(:browse), :Enabled, false)
          UI.ChangeWidget(Id(:test), :Enabled, false)
        end
        slpserver = Convert.to_string(UI.QueryWidget(Id(:slpserver), :Value))
        if slpserver == ""
          UI.ChangeWidget(Id(:slpScopes), :Enabled, false)
        else
          UI.ChangeWidget(Id(:slpScopes), :Enabled, true)
          UI.ChangeWidget(Id(:slpScopes), :value, slpScopes)
        end

        if Edirectory.retryInProgress
          UI.ChangeWidget(Id(:back), :Enabled, false)
        end
        UI.SetFocus(Id(:timeserver))
        ret = nil
        while true
          ret = UI.UserInput
          # read the data
          tt = Convert.to_symbol(UI.QueryWidget(Id(:mode), :CurrentButton))
          tree_name = Convert.to_string(UI.QueryWidget(Id(:tree_name), :Value))
          tree_name = Builtins.toupper(tree_name)
          adminName = Convert.to_string(UI.QueryWidget(Id(:adminName), :Value))
          adminPassword = Convert.to_string(UI.QueryWidget(Id(:pw1), :Value))
          timeserver = Convert.to_string(
            UI.QueryWidget(Id(:timeserver), :Value)
          )
          if ret == :adminName
            if serverContext == nil || serverContext == ""
              adminName2 = Ops.get_string(
                NovellLDAP.Settings,
                "CONFIG_LDAP_ADMIN_CONTEXT",
                ""
              )
              if adminName2 == "" || adminName2 == nil
                adminName2 = Convert.to_string(
                  UI.QueryWidget(Id(:adminName), :Value)
                )
              end
              tmp = NovellUtils.GetContextNDS(adminName2)
              UI.ChangeWidget(Id(:serverContext), :Value, tmp)
            end
          elsif ret == :abort || ret == :cancel
            if ReallyAbort()
              break
            else
              next
            end
          elsif ret == :existing
            UI.ChangeWidget(Id(:replica_address), :Enabled, true)
            UI.ChangeWidget(Id(:pw2), :Enabled, false)
            UI.ChangeWidget(Id(:browse), :Enabled, true)
            UI.ChangeWidget(Id(:test), :Enabled, true)
          elsif ret == :new
            UI.ChangeWidget(Id(:replica_address), :Enabled, false)
            UI.ChangeWidget(Id(:pw2), :Enabled, true)
            UI.ChangeWidget(Id(:browse), :Enabled, false)
            UI.ChangeWidget(Id(:test), :Enabled, false)
          elsif ret == :new || ret == :existing
            next
          elsif ret == :slpserver
            slpserver = Convert.to_string(
              UI.QueryWidget(Id(:slpserver), :Value)
            )
            slpScopes = Convert.to_string(
              UI.QueryWidget(Id(:slpScopes), :Value)
            )
            if slpserver == "" || slpserver == nil
              UI.ChangeWidget(Id(:slpScopes), :value, slpScopes)
              UI.ChangeWidget(Id(:slpScopes), :Enabled, false)
            else
              UI.ChangeWidget(Id(:slpScopes), :Enabled, true)
              UI.ChangeWidget(Id(:slpScopes), :value, slpScopes)
            end
          elsif ret == :next
            #SLP Server validation
            slpserver = Convert.to_string(
              UI.QueryWidget(Id(:slpserver), :Value)
            )
            slpScopes = Convert.to_string(
              UI.QueryWidget(Id(:slpScopes), :Value)
            )
            if slpserver == "" || slpserver == nil
              goon = Popup.YesNoHeadline(
                _("SLP Configuration"),
                _(
                  "For multicast to function properly, you must adjust the firewall.\nDo you want to keep this option?"
                )
              )
              if !goon
                UI.SetFocus(Id(:slpserver))
                next
              else
                Ops.set(
                  Edirectory.EdirSettings,
                  "CONFIG_EDIR_SLP_MODE",
                  "multicast"
                )
              end
            elsif !NovellValidators.ValidateDNSorIP(slpserver)
              # The validator has its own error message
              next
            else
              slpDA = []
              slpDA = Builtins.add(slpDA, slpserver)
              # Validation complete save data

              Ops.set(Edirectory.EdirSettings, "CONFIG_EDIR_SLP_MODE", "da")
              Ops.set(Edirectory.EdirSettings, "CONFIG_EDIR_SLP_DA", slpDA)
              Ops.set(
                Edirectory.EdirSettings,
                "CONFIG_EDIR_SLP_SCOPES",
                slpScopes
              )
              stepOK = Edirectory.ConfigureAndStartSLP
              if !stepOK
                err = _("Error configuring and starting SLP")
                Report.Error(err)
              end
            end

            #NTP Server Validation

            timeserver = Convert.to_string(
              UI.QueryWidget(Id(:timeserver), :Value)
            )
            if timeserver == "" || timeserver == nil
              Report.Error(
                Builtins.sformat(_("NTP Time Server cannot be empty"))
              )
              UI.SetFocus(Id(:timeserver))
              next
            end
            if !NovellValidators.ValidateDNSorIP(timeserver)
              # The validator has its own error message
              next
            end

            timeServers = []
            timeServers = Builtins.add(timeServers, timeserver)
            Ops.set(
              Edirectory.EdirSettings,
              "CONFIG_EDIR_NTP_SERVERS",
              timeServers
            )


            # Check the Tree name
            if !NovellValidators.ValidateTreeName(tree_name)
              UI.SetFocus(Id(:tree_name))
              next
            end
            # Check for existing tree with same name
            if tt == :new
              if Edirectory.autoyast_tool == false
                if Edirectory.xadTestMode == false
                  if Edirectory.DoesEdirectoryTreeExist(tree_name)
                    Report.Error(
                      Builtins.sformat(
                        _("The tree %1 already exists."),
                        tree_name
                      )
                    )
                    next
                  end
                end
              end

              server_list2 = Ops.get_list(
                NovellLDAP.Settings,
                "CONFIG_LDAP_SERVERS_LIST",
                []
              )
              if NovellLDAP.RemoteAddressExists(server_list2)
                remote_servers = NovellLDAP.GetRemoteServers(server_list2)
                remote_addresses = NovellLDAP.GetAddresses(remote_servers)
                removeRemoteText = _(
                  "You have selected to create a new eDirectory tree."
                ) + "\n" +
                  _(
                    "The following remote server(s) will be removed from the LDAP server list:"
                  ) + "\n\n"
                Builtins.foreach(remote_servers) do |server_info|
                  removeRemoteText = Ops.add(
                    removeRemoteText,
                    Ops.get_string(server_info, "CONFIG_LDAP_SERVER_IP", "")
                  )
                end
                if Popup.ContinueCancel(removeRemoteText)
                  # FIXME - Don't actually remove the addresses here, just queue them for removal
                  server_list2 = NovellLDAP.RemoveServersByAddress(
                    remote_addresses,
                    server_list2
                  )
                  Builtins.y2milestone("Servers in list: %1", server_list2)
                else
                  next
                end
              end
              Ops.set(
                NovellLDAP.Settings,
                "CONFIG_LDAP_SERVERS_LIST",
                server_list2
              )
            end


            # Save Data to MAP

            Ops.set(
              Edirectory.EdirSettings,
              "CONFIG_EDIR_TREE_TYPE",
              tt == :existing ? "existing" : "new"
            )
            Ops.set(NovellLDAP.Settings, "CONFIG_LDAP_TREE_NAME", tree_name)

            if Convert.to_boolean(
                UI.QueryWidget(Id(:replica_address), :Enabled)
              )
              replica_address = Convert.to_string(
                UI.QueryWidget(Id(:replica_address), :Value)
              )
              if replica_address == "" || replica_address == ""
                Report.Error(
                  Builtins.sformat(_("Replica Server address cannot be empty"))
                )
                UI.SetFocus(Id(:replica_address))
                next
              end

              # Check IP address / Hostname
              if !Address.Check4(replica_address)
                if replica_address != ""
                  Popup.Error(Address.Valid4)
                  UI.SetFocus(Id(:replica_address))
                  next
                else
                  Popup.Error(
                    _(
                      "Enter the IP address / hostname of an existing server in the tree."
                    )
                  )
                  UI.SetFocus(Id(:replica_address))
                  next
                end
              else
                local_addresses = Convert.convert(
                  NovellUtils.GetAllStaticIPAddrs,
                  :from => "list",
                  :to   => "list <string>"
                )
                found = 0
                found = 1 if Builtins.contains(local_addresses, replica_address)
                if replica_address == NovellUtils.GetHostname ||
                    replica_address == NovellUtils.GetDNSname
                  found = 1
                end
                if found == 1
                  Report.Error(
                    _(
                      "The replica server IP address / hostname must be a remote (non-local) address."
                    )
                  )
                  replica_address = ""
                  UI.ChangeWidget(Id(:replica_address), :Value, replica_address)
                  UI.SetFocus(Id(:replica_address))
                  next
                end
              end
              if !NovellUtils.Ping_IP(replica_address)
                erMsg = Builtins.sformat(
                  _(
                    "The specified IP address / hostname (%1) is either not reachable or unresolvable.\nDo you want to continue anyway?"
                  ),
                  replica_address
                )

                next if Popup.ContinueCancel(erMsg) == false
              end

              Ops.set(
                Edirectory.EdirSettings,
                "CONFIG_EDIR_REPLICA_SERVER",
                replica_address
              )
            end

            # adminname validation

            if EdirUtils.isLDAPdn(adminName)
              adminName = NovellUtils.Ldap2Nds(adminName)
            end

            if !NovellValidators.ValidateFDN(adminName, false)
              Report.Error(Builtins.sformat(_("Admin Context cannot be empty")))
              UI.SetFocus(Id(:adminName))
              next
            end

            # Save the data

            Ops.set(NovellLDAP.Settings, "CONFIG_LDAP_ADMIN_CONTEXT", adminName)
            pw1 = adminPassword
            pw2 = Convert.to_string(UI.QueryWidget(Id(:pw2), :Value))
            if tt == :new
              if !NovellValidators.ValidatePasswords(pw1, pw2)
                UI.ChangeWidget(Id(:pw1), :Value, "")
                UI.ChangeWidget(Id(:pw2), :Value, "")
                UI.SetFocus(Id(:pw1))
                next
              end
            end

            if tt == :existing
              if !NovellValidators.ValidatePasswords(pw1, pw1)
                UI.ChangeWidget(Id(:pw1), :Value, "")
                UI.SetFocus(Id(:pw1))
                next
              end
            end

            Ops.set(
              NovellLDAP.Settings,
              "CONFIG_LDAP_ADMIN_PASSWORD",
              adminPassword
            )
            if tt == :existing
              # Validate that the existing server is part of the expected tree

              if Edirectory.autoyast_tool == false
                givenTreeName = Builtins.toupper(
                  Ops.get_string(
                    NovellLDAP.Settings,
                    "CONFIG_LDAP_TREE_NAME",
                    ""
                  )
                )
                foundTree = Edirectory.GetTreeName(replica_address, ncpport)
                foundTree = Builtins.substring(
                  foundTree,
                  0,
                  Ops.subtract(Builtins.size(foundTree), 1)
                )
                if foundTree != givenTreeName
                  goon = Popup.AnyQuestion(
                    _("Tree names do not match"),
                    Builtins.sformat(
                      _(
                        "At the address specified the \"%1\" tree responded.\nThe name of the tree that you requested to join is: %2"
                      ),
                      foundTree,
                      givenTreeName
                    ),
                    _("Continue"),
                    _("Cancel"),
                    :focus_no
                  )

                  next if !goon
                end

                # Validate the credentails against the Existing Tree

                if Edirectory.xadTestMode == false
                  val = NovellValidators.ValidateCredentials(
                    adminName,
                    adminPassword,
                    replica_address,
                    secure_port,
                    true
                  )
                  if val != 0
                    Builtins.y2milestone(
                      "ValidateCredentials() returned %1",
                      val
                    )
                    if val == -666
                      err = _(
                        "The attempt to perform a secure LDAP bind did not respond in 2 minutes\n" +
                          "This may indicate a problem with LDAP on the target server.\n" +
                          "If you are confident that your credentials are correct you may continue,\n" +
                          "otherwise please determine if LDAP is running correctly on the target system\n" +
                          "Do you want to continue?"
                      )
                      yes = Popup.YesNoHeadline(
                        _("LDAP secure bind timeout"),
                        err
                      )
                      next if !yes
                    else
                      err = Builtins.sformat(
                        _(
                          "User credentials failed to validate Using:\n" +
                            "      Server: %1\n" +
                            "      User: %2\n" +
                            "      LDAP port: %3\n" +
                            "Do you want to continue anyway?"
                        ),
                        replica_address,
                        adminName,
                        secure_port
                      )
                      yes = Popup.YesNoHeadline(_("Credentials Failed"), err)
                      next if !yes
                    end
                  end

                  cmd = Builtins.sformat(
                    "ldapsearch  -H ldaps://%1:%2 -D '%3' -w '%4' -s base -b '%5'",
                    replica_address,
                    secure_port,
                    NovellUtils.Nds2Ldap(adminName),
                    adminPassword,
                    NovellUtils.Nds2Ldap(NovellUtils.GetContextNDS(adminName))
                  )
                  rmap = Convert.to_map(
                    SCR.Execute(path(".target.bash_output"), cmd)
                  )

                  if Ops.get_integer(rmap, "exit", -1) != 0
                    msg = Builtins.sformat(
                      _(
                        "The specified IP address / hostname (%1) is not reachable, unresolvable or\nthe hostname is not part of the server certificate."
                      ),
                      replica_address
                    )
                    next if Popup.ContinueCancel(msg) == false
                  end
                end
              end
              server_list = NovellLDAP.RemoveServersByAddress(
                [Ops.get_string(replica_server, "CONFIG_LDAP_SERVER_IP", "")],
                server_list
              )
              replica_server = {
                "CONFIG_LDAP_SERVER_IP"   => replica_address,
                "CONFIG_LDAP_PORT"        => port,
                "CONFIG_LDAP_SECURE_PORT" => secure_port
              }

              server_list = Builtins.add(server_list, replica_server)
              Ops.set(
                NovellLDAP.Settings,
                "CONFIG_LDAP_ADMIN_CONTEXT",
                adminName
              )
              Ops.set(
                NovellLDAP.Settings,
                "CONFIG_LDAP_ADMIN_PASSWORD",
                adminPassword
              )
              Ops.set(
                NovellLDAP.Settings,
                "CONFIG_LDAP_SERVERS_LIST",
                server_list
              )
            end

            # Server Context validation

            serverContext = Convert.to_string(
              UI.QueryWidget(Id(:serverContext), :Value)
            )
            if doServerContextValidation
              if EdirUtils.isLDAPdn(serverContext)
                serverContext = NovellUtils.Ldap2Nds(serverContext)
              end
              if !NovellValidators.ValidateContext(serverContext)
                UI.SetFocus(Id(:serverContext))
                next
              end
            end
            Ops.set(
              Edirectory.EdirSettings,
              "CONFIG_EDIR_SERVER_CONTEXT",
              serverContext
            )
            Ops.set(
              NovellLDAP.Settings,
              "CONFIG_COMMON_PROXY_CONTEXT",
              serverContext
            )

	    # dib location validation
            dibLocation = Convert.to_string(UI.QueryWidget(Id(:dibLoc), :Value))
            next if !NovellValidators.ValidatePathname(dibLocation, true)
            if dibLocation == ""
              Popup.Error(_("The DIB location field cannot be empty"))
              next
            end

            dib = dibLocation
            found=false
            begin
              if FileUtils.Exists(dib)
                cmd = "/usr/bin/stat \-f \-\-printf=\"%T\" "
                cmd = Ops.add(cmd,dib)
                val = Convert.to_map(SCR.Execute(path(".target.bash_output"), cmd))
                stdout = NovellUtils.CleanUpString(Ops.get_string(val, "stdout", ""))
                if stdout == "btrfs"
                  found=true
                  break
	        else
		  break
                end
              else
               cmd=Builtins.sformat("/usr/bin/dirname %1",dib)
               val = Convert.to_map(SCR.Execute(path(".target.bash_output"), cmd))
               dib = NovellUtils.CleanUpString(Ops.get_string(val, "stdout", ""))
              end
            end until dib == "/" &&  Builtins.size(dib) >= 1

            if found
            Popup.Error(_("eDirectory does not support Btrfs file system. Specify the\n
EXT4, EXT3, or XFS path in the Directory Information Base (DIB)\nLocation field.\n\nIf a new partition needs to be created, you must abort this\nconfiguration. If the default path needs to be modified,\nchange the path of the eDirectory DIB in the OES eDirectory\nConfiguration page."))
              next
            end

            dib = dibLocation
            ext = Builtins.regexpmatch(dib, "data/dib$")
	    if ext
	      num=0
	      while num < 2
                cmd=Builtins.sformat("/usr/bin/dirname %1",dib)
                val = Convert.to_map(SCR.Execute(path(".target.bash_output"), cmd))
                dib = NovellUtils.CleanUpString(Ops.get_string(val, "stdout", ""))
	        num = num +1	
	      end
            end
            if !FileUtils.Exists(dib)
              Popup.Error(Builtins.sformat(_("%1 directory does not exist"),dib))
              next
            end

            Ops.set(Edirectory.EdirSettings,"CONFIG_EDIR_DIB_LOCATION", dibLocation)
            if universal
              cmd = "grep  'export*NDSD_TRY_NMASLOGIN_FIRST.*=.*' /opt/novell/eDirectory/sbin/pre_ndsd_start > /dev/null"
              rval = Convert.to_integer(SCR.Execute(path(".target.bash"), cmd))
              if rval != 0
                cmd = "echo export NDSD_TRY_NMASLOGIN_FIRST=true >>  /opt/novell/eDirectory/sbin/pre_ndsd_start"
                rval2 = Convert.to_integer(
                  SCR.Execute(path(".target.bash"), cmd)
                )
                Builtins.y2milestone(
                  "Edirectory: executing cmd: %1  rval: %2",
                  cmd,
                  rval2
                )
                if rval2 != 0
                  Builtins.y2milestone(
                    "Failed to add 'NDSD_TRY_NMASLOGIN_FIRST=true' to /opt/novell/eDirectory/sbin/pre_ndsd_start file"
                  )
                end
              end
              Ops.set(
                Edirectory.EdirSettings,
                "CONFIG_EDIR_CONFIGURE_UNIVERSALSTORE",
                "yes"
              )
            end

            break
          elsif ret == :test
            replica_address2 = Convert.to_string(
              UI.QueryWidget(Id(:replica_address), :Value)
            )
            NovellUtils.ServerIseDirServer(replica_address2)
          elsif ret == :browse
            uName = Ops.get_string(
              NovellLDAP.Settings,
              "CONFIG_LDAP_ADMIN_CONTEXT",
              ""
            )
            uPassword = Ops.get_string(
              NovellLDAP.Settings,
              "CONFIG_LDAP_ADMIN_PASSWORD",
              ""
            )
            if Ops.get_string(
                Edirectory.EdirSettings,
                "XAD_SERVICE_CONFIGURED",
                "no"
              ) == "yes"
              uName = Ops.get_string(
                Edirectory.EdirSettings,
                "XAD_LDAP_ADMIN_CONTEXT",
                ""
              )
              uPassword = Ops.get_string(
                Edirectory.EdirSettings,
                "XAD_LDAP_ADMIN_PASSWORD",
                ""
              )
            end

            uName = Convert.to_string(UI.QueryWidget(Id(:adminName), :Value))
            uPassword = Convert.to_string(UI.QueryWidget(Id(:pw1), :Value))
            replica_address2 = Ops.get_string(
              Edirectory.EdirSettings,
              "CONFIG_EDIR_REPLICA_SERVER",
              ""
            )
            replica_address2 = Convert.to_string(
              UI.QueryWidget(Id(:replica_address), :Value)
            )
            server_list2 = Ops.get_list(
              NovellLDAP.Settings,
              "CONFIG_LDAP_SERVERS_LIST",
              []
            )
            replica_server2 = NovellLDAP.GetAddressServer(
              replica_address2,
              server_list2
            )
            port2 = Ops.get_integer(replica_server2, "CONFIG_LDAP_PORT", 389)
            port2 = 389 if port2 == nil || Ops.less_or_equal(port2, 0)

            secure_port2 = Ops.get_integer(
              replica_server2,
              "CONFIG_LDAP_SECURE_PORT",
              636
            )
            if secure_port2 == nil || Ops.less_or_equal(secure_port2, 0)
              secure_port2 = 636
            end

            uName = NovellUtils.Nds2Ldap(uName)
            wrkContainer = NovellLdapBrowser.LdapBrowser(
              replica_address2,
              secure_port2,
              true,
              uName,
              uPassword,
              "",
              "",
              _("Browse for container")
            )
            Builtins.y2milestone(
              Builtins.sformat(
                "Edirectory.dialogs: server context from browse is: '%1'",
                wrkContainer
              )
            )
            if wrkContainer != nil && wrkContainer != ""
              wrkContainer = NovellUtils.Nds2Ldap(wrkContainer)
              UI.ChangeWidget(Id(:serverContext), :Value, wrkContainer)
            end
          elsif ret == :back
            Edirectory.backButtonClicked = true
            Edirectory.quickInstallBackButtonClicked = true
            break
          else
            Builtins.y2error("unexpected retcode: %1", ret)
            next
          end
        end

        NovellUtils.edir_quick_install = false
        return deep_copy(ret)
      else
        Builtins.y2milestone("Starting values %1, %2", tt, tree_name)
        # Edirectory configure1 dialog caption
        caption = _("eDirectory Configuration - New or Existing Tree")
        contents = HVSquash(
          VBox(
            Left(Label(_("New or Existing Tree"))),
            RadioButtonGroup(
              Id(:mode),
              Opt(:notify),
              VBox(
                Left(
                  RadioButton(
                    Id(:new),
                    Opt(:notify),
                    _("N&ew Tree"),
                    tt == :new
                  )
                ),
                Left(
                  RadioButton(
                    Id(:existing),
                    Opt(:notify),
                    _("E&xisting Tree"),
                    tt == :existing
                  )
                )
              )
            ),
            VSpacing(1),
            TextEntry(Id(:tree_name), _("eDirectory &Tree Name"), tree_name),
            VBox(
              VSpacing(1),
              Left(
                CheckBox(
                  Id(:overwrite),
                  _("&Use eDirectory Certificates for HTTPS Services"),
                  overwrite_certs
                )
              )
            ),
            VBox(
              VSpacing(1),
              Left(
                CheckBox(
                  Id(:tlsbind),
                  _(" &Require TLS for Simple Binds with Password"),
                  tls_binds
                )
              )
            ),
            VBox(
              VSpacing(1),
              Left(
                CheckBox(
                  Id(:secretstore),
                  _(" &Install SecretStore"),
                  dosecretstore
                )
              )
            ),
            VBox(
              VSpacing(1),
              Left(
                CheckBox(
                  Id(:universal),
                  _(" Enable &NMAS-based login for LDAP authentication"),
                  universal
                )
              )
            )
          )
        )

        Wizard.SetContentsButtons(
          caption,
          contents,
          Ops.get_string(@HELPS, "new_or_existing", ""),
          Label.BackButton,
          Label.NextButton
        )
        if NovellUtils.IsLumNcsConfigured
          UI.ChangeWidget(Id(:new), :Enabled, false)
          UI.ChangeWidget(Id(:mode), :CurrentButton, :existing)
        end

        if Edirectory.retryInProgress
          UI.ChangeWidget(Id(:back), :Enabled, false)
        end

        UI.SetFocus(Id(:tree_name))

        ret = nil
        while true
          ret = UI.UserInput

          # read the data
          tt = Convert.to_symbol(UI.QueryWidget(Id(:mode), :CurrentButton))
          tree_name = Convert.to_string(UI.QueryWidget(Id(:tree_name), :Value))
          tree_name = Builtins.toupper(tree_name)

          if ret == :abort || ret == :cancel
            if ReallyAbort()
              break
            else
              next
            end
          elsif ret == :new || ret == :existing
            next
          elsif ret == :next
            # Check the data

            # Check the Tree name
            if !NovellValidators.ValidateTreeName(tree_name)
              UI.SetFocus(Id(:tree_name))
              next
            end
            overwrite_certs = Convert.to_boolean(
              UI.QueryWidget(Id(:overwrite), :Value)
            )
            if overwrite_certs
              Ops.set(
                Edirectory.EdirSettings,
                "CONFIG_EDIR_OVERWRITE_CERT_FILES",
                "yes"
              )
            else
              Ops.set(
                Edirectory.EdirSettings,
                "CONFIG_EDIR_OVERWRITE_CERT_FILES",
                "no"
              )
            end

            tls_binds = Convert.to_boolean(UI.QueryWidget(Id(:tlsbind), :Value))
            if tls_binds
              Ops.set(
                Edirectory.EdirSettings,
                "CONFIG_EDIR_TLS_FOR_SIMPLE_BINDS",
                "yes"
              )
            else
              Ops.set(
                Edirectory.EdirSettings,
                "CONFIG_EDIR_TLS_FOR_SIMPLE_BINDS",
                "no"
              )
            end

            dosecretstore = Convert.to_boolean(
              UI.QueryWidget(Id(:secretstore), :Value)
            )
            if dosecretstore
              Ops.set(
                Edirectory.EdirSettings,
                "CONFIG_EDIR_CONFIGURE_SECRETSTORE",
                "yes"
              )
            else
              Ops.set(
                Edirectory.EdirSettings,
                "CONFIG_EDIR_CONFIGURE_SECRETSTORE",
                "no"
              )
            end
            universal = Convert.to_boolean(
              UI.QueryWidget(Id(:universal), :Value)
            )
            if universal
              cmd = "grep  'export*NDSD_TRY_NMASLOGIN_FIRST.*=.*' /opt/novell/eDirectory/sbin/pre_ndsd_start > /dev/null"
              rval = Convert.to_integer(SCR.Execute(path(".target.bash"), cmd))
              if rval != 0
                cmd = "echo export NDSD_TRY_NMASLOGIN_FIRST=true >>  /opt/novell/eDirectory/sbin/pre_ndsd_start"
                rval2 = Convert.to_integer(
                  SCR.Execute(path(".target.bash"), cmd)
                )
                Builtins.y2milestone(
                  "Edirectory: executing cmd: %1  rval: %2",
                  cmd,
                  rval2
                )
                if rval2 != 0
                  Builtins.y2milestone(
                    "Failed to add 'NDSD_TRY_NMASLOGIN_FIRST=true' to /opt/novell/eDirectory/sbin/pre_ndsd_start file"
                  )
                end
              end
              Ops.set(
                Edirectory.EdirSettings,
                "CONFIG_EDIR_CONFIGURE_UNIVERSALSTORE",
                "yes"
              )
            else
              cmd = "grep  'export *NDSD_TRY_NMASLOGIN_FIRST*=*' /opt/novell/eDirectory/sbin/pre_ndsd_start > /dev/null"
              rval = Convert.to_integer(SCR.Execute(path(".target.bash"), cmd))
              if rval == 0
                cmd = "sed -i '/export *NDSD_TRY_NMASLOGIN_FIRST.*=.*/d' /opt/novell/eDirectory/sbin/pre_ndsd_start > /dev/null"
                rval2 = Convert.to_integer(
                  SCR.Execute(path(".target.bash"), cmd)
                )
                Builtins.y2milestone(
                  "Edirectory: executing cmd: %1  rval: %2",
                  cmd,
                  rval2
                )
                if rval2 != 0
                  Builtins.y2milestone(
                    "Failed to remove 'NDSD_TRY_NMASLOGIN_FIRST=true' from /opt/novell/eDirectory/sbin/pre_ndsd_start file"
                  )
                end
              end
              Ops.set(
                Edirectory.EdirSettings,
                "CONFIG_EDIR_CONFIGURE_UNIVERSALSTORE",
                "no"
              )
            end

            # Check for existing tree with same name
            if tt == :new
              if Edirectory.autoyast_tool == false
                if Edirectory.xadTestMode == false
                  if Edirectory.DoesEdirectoryTreeExist(tree_name)
                    Report.Error(
                      Builtins.sformat(
                        _("The tree %1 already exists."),
                        tree_name
                      )
                    )
                    next
                  end
                end
              end
              server_list = Ops.get_list(
                NovellLDAP.Settings,
                "CONFIG_LDAP_SERVERS_LIST",
                []
              )
              if NovellLDAP.RemoteAddressExists(server_list)
                remote_servers = NovellLDAP.GetRemoteServers(server_list)
                remote_addresses = NovellLDAP.GetAddresses(remote_servers)
                removeRemoteText = _(
                  "You have selected to create a new eDirectory tree."
                ) + "\n" +
                  _(
                    "The following remote server(s) will be removed from the LDAP server list:"
                  ) + "\n\n"
                Builtins.foreach(remote_servers) do |server_info|
                  removeRemoteText = Ops.add(
                    removeRemoteText,
                    Ops.get_string(server_info, "CONFIG_LDAP_SERVER_IP", "")
                  )
                end

                if Popup.ContinueCancel(removeRemoteText)
                  # FIXME - Don't actually remove the addresses here, just queue them for removal
                  server_list = NovellLDAP.RemoveServersByAddress(
                    remote_addresses,
                    server_list
                  )
                  Builtins.y2milestone("Servers in list: %1", server_list)
                else
                  next
                end
              end
              Ops.set(
                NovellLDAP.Settings,
                "CONFIG_LDAP_SERVERS_LIST",
                server_list
              )
            end

            # Save Data to MAP
            Ops.set(
              Edirectory.EdirSettings,
              "CONFIG_EDIR_TREE_TYPE",
              tt == :existing ? "existing" : "new"
            )
            Ops.set(NovellLDAP.Settings, "CONFIG_LDAP_TREE_NAME", tree_name)

            # IF new tree set EXISTING_IP to LOCAL_IP
            # Set the token correctly to select the next page.
            if tt == :new
              ret = :new
            else
              ret = :existing
            end

            if Ops.get_string(
                Edirectory.EdirSettings,
                "XAD_SERVICE_CONFIGURED",
                ""
              ) == "yes"
              if Ops.get_string(
                  Edirectory.EdirSettings,
                  "CONFIG_EDIR_TREE_TYPE",
                  ""
                ) == "new" &&
                  Ops.get_string(Edirectory.EdirSettings, "XAD_DOMAIN_TYPE", "") == "forest"
                Ops.set(NovellLDAP.Settings, "XAD_TREE_ADMIN_CONTEXT", "")
                Ops.set(NovellLDAP.Settings, "XAD_TREE_ADMIN_PASSWORD", "")
              end
            end

            break
          elsif ret == :back
            Edirectory.backButtonClicked = true # Tell the DoXadorEdirDialogs() that back was hit.
            break
          else
            Builtins.y2error("unexpected retcode: %1", ret)
            next
          end
        end
        NovellUtils.edir_quick_install = false
        return deep_copy(ret)
      end
    end
    # XadExistingDialog
    #
    # @return dialog result
    def XadExistingDialog
      Builtins.y2milestone("Entering Edirectory XadExistingDialog()")
      # Edirectory configure1 dialog caption
      caption = _("eDirectory Configuration - Existing Tree Information")

      # Establish a default setting for TREE TYPE
      tree_type = "existing"

      tree_name = Ops.get_string(
        NovellLDAP.Settings,
        "CONFIG_LDAP_TREE_NAME",
        ""
      )
      tree_name = Builtins.toupper(tree_name)

      if tree_name == nil || tree_name == ""
        domainType = "adc"
        if Ops.get_string(Edirectory.EdirSettings, "XAD_DOMAIN_TYPE", "") == "domain"
          domainType = "child"
        end
        tree_name = Edirectory.GetExistingTreeName(domainType)
      end

      overwriteCerts = Ops.get_string(
        Edirectory.EdirSettings,
        "CONFIG_EDIR_OVERWRITE_CERT_FILES",
        ""
      )
      overwriteCerts = "yes" if overwriteCerts == nil || overwriteCerts == ""

      overwrite_certs = true # always true by default but can be deselected.
      overwrite_certs = false if Builtins.tolower(overwriteCerts) == "no"

      tlsForSimpleBinds = Ops.get_string(
        Edirectory.EdirSettings,
        "CONFIG_EDIR_TLS_FOR_SIMPLE_BINDS",
        "yes"
      )

      if tlsForSimpleBinds == nil || tlsForSimpleBinds == ""
        tlsForSimpleBinds = "yes"
      end

      tls_binds = true
      tls_binds = false if Builtins.tolower(tlsForSimpleBinds) == "no"

      configureSecretStore = Ops.get_string(
        Edirectory.EdirSettings,
        "CONFIG_EDIR_CONFIGURE_SECRETSTORE",
        "yes"
      )
      dosecretstore = true
      dosecretstore = false if Builtins.tolower(configureSecretStore) == "no"

      universal = false
      universalStore = Ops.get_string(
        Edirectory.EdirSettings,
        "CONFIG_EDIR_CONFIGURE_UNIVERSALSTORE",
        "no"
      )
      universal = true if Builtins.tolower(universalStore) == "yes"

      Builtins.y2milestone("Starting values %1", tree_name)
      contents = HVSquash(
        VBox(
          TextEntry(
            Id(:tree_name),
            _("Existing eDirectory &Tree Name"),
            tree_name
          ),
          VBox(
            VSpacing(1),
            Left(
              CheckBox(
                Id(:overwrite),
                _("&Use eDirectory Certificates for HTTPS Services"),
                overwrite_certs
              )
            )
          ),
          VBox(
            VSpacing(1),
            Left(
              CheckBox(
                Id(:tlsbind),
                _(" &Require TLS for Simple Binds with Password"),
                tls_binds
              )
            )
          ),
          VBox(
            VSpacing(1),
            Left(
              CheckBox(
                Id(:secretstore),
                _(" &Install SecretStore"),
                dosecretstore
              )
            )
          ),
          VBox(
            VSpacing(1),
            Left(
              CheckBox(
                Id(:universal),
                _("Enable NMAS-based login for LDAP authentication"),
                universal
              )
            )
          )
        )
      )

      Wizard.SetContentsButtons(
        caption,
        contents,
        Ops.get_string(@HELPS, "xad_existing", ""),
        Label.BackButton,
        Label.NextButton
      )

      UI.ChangeWidget(Id(:back), :Enabled, false) if Edirectory.retryInProgress

      if tree_name == nil || tree_name == ""
        UI.SetFocus(Id(:tree_name))
        UI.ChangeWidget(Id(:tree_name), :Enabled, true)
      else
        UI.SetFocus(Id(:next))
        UI.ChangeWidget(Id(:tree_name), :Enabled, false)
      end

      ret = nil
      while true
        ret = UI.UserInput

        # read the data
        tree_name = Convert.to_string(UI.QueryWidget(Id(:tree_name), :Value))
        tree_name = Builtins.toupper(tree_name)

        if ret == :abort || ret == :cancel
          if ReallyAbort()
            break
          else
            next
          end
        elsif ret == :next
          # Check the data

          # Check the Tree name
          if !NovellValidators.ValidateTreeName(tree_name)
            UI.SetFocus(Id(:tree_name))
            next
          end
          overwrite_certs = Convert.to_boolean(
            UI.QueryWidget(Id(:overwrite), :Value)
          )
          if overwrite_certs
            Ops.set(
              Edirectory.EdirSettings,
              "CONFIG_EDIR_OVERWRITE_CERT_FILES",
              "yes"
            )
          else
            Ops.set(
              Edirectory.EdirSettings,
              "CONFIG_EDIR_OVERWRITE_CERT_FILES",
              "no"
            )
          end

          tls_binds = Convert.to_boolean(UI.QueryWidget(Id(:tlsbind), :Value))
          if tls_binds
            Ops.set(
              Edirectory.EdirSettings,
              "CONFIG_EDIR_TLS_FOR_SIMPLE_BINDS",
              "yes"
            )
          else
            Ops.set(
              Edirectory.EdirSettings,
              "CONFIG_EDIR_TLS_FOR_SIMPLE_BINDS",
              "no"
            )
          end

          dosecretstore = Convert.to_boolean(
            UI.QueryWidget(Id(:secretstore), :Value)
          )
          if dosecretstore
            Ops.set(
              Edirectory.EdirSettings,
              "CONFIG_EDIR_CONFIGURE_SECRETSTORE",
              "yes"
            )
          else
            Ops.set(
              Edirectory.EdirSettings,
              "CONFIG_EDIR_CONFIGURE_SECRETSTORE",
              "no"
            )
          end
          universal = Convert.to_boolean(UI.QueryWidget(Id(:universal), :Value))
          if universal
            cmd = "grep  'export*NDSD_TRY_NMASLOGIN_FIRST.*=.*' /opt/novell/eDirectory/sbin/pre_ndsd_start > /dev/null"
            rval = Convert.to_integer(SCR.Execute(path(".target.bash"), cmd))
            if rval != 0
              cmd = "echo export NDSD_TRY_NMASLOGIN_FIRST=true >>  /opt/novell/eDirectory/sbin/pre_ndsd_start"
              rval2 = Convert.to_integer(SCR.Execute(path(".target.bash"), cmd))
              Builtins.y2milestone(
                "Edirectory: executing cmd: %1  rval: %2",
                cmd,
                rval2
              )
              if rval2 != 0
                Builtins.y2milestone(
                  "Failed to add 'NDSD_TRY_NMASLOGIN_FIRST=true' to /opt/novell/eDirectory/sbin/pre_ndsd_start file"
                )
              end
            end
            Ops.set(
              Edirectory.EdirSettings,
              "CONFIG_EDIR_CONFIGURE_UNIVERSALSTORE",
              "yes"
            )
          else
            cmd = "grep  'export *NDSD_TRY_NMASLOGIN_FIRST*=*' /opt/novell/eDirectory/sbin/pre_ndsd_start > /dev/null"
            rval = Convert.to_integer(SCR.Execute(path(".target.bash"), cmd))
            if rval == 0
              cmd = "sed -i 's/export *NDSD_TRY_NMASLOGIN_FIRST.*=.*//' /opt/novell/eDirectory/sbin/pre_ndsd_start > /dev/null"
              rval2 = Convert.to_integer(SCR.Execute(path(".target.bash"), cmd))
              Builtins.y2milestone(
                "Edirectory: executing cmd: %1  rval: %2",
                cmd,
                rval2
              )
              if rval2 != 0
                Builtins.y2milestone(
                  "Failed to remove 'NDSD_TRY_NMASLOGIN_FIRST=true' from /opt/novell/eDirectory/sbin/pre_ndsd_start file"
                )
              end
            end
            Ops.set(
              Edirectory.EdirSettings,
              "CONFIG_EDIR_CONFIGURE_UNIVERSALSTORE",
              "no"
            )
          end

          # Save Data to MAP
          Ops.set(Edirectory.EdirSettings, "CONFIG_EDIR_TREE_TYPE", "existing")
          Ops.set(NovellLDAP.Settings, "CONFIG_LDAP_TREE_NAME", tree_name)

          break
        elsif ret == :back
          break
        else
          Builtins.y2error("unexpected retcode: %1", ret)
          next
        end
      end
      deep_copy(ret)
    end

    def CompareDomain(domain_name)
      # First get the machine Domain Name
      splitFQ = Hostname.SplitFQ(NovellUtils.GetDNSname)
      machineDomainName = Builtins.tolower(Ops.get(splitFQ, 1, ""))
      return machineDomainName if domain_name == nil || domain_name == ""
      domain_name = Builtins.tolower(domain_name)
      return machineDomainName if domain_name != machineDomainName

      nil
    end

    def DoXadorEdirDialogs
      ret = :edir

      if Edirectory.backButtonClicked
        Edirectory.backButtonClicked = false # reset for next pass
        return :back
      end

      Builtins.y2milestone(
        "edir.DoXadorEdirDialogs:xad_packages_installed: %1",
        Edirectory.xad_packages_installed
      )
      
      #1105182
      if Edirectory.xad_packages_installed
       if Edirectory.migration_pattern_installed
        ret = :edir
       else
        ret = :xad
        Ops.set(Edirectory.EdirSettings, "XAD_SERVICE_CONFIGURED", "yes")
       end
      end

      # For test pruposes
      if Edirectory.xadTestMode == true
        if Edirectory.doXadSequence == true
          ret = :xad
          Ops.set(Edirectory.EdirSettings, "XAD_SERVICE_CONFIGURED", "yes")
        else
          ret = :edir
          Ops.set(Edirectory.EdirSettings, "XAD_SERVICE_CONFIGURED", "no")
        end
      end

      ret
    end

    # Configuration options for "Domain Services for Windows" (XAD)
    #
    # @return dialog result
    def XadDomainChoiceDialog
      Builtins.y2milestone("Entering Edirectory XadDomainChoiceDialog()")
      recommendations = false
      recommendations = Ops.get_boolean(
        Edirectory.EdirSettings,
        "recommendations",
        false
      )
      # Edirectory XadDomainChoiceDialog dialog caption
      caption = _("Domain Services for Windows Configuration")

      # Establish a default setting for Domain Type
      domain_type = Ops.get_string(
        Edirectory.EdirSettings,
        "XAD_DOMAIN_TYPE",
        ""
      )
      quick_install = Ops.get_string(
        Edirectory.EdirSettings,
        "XAD_QUICK_INSTALL",
        "no"
      )
      if domain_type != "domain" && domain_type != "controller"
        domain_type = "forest"
      end
      domain_name = Ops.get_string(
        Edirectory.EdirSettings,
        "XAD_DOMAIN_NAME",
        ""
      )
      if domain_name == nil || domain_name == ""
        splitFQ = Hostname.SplitFQ(NovellUtils.GetDNSname)
        domain_name = Ops.get(splitFQ, 1, "")
      end
      domain_name = Builtins.tolower(domain_name)

      if Ops.get_string(Edirectory.EdirSettings, "CONFIG_EDIR_TREE_TYPE", "") == "new"
        domain_type = "forest"
      end

      tt = domain_type == "domain" ? :domain : :controller
      tt = domain_type == "forest" ? :forest : tt
      best_practise_link = "https://www.microfocus.com/documentation/open-enterprise-server/2023/dsfw_bp_lx/bookinfo.html"

      contents = HVSquash(
        VBox(
          VBox(
            Frame(
              _("Important"),
              MarginBox(
                1.5,
                0.2,
                VBox(
                  Left(
                    Label(
                      Builtins.sformat(
                      _(
                        "All Deployments\n" +
                          "    * You must properly prepare your system before installing Domain Services for Windows (DSfW).\n" +
                          "    * Be sure to read and comply with the DSfW Best Practices Guide available at\n" +
                          "      [ %1 ].\n" +
                          "\n" +
                          "Large Deployments\n" +
                          "    If your deployment has\n" +
                          "        * More than 3 Domain Controllers\n" +
                          "        or\n" +
                          "        * More than 2,000 active users\n" +
                          "    You should contact Novell Consulting Services or a qualified Novell Partner for deployment assistance.\n" +
                          "\n" +
                          "    Novell Support might require Novell Consulting or Novell Partner involvement before opening or\n" +
                          "    continuing with service requests."
                      ),best_practise_link)
                    )
                  ),
                  Left(
                    CheckBox(
                      Id(:recommendations),
                      Opt(:notify),
                      _(
                        "I have read these recommendations and reviewed the DSfW Best Practices Guide."
                      ),
                      recommendations
                    )
                  )
                )
              )
            )
          ),
          Left(Label(_("Select Server Type:"))),
          RadioButtonGroup(
            Id(:mode),
            Opt(:notify),
            VBox(
              Left(
                RadioButton(
                  Id(:forest),
                  Opt(:notify),
                  _("N&ew Domain Services for Windows Forest"),
                  tt == :forest
                )
              ),
              Left(
                RadioButton(
                  Id(:domain),
                  Opt(:notify),
                  _(
                    "New Domain in an &existing Domain Services for Windows Forest"
                  ),
                  tt == :domain
                )
              ),
              Left(
                RadioButton(
                  Id(:controller),
                  Opt(:notify),
                  _(
                    "New Domain &Controller in an existing Domain Services for Windows Domain"
                  ),
                  tt == :controller
                )
              )
            )
          ),
          VBox(
            VSpacing(1),
            Left(
              CheckBox(
                Id(:quick_install),
                Opt(:notify),
                _("&Express Install"),
                quick_install == "yes"
              )
            ),
            Left(Label(_("Recommended only for default configurations.")))
          )
        )
      )
      Wizard.SetContentsButtons(
        caption,
        contents,
        Ops.get_string(@HELPS, "eDir_conf_ndsw", ""),
        Label.BackButton,
        Label.NextButton
      )

      if domain_type == "controller"
        UI.ChangeWidget(Id(:controller), :Value, true)
      else
        if domain_type == "forest"
          UI.ChangeWidget(Id(:forest), :Value, true)
        else
          UI.ChangeWidget(Id(:domain), :Value, true)
        end
      end

      if !Ops.get_boolean(Edirectory.EdirSettings, "recommendations", false)
        Wizard.DisableNextButton
      end
      ret = nil
      while true
        ret = Convert.to_symbol(UI.UserInput)
        # read the data
        tt = Convert.to_symbol(UI.QueryWidget(Id(:mode), :CurrentButton))

        if ret == :back
          Edirectory.backButtonClicked = true # Tell the DoXadorEdirDialogs() that back was hit.
          Ops.set(Edirectory.EdirSettings, "recommendations", false)
          break
        elsif ret == :recommendations
          if Convert.to_boolean(UI.QueryWidget(Id(:recommendations), :Value))
            Ops.set(Edirectory.EdirSettings, "recommendations", true)
            Wizard.EnableNextButton
          else
            Wizard.DisableNextButton
          end
        elsif ret == :abort || ret == :cancel
          if ReallyAbort()
            break
          else
            next
          end
        elsif ret == :next
          domain_type2 = "forest"
          if tt == :domain
            domain_type2 = "domain"
          elsif tt == :controller
            domain_type2 = "controller"
          end

          replica_address = Ops.get_string(
            Edirectory.EdirSettings,
            "CONFIG_EDIR_REPLICA_SERVER",
            ""
          )

          Ops.set(Edirectory.EdirSettings, "XAD_DOMAIN_TYPE", domain_type2)

          if Convert.to_boolean(UI.QueryWidget(Id(:quick_install), :Value))
            quick_install = "yes"
          else
            quick_install = "no"
          end

          Ops.set(Edirectory.EdirSettings, "XAD_QUICK_INSTALL", quick_install)


          if domain_type2 == "controller"
            treeName = Ops.get_string(
              NovellLDAP.Settings,
              "CONFIG_LDAP_TREE_NAME",
              ""
            )
            # Validate that the Namerserver Entry is pointing to the right DNS server.
            cmd = Builtins.sformat(
              "TREE_NAME=%1 /opt/novell/xad/share/dcinit/provisionTools.sh validate-adc-nameserver-entry -d %2",
              treeName,
              domain_name
            )
            Builtins.y2milestone(
              "edirectory.ValidatingADCNameServerEntry:executing:%1",
              cmd
            )

            Popup.ShowFeedback(
              _("Validating Name Server Entry in resolv.conf"),
              _("This may take a while")
            )
            retmap = Convert.to_map(
              SCR.Execute(path(".target.bash_output"), cmd)
            )
            Popup.ClearFeedback
            if Ops.get_integer(retmap, "exit", -1) != 0
              errmsg = _(
                "Continuing with this entry:\n" +
                  "1) Will lead to the wrong context for DNS records of this server.\n" +
                  "2) All DC's in a domain MUST use the same context for their DNS records.\n" +
                  "\n"
              )
              goon = Popup.ContinueCancelHeadline(
                _("Name Server Entry is not pointing to the right DNS Server"),
                errmsg
              )
              next if !goon
            end

            # Validate the Nameserver Entry and make sure the existing domain is reachable.

            Popup.ShowFeedback(
              _("Locating the existing domain controller"),
              _("This might take a while")
            )
            cmd = Builtins.sformat(
              "/opt/novell/xad/sbin/provision -q -l 60 --locate-dc %1",
              domain_name
            )
            Builtins.y2milestone("Executing: %1", cmd)
            retmap = Convert.to_map(
              SCR.Execute(path(".target.bash_output"), cmd)
            )
            Popup.ClearFeedback
            Builtins.y2milestone("retmap = %1", retmap)
            if Ops.get_integer(retmap, "exit", -1) == 3
              Report.Error(
                _(
                  "Unable to locate the existing domain controller for the domain.\nVerify that all the services are running properly on all the domain controllers."
                )
              )
              next if !Edirectory.xadTestMode
            end
            if Ops.get_integer(retmap, "exit", -1) != 0
              errmsg = _(
                "Possible causes are:\n" +
                  "\n" +
                  "* DNS server is unreachable. \n" +
                  "* /etc/resolv.conf is not configured properly. \n" +
                  "* Firewall is not configured properly. \n" +
                  "* Domain does not exist. \n"
              )

              Report.Error(
                Builtins.sformat(
                  _("Unable to locate the existing domain controller. %1"),
                  errmsg
                )
              )
              next if !Edirectory.xadTestMode
            end
          end

          # Make sure the new domain name does not already exist.
          if domain_type2 == "domain"
            Popup.ShowFeedback(
              _("Locating the existing parent domain controller"),
              _("This might take a while")
            )
            cmd = Builtins.sformat(
              "/opt/novell/xad/sbin/provision -q --locate-dc %1",
              domain_name
            )
            Builtins.y2milestone("Executing: %1", cmd)
            retmap = Convert.to_map(
              SCR.Execute(path(".target.bash_output"), cmd)
            )
            Popup.ClearFeedback
            Builtins.y2milestone("retmap = %1", retmap)
            if Ops.get_integer(retmap, "exit", -1) == 0
              errmsg = Builtins.sformat(
                _("The domain %1 already exists."),
                domain_name
              )
              Popup.Error(errmsg)
              next if !Edirectory.xadTestMode
            end
            splitFQ = Hostname.SplitFQ(domain_name)
            parent_name = Ops.get(splitFQ, 1, "")
            Builtins.y2milestone("Got parent name: %1", parent_name)
            Popup.ShowFeedback(
              _("Locating the existing parent domain controller"),
              _("This might take a while")
            )
            cmd = Builtins.sformat(
              "/opt/novell/xad/sbin/provision -q -l 60 --locate-dc %1",
              parent_name
            )
            Builtins.y2milestone("Executing: %1", cmd)
            retmap = Convert.to_map(
              SCR.Execute(path(".target.bash_output"), cmd)
            )
            Popup.ClearFeedback
            Builtins.y2milestone("retmap = %1", retmap)
            if Ops.get_integer(retmap, "exit", -1) == 3
              Report.Error(
                _(
                  "Unable to locate the existing parent domain controller for the domain.\nVerify that all the services are running properly on all the parent domain controllers."
                )
              )
              next if !Edirectory.xadTestMode
            end
            if Ops.get_integer(retmap, "exit", -1) != 0
              errmsg = _(
                "Possible causes are:\n" +
                  "\n" +
                  "* DNS server is unreachable. \n" +
                  "* /etc/resolv.conf is not configured properly. \n" +
                  "* Firewall is not configured properly. \n" +
                  "* Parent domain does not exist. \n"
              )
              Report.Error(
                Builtins.sformat(
                  _(
                    "Unable to locate the existing parent domain controller. %1"
                  ),
                  errmsg
                )
              )
              next if !Edirectory.xadTestMode
            end
          end


          if Ops.get_string(Edirectory.EdirSettings, "XAD_DOMAIN_TYPE", "") == "domain" ||
              Ops.get_string(Edirectory.EdirSettings, "XAD_DOMAIN_TYPE", "") == "controller"
            ret = :xad
          end
          break
        elsif ret == :quick_install
          if Convert.to_boolean(UI.QueryWidget(Id(:quick_install), :Value))
            Report.Warning(
              _(
                "Express Install assigns default configuration parameters. Using express\n" +
                  "Install, you cannot customize configuration parameters for components\n" +
                  "such as DNS. To customize the configuration, you must deselect the\n" +
                  "'Express Install' option."
              )
            )
          end
        else
          Builtins.y2error("unexpected retcode: %1", ret)
          next
        end
      end

      ret
    end


    def GetForestRootDomain(replica_address, tree, admin, password, domain)
      Builtins.y2milestone(
        "edirectory.GetForestRootDomain:entering with ip %1, tree %2, admin %3, and domain %4",
        replica_address,
        tree,
        admin,
        domain
      )

      if replica_address == nil || replica_address == "" || tree == nil ||
          tree == "" ||
          admin == nil ||
          admin == "" ||
          password == nil ||
          password == "" ||
          domain == nil ||
          domain == ""
        Builtins.y2milestone(
          "edirectory.GetForestRootDomain:missing parameter."
        )
        return ""
      end

      forestRootDomain = ""

      cmd = Builtins.sformat(
        "TREE_NAME=%1 /opt/novell/xad/share/dcinit/provisionTools.sh forest-query -d %2 -a '%3' -p %4",
        tree,
        domain,
        NovellUtils.Ldap2Nds(admin),
        replica_address
      )
      Builtins.y2milestone("edirectory.GetForestRootDomain:executing:%1", cmd)
      cmd = Builtins.sformat("ADM_PASSWD='%1' %2", password, cmd)
      Builtins.y2milestone("xad.executing:%1", cmd) if Edirectory.xadTestMode

      Popup.ShowFeedback(
        _("Getting Forest Root Domain"),
        _("This may take a while")
      )
      val = Convert.to_map(SCR.Execute(path(".target.bash_output"), cmd))
      Popup.ClearFeedback

      iRet = Ops.get_integer(val, "exit", -1)
      Builtins.y2milestone(
        "edirectory.GetForestRootDomain:return values:%1",
        val
      )
      if iRet == 4
        # strip off the line feed on the output from the script file.
        forestRootDomain = Builtins.tolower(
          NovellUtils.CleanUpString(Ops.get_string(val, "stdout", ""))
        )
        forestRootDomain = "" if forestRootDomain == nil
        Builtins.y2milestone(
          "edirectory.GetForestRootDomain:forest found: %1",
          forestRootDomain
        )
      else
        errMsg = "Unknown error in call for Forest Root Domain."
        if iRet == 0
          errMsg = Builtins.sformat(
            "No forest can be found at:%1",
            replica_address
          )
        elsif iRet == 1
          errMsg = "Missing parameter in call for check of forest root domain."
        elsif iRet == 2
          errMsg = Builtins.sformat(
            "Server was unreachable during check forest root domain:%1.",
            replica_address
          )
        end

        Builtins.y2milestone(
          "edirectory.GetForestRootDomain:error: %1. Error:%2",
          errMsg,
          iRet
        )
      end

      forestRootDomain
    end


    # Configuration options for "Domain Services for Windows" (XAD) (only called for new domain)
    #
    # This function is used only for execution, no screen is diaplayed.
    #
    # @return dialog result
    def XadNetBIOSDialog
      Builtins.y2milestone(
        "Edirectory.XadNetBIOSDialog:Entering Edirectory XadNetBIOSDialog()"
      )

      # Edirectory XadNetBIOSDialog dialog caption
      caption = _("eDirectory Configuration - Domain Services for Windows")

      domErrMsg = _("The domain name %1 could not be resolved.")

      # Generate a default Forest Root based on the given DNS domain
      # For example: splitFQ("provo.novell.com") -> ["provo", "novell.com"]
      splitFQ = Hostname.SplitFQ(
        Ops.get_string(Edirectory.EdirSettings, "XAD_DOMAIN_NAME", "")
      )

      forest_root = Ops.get_string(
        Edirectory.EdirSettings,
        "XAD_FOREST_ROOT",
        ""
      )
      if forest_root == nil || forest_root == ""
        forest_root = Ops.get(splitFQ, 1, "")
      end
      forestRootViaCall = false # indicates if we got forest root via a call or just calculated it (we need to know if we can trust the value for grey out purposes).
      frd = ""
      forest_root = Builtins.tolower(forest_root)

      frd = GetForestRootDomain(
        Ops.get_string(
          Edirectory.EdirSettings,
          "CONFIG_EDIR_REPLICA_SERVER",
          ""
        ),
        Ops.get_string(NovellLDAP.Settings, "CONFIG_LDAP_TREE_NAME", ""),
        Ops.get_string(Edirectory.EdirSettings, "XAD_LDAP_ADMIN_CONTEXT", ""),
        Ops.get_string(Edirectory.EdirSettings, "XAD_LDAP_ADMIN_PASSWORD", ""),
        Ops.get_string(Edirectory.EdirSettings, "XAD_DOMAIN_NAME", "")
      )
      if frd != ""
        forest_root = frd
        forestRootViaCall = true # try a second method to get forest root
      else
        instType = "child"
        if Ops.get_string(Edirectory.EdirSettings, "XAD_DOMAIN_TYPE", "") != "domain"
          instType = "adc"
        end
        frd = Edirectory.GetForestRoot(instType)
        if frd != ""
          forest_root = frd
          forestRootViaCall = true
        end
      end

      parent_domain = Ops.get_string(
        Edirectory.EdirSettings,
        "XAD_PARENT_DOMAIN",
        ""
      )
      if parent_domain == nil || parent_domain == ""
        parent_domain = Edirectory.GetParentDomain
      end

      ret = nil
      if forest_root == nil || forest_root == ""
        Popup.Error(
          _(
            "The forest root domain is unavailable. Ensure that the DNS server and eDirectory on the Primary Domain Controller is up and running."
          )
        )
        return :continue
      end

      pos = Builtins.search(forest_root, ".")
      if pos == nil || Ops.less_than(pos, 0)
        Popup.Error(_("Forest root domain must have a period in it."))
        return :continue
      end

      if Ops.greater_than(Builtins.size(forest_root), 120)
        Popup.Error(_("Forest root domain must be 120 characters or less."))
        return :continue
      end

      if Hostname.CheckDomain(forest_root) == false
        Popup.Error(Hostname.ValidDomain)
        return :continue if !Edirectory.xadTestMode
      end

      # First make sure the forest root domain is reachable.
      cmd = Builtins.sformat(
        "/opt/novell/xad/sbin/provision -q --locate-dc %1",
        forest_root
      )
      Builtins.y2milestone("Executing: %1", cmd)
      retmap = Convert.to_map(SCR.Execute(path(".target.bash_output"), cmd))
      Builtins.y2milestone("retmap = %1", retmap)
      if Ops.get_integer(retmap, "exit", -1) != 0
        errmsg = _(
          "Possible causes are:\n" +
            "\n" +
            "1) DNS server is not reachable.\n" +
            "2) DNS server does not have the SRV record for the existing domain controller.\n" +
            "3) Firewall is blocking the packets of the current server.\n" +
            "\n"
        )
        #					boolean goon = Popup::ContinueCancelHeadline(_("Cannot Locate Existing Domain Controller"), errmsg);
        #					if (!goon) return `continue;
        Report.Error(
          Builtins.sformat(
            _("Cannot Locate Existing Domain Controller %1"),
            errmsg
          )
        )
        return :continue if !Edirectory.xadTestMode
      end

      # Now make sure the forest exists and the forest root domain is correct.
      replica_address = Ops.get_string(
        Edirectory.EdirSettings,
        "CONFIG_EDIR_REPLICA_SERVER",
        ""
      )
      tree = Ops.get_string(NovellLDAP.Settings, "CONFIG_LDAP_TREE_NAME", "")
      admin = Ops.get_string(
        Edirectory.EdirSettings,
        "XAD_LDAP_ADMIN_CONTEXT",
        ""
      )
      admPassword = Ops.get_string(
        Edirectory.EdirSettings,
        "XAD_LDAP_ADMIN_PASSWORD",
        ""
      )
      domain = Ops.get_string(Edirectory.EdirSettings, "XAD_DOMAIN_NAME", "")
      cmd = Builtins.sformat(
        "TREE_NAME=%1 /opt/novell/xad/share/dcinit/provisionTools.sh forest-query -d %2 -a '%3' -p %4",
        tree,
        domain,
        NovellUtils.Ldap2Nds(admin),
        replica_address
      )
      Builtins.y2milestone("Edirectory:executing:%1", cmd)
      cmd = Builtins.sformat("ADM_PASSWD='%1' %2", admPassword, cmd)
      Builtins.y2milestone("xad.executing:%1", cmd) if Edirectory.xadTestMode

      val = Convert.to_map(SCR.Execute(path(".target.bash_output"), cmd))
      iRet = Ops.get_integer(val, "exit", -1)
      Builtins.y2milestone("Edirectory:return values:%1", val)

      popUpMsg = true
      errMsg = Builtins.sformat(
        _(
          "Unknown error while validating forest root domain:%1. Continue anyway?"
        ),
        iRet
      )
      if iRet == 0
        errMsg = Builtins.sformat(
          _(
            "No forest can be found in the tree you are joining:%1. Continue anyway?"
          ),
          replica_address
        )
      elsif iRet == 1
        errMsg = _(
          "Missing parameter in call for check of forest root domain. Continue anyway?"
        )
      elsif iRet == 2
        errMsg = Builtins.sformat(
          _(
            "Server was unreachable during check forest root domain:%1. Continue anyway?"
          ),
          replica_address
        )
      elsif iRet == 4
        # strip off the line feed on the output from the script file.
        returnedFRD = NovellUtils.CleanUpString(
          Ops.get_string(val, "stdout", "")
        )

        Builtins.y2milestone(
          "Edirectory:forest found comparing frd with user entered frd: %1 %2",
          returnedFRD,
          forest_root
        )
        if Builtins.toupper(forest_root) != Builtins.toupper(returnedFRD)
          errMsg = Builtins.sformat(
            _(
              "The forest root domain in the tree '%1' does not match the entered forest root domain '%2' Continue anyway?"
            ),
            returnedFRD,
            forest_root
          )
        else
          popUpMsg = false
        end
      end
      return :continue if Popup.ContinueCancel(errMsg) == false if popUpMsg
      cmd = Ops.add(
        "/opt/novell/xad/share/dcinit/provisionTools.sh check-domain-resolution -d ",
        forest_root
      )
      Builtins.y2milestone("Edirectory.XadNetBiosDialog:executing %1", cmd)
      val = Convert.to_map(SCR.Execute(path(".target.bash_output"), cmd))
      iRet = Ops.get_integer(val, "exit", -1)
      Builtins.y2milestone("Edirectory:return values:%1", val)
      if iRet != 0 # iRet of 18 = ERR_DOMAIN_RESOLUTION_FAILED
        errMsg2 = Builtins.sformat(domErrMsg, forest_root)
        Builtins.y2error(errMsg2)
        return :continue if Popup.ContinueCancel(errMsg2) == false
      end

      #				parent_domain = (string)UI::QueryWidget(`id(`parent_domain), `Value);
      if parent_domain == nil || parent_domain == ""
        Popup.Error(_("Parent domain cannot be empty."))
        return :continue
      end

      pos = Builtins.search(parent_domain, ".")
      if pos == nil || Ops.less_than(pos, 0)
        Popup.Error(_("Parent domain must have a period in it."))
        return :continue
      end

      if Ops.greater_than(Builtins.size(parent_domain), 120)
        Popup.Error(_("Parent domain must be 120 characters or less."))
        return :continue
      end

      if Hostname.CheckDomain(parent_domain) == false
        Popup.Error(Hostname.ValidDomain)
        return :continue if !Edirectory.xadTestMode
      end

      # Make sure the parent domain exists
      replica_address = Ops.get_string(
        Edirectory.EdirSettings,
        "CONFIG_EDIR_REPLICA_SERVER",
        ""
      )
      iRet = Edirectory.DoesDomainExistInForest(parent_domain, replica_address)
      if iRet != 10
        errMsg2 = Builtins.sformat(
          _(
            "Unknown error while checking for existence of parent domain name:%1"
          ),
          iRet
        )
        if iRet == 0
          errMsg2 = Builtins.sformat(
            _(
              "The parent domain name '%1' cannot be found in the tree you are joining: %2"
            ),
            parent_domain,
            replica_address
          )
        elsif iRet == 1
          errMsg2 = _("Missing parameter in call for check of domain name.")
        elsif iRet == 2
          errMsg2 = Builtins.sformat(
            _(
              "Server was unreachable during check for existence of domain name:%1"
            ),
            replica_address
          )
        end

        return :continue if Popup.ContinueCancel(errMsg2) == false
      end
      cmd = Ops.add(
        "/opt/novell/xad/share/dcinit/provisionTools.sh check-domain-resolution -d ",
        parent_domain
      )
      Builtins.y2milestone("Edirectory.XadNetBiosDialog:executing %1", cmd)
      val = Convert.to_map(SCR.Execute(path(".target.bash_output"), cmd))
      iRet = Ops.get_integer(val, "exit", -1)
      Builtins.y2milestone("Edirectory:return values:%1", val)
      if iRet != 0 # iRet of 18 = ERR_DOMAIN_RESOLUTION_FAILED
        errMsg2 = Builtins.sformat(domErrMsg, parent_domain)
        Builtins.y2error(errMsg2)
        return :continue if Popup.ContinueCancel(errMsg2) == false
      end


      Ops.set(
        Edirectory.EdirSettings,
        "XAD_FOREST_ROOT",
        Builtins.tolower(forest_root)
      ) # DNS names look better in lower case
      Ops.set(
        Edirectory.EdirSettings,
        "BACK_XAD_FOREST_ROOT",
        Builtins.tolower(forest_root)
      )
      Ops.set(
        Edirectory.EdirSettings,
        "XAD_PARENT_DOMAIN",
        Builtins.tolower(parent_domain)
      ) # DNS names look better in lower case

      # set the eDirectory admin name and server context
      xad_settings = Edirectory.ProposeXadContextSettings(
        Ops.get_string(Edirectory.EdirSettings, "XAD_DOMAIN_TYPE", ""),
        Ops.get_string(Edirectory.EdirSettings, "XAD_DOMAIN_NAME", ""),
        Ops.get_string(Edirectory.EdirSettings, "XAD_FOREST_ROOT", "")
      )

      Ops.set(
        Edirectory.EdirSettings,
        "CONFIG_EDIR_SERVER_CONTEXT",
        Ops.get_string(xad_settings, "CONFIG_EDIR_SERVER_CONTEXT", "")
      )

      Ops.set(
        NovellLDAP.Settings,
        "CONFIG_LDAP_ADMIN_CONTEXT",
        Ops.get_string(xad_settings, "CONFIG_LDAP_ADMIN_CONTEXT", "")
      )

      if Ops.get_string(Edirectory.EdirSettings, "XAD_DOMAIN_TYPE", "") == "forest" &&
          Ops.get_string(Edirectory.EdirSettings, "CONFIG_EDIR_TREE_TYPE", "") == "new"
        Ops.set(
          Edirectory.EdirSettings,
          "XAD_LDAP_ADMIN_CONTEXT",
          Ops.get_string(xad_settings, "XAD_LDAP_ADMIN_CONTEXT", "")
        )
      end

      ret = :parent

      ret
    end




    # Configuration options for "Domain Services for Windows" (XAD)
    #
    # @return dialog result
    def XadDomainAndNetbiosDialog
      Builtins.y2milestone("Entering Edirectory XadDomainAndNetbiosDialog()")

      # Edirectory XadDomainTypeDialog dialog caption
      caption = _(
        "Domain Services for Windows Configuration - Domain and NetBIOS Name"
      )

      # Get the Domain Type from the previous screen.
      domain_type = Ops.get_string(
        Edirectory.EdirSettings,
        "XAD_DOMAIN_TYPE",
        ""
      )

      domain_name = Ops.get_string(
        Edirectory.EdirSettings,
        "XAD_DOMAIN_NAME",
        ""
      )
      if domain_name == nil || domain_name == ""
        splitFQ = Hostname.SplitFQ(NovellUtils.GetDNSname)
        domain_name = Ops.get(splitFQ, 1, "")
      end
      domain_name = Builtins.tolower(domain_name)

      wins_server_exists = 0
      wins_server = "no"
      if Ops.get_string(Edirectory.EdirSettings, "XAD_WINS_SERVER", "") != "yes"
        if domain_type == "controller"
          # to check whether wins is configured or not
          cmd = "perl /opt/novell/xad/share/dcinit/configure_dsfw_wins.pl --isconfigured"
          Builtins.y2milestone("Executing: %1", cmd)
          retmap = Convert.to_map(SCR.Execute(path(".target.bash_output"), cmd))
          Popup.ClearFeedback
          Builtins.y2milestone("retmap = %1", retmap)
          wins_server_exists = Ops.get_integer(retmap, "exit", -1)
        end
        wins_server2 = ""
        if wins_server_exists == 0
          wins_server2 = "yes"
        elsif wins_server_exists == 1 || wins_server_exists == 2
          wins_server2 = "no"
        end
      end

      errMsg = _(
        "Please ensure that hostname in the properties of active ethernet\n" +
          "controller is a FQDN.For example, if the hostname in the Hostname/DNS tab is\n" +
          "dsfw-dc1 and domain name is dsfw.com, then the hostname of the active ethernet\n" +
          "controller must be dsfw-dc1.dsfw.com. You can modify the hostname of the active\n" +
          "ethernet controller by using the Edit option in the Overview tab of lan\n" +
          "settings in YaST."
      )

      tt = domain_type == "domain" ? :domain : :controller
      tt = domain_type == "forest" ? :forest : tt
      dnsServerStr = _("Configure this server as a DNS server")
      dnsNameStr = _("&DNS Name for New Domain")
      dnsNameStrCtrl = _("&DNS Name for Existing Domain")
      dnsNameStrWrk = dnsNameStr

      #Obtain the netbios name for controller
      if domain_type == "controller"
        cmd = Builtins.sformat(
          "/opt/novell/xad/share/dcinit/provisionTools.sh get-NetBIOS-name -d '%1'",
          domain_name
        )
        Builtins.y2milestone(
          "edirectory.GetDomainNetBIOSName:executing:%1",
          cmd
        )
        val = Convert.to_map(SCR.Execute(path(".target.bash_output"), cmd))
        netbios2 = Builtins.toupper(
          NovellUtils.CleanUpString(Ops.get_string(val, "stdout", ""))
        )
        Ops.set(Edirectory.EdirSettings, "XAD_NETBIOS", netbios2)
        Builtins.y2milestone("edirectory.GetNetBIOSname:return values:%1", val)
      end

      netbios = Ops.get_string(Edirectory.EdirSettings, "XAD_NETBIOS", "")
      # if netbios  name is null assing the default value
      if netbios == nil || netbios == ""
        splitFQ = Hostname.SplitFQ(domain_name)
        netbios = Builtins.toupper(Ops.get(splitFQ, 0, ""))
      end
      netbios = Builtins.toupper(netbios)

      #if site is null, setting it to default value as Default-First-Site-Name
      site_subnet = Ops.get_string(Edirectory.EdirSettings, "XAD_SITE_NAME", "")
      if site_subnet == nil || site_subnet == ""
        site_subnet = "Default-First-Site-Name"
      end

      contents = HVSquash(
        VBox(
          TextEntry(Id(:domain_name), dnsNameStrWrk, domain_name),
          VBox(
            Left(
              CheckBox(
                Id(:config_dns),
                dnsServerStr,
                Ops.get_string(Edirectory.EdirSettings, "XAD_CONFIG_DNS", "no") == "yes"
              )
            )
          ),
          VSpacing(1),
          TextEntry(Id(:netbios), _("N&etBIOS Domain Name"), netbios),
          VBox(
            Left(
              CheckBox(
                Id(:wins_server),
                _("Configure this server as a W&INS Server"),
                wins_server == "yes"
              )
            )
          ),
          VSpacing(1),
          MinWidth(
            45,
            HBox(
              TextEntry(
                Id(:site_subnet),
                _("&Site Name of Domain Controller"),
                site_subnet
              ),
              VBox(Label(""), PushButton(Id(:browse_sitesubnets), _("Browse")))
            )
          )
        )
      )

      Wizard.SetContentsButtons(
        caption,
        contents,
        Ops.get_string(@HELPS, "eDir_conf_ndsw_2", ""),
        Label.BackButton,
        Label.NextButton
      )

      UI.ChangeWidget(Id(:domain_name), :Label, dnsNameStrWrk)

      if Ops.get_string(Edirectory.EdirSettings, "XAD_WINS_SERVER", "") != "yes"
        if wins_server_exists == 0
          UI.ChangeWidget(Id(:wins_server), :Value, false)
          UI.ChangeWidget(Id(:wins_server), :Enabled, true)
        elsif wins_server_exists == 1
          UI.ChangeWidget(Id(:wins_server), :Value, false)
          UI.ChangeWidget(Id(:wins_server), :Enabled, false)
        elsif wins_server_exists == 2
          UI.ChangeWidget(Id(:wins_server), :Value, true)
          UI.ChangeWidget(Id(:wins_server), :Enabled, false)
        end
      else
        UI.ChangeWidget(Id(:wins_server), :Value, true)
        UI.ChangeWidget(Id(:wins_server), :Enabled, true)
      end

      if domain_type == "forest"
        UI.ChangeWidget(Id(:browse_sitesubnets), :Enabled, false)
      else
        UI.ChangeWidget(Id(:browse_sitesubnets), :Enabled, true)
      end

      if domain_type == "controller"
        UI.ChangeWidget(Id(:controller), :Value, true)
        if Ops.get_string(Edirectory.EdirSettings, "XAD_CONFIG_DNS", "") == "yes"
          UI.ChangeWidget(Id(:config_dns), :Enabled, true)
          UI.ChangeWidget(Id(:config_dns), :Value, true)
        else
          UI.ChangeWidget(Id(:config_dns), :Enabled, true)
          UI.ChangeWidget(Id(:config_dns), :Value, false)
        end
        UI.ChangeWidget(Id(:netbios), :Enabled, false)
      else
        UI.ChangeWidget(Id(:domain_name), :Label, dnsNameStr)
        UI.ChangeWidget(Id(:netbios), :Enabled, true)
        if domain_type == "forest"
          UI.ChangeWidget(Id(:forest), :Value, true)
          UI.ChangeWidget(Id(:config_dns), :Enabled, false)
          UI.ChangeWidget(Id(:config_dns), :Value, true)
        else
          if Ops.get_string(Edirectory.EdirSettings, "XAD_CONFIG_DNS", "") == "yes"
            UI.ChangeWidget(Id(:config_dns), :Enabled, true)
            UI.ChangeWidget(Id(:config_dns), :Value, true)
          else
            UI.ChangeWidget(Id(:config_dns), :Enabled, true)
            UI.ChangeWidget(Id(:config_dns), :Value, false)
          end
        end
      end
      UI.ChangeWidget(Id(:domain_name), :Enabled, false) # don't let them change this here

      if domain_name == nil || domain_name == ""
        NovellUtils.PopupErrorDetailsText(
          _("DNS name for new domain could not be determined."),
          errMsg
        )
      end

      ret = nil
      while true
        ret = Convert.to_symbol(UI.UserInput)

        if ret == :back
          break
        elsif ret == :abort || ret == :cancel
          if ReallyAbort()
            break
          else
            next
          end
        elsif ret == :next
          config_dns = Convert.to_boolean(
            UI.QueryWidget(Id(:config_dns), :Value)
          )
          wins_server2 = Convert.to_boolean(
            UI.QueryWidget(Id(:wins_server), :Value)
          )

          site_subnet = Convert.to_string(
            UI.QueryWidget(Id(:site_subnet), :Value)
          )
          if site_subnet == ""
            Report.Error(Builtins.sformat(_("Site name cannot be empty")))
            next
          else
            cmd = Builtins.sformat(
              "/opt/novell/xad/share/dcinit/provisionTools.sh validate-site-name -z '%1'",
              site_subnet
            )
            mret = Convert.to_map(SCR.Execute(path(".target.bash_output"), cmd))
            exit = Ops.get_integer(mret, "exit", -1)
            Builtins.y2milestone("mret is %1", mret)
            if exit == 26
              if Popup.ContinueCancel(Ops.get_string(mret, "stdout", "")) == false
                next
              end
            elsif exit != 0
              Report.Error(
                Builtins.sformat("%1", Ops.get_string(mret, "stdout", ""))
              )
              next
            end
          end
          domain_name = Convert.to_string(
            UI.QueryWidget(Id(:domain_name), :Value)
          )
          if domain_name == nil || domain_name == ""
            NovellUtils.PopupErrorDetailsText(
              _("DNS name for new domain cannot be empty."),
              errMsg
            )
            next
          end

          pos = Builtins.search(domain_name, ".")
          if pos == nil || Ops.less_than(pos, 0)
            Popup.Error(_("Domain name must have a period in it."))
            next
          end

          if Ops.greater_than(Builtins.size(domain_name), 63)
            Popup.Error(_("Domain name must be 63 characters or less."))
            next
          end

          if Hostname.CheckDomain(domain_name) == false
            Popup.Error(Hostname.ValidDomain)
            next if !Edirectory.xadTestMode
          end

          machineDomain = CompareDomain(domain_name)
          if machineDomain != nil
            erMsg = Builtins.sformat(
              _(
                "The domain name entered does not match the machine domain name\n" +
                  "Machine domain:%1\n" +
                  "Entered domain:%2\n" +
                  "Continue anyway?"
              ),
              machineDomain,
              domain_name
            )
            next if Popup.ContinueCancel(erMsg) == false
          end

          if domain_type != "controller"
            netbios = Convert.to_string(UI.QueryWidget(Id(:netbios), :Value))
            if netbios == nil || netbios == ""
              Popup.Error(_("NetBIOS cannot be empty."))
              next
            end

            if Ops.greater_than(Builtins.size(netbios), 15)
              Popup.Error(_("NetBIOS must be 15 characters or less."))
              next
            end
            iRet = Edirectory.CheckForValidNetbiosName(netbios)
            if iRet != 0
              errMsg2 = Builtins.sformat(
                _(
                  "Unknown error while checking for existence of NetBIOS name:%1"
                ),
                iRet
              )
              if iRet == 13
                errMsg2 = Builtins.sformat(
                  _("The NetBIOS name already exists in the subnet:%1"),
                  netbios
                )
              elsif iRet == 19
                errMsg2 = Builtins.sformat(
                  _("NetBIOS name '%1' is not supported."),
                  netbios
                )
              end
              Popup.Error(errMsg2)
              next if !Edirectory.xadTestMode
            end

            # Check for duplicate netbios name in the tree (LDAP search call)
            if Ops.get_string(
                Edirectory.EdirSettings,
                "CONFIG_EDIR_TREE_TYPE",
                ""
              ) != "new"
              ipAddr = Ops.get_string(
                Edirectory.EdirSettings,
                "CONFIG_EDIR_REPLICA_SERVER",
                ""
              )
              iRet = Edirectory.CheckForExistingNetbiosName(ipAddr, netbios)
              if iRet != 0
                errMsg2 = Builtins.sformat(
                  _(
                    "Unknown error while checking for existence of NetBIOS name:%1"
                  ),
                  iRet
                )
                if iRet == 5
                  errMsg2 = Builtins.sformat(
                    _(
                      "The NetBIOS name already exists in the tree you are joining:%1, %2"
                    ),
                    ipAddr,
                    netbios
                  )
                elsif iRet == 1
                  errMsg2 = _(
                    "Missing parameter in call for check of NetBIOS name."
                  )
                elsif iRet == 2
                  errMsg2 = Builtins.sformat(
                    _(
                      "Server was unreachable during check for existence of NetBIOS name:%1"
                    ),
                    ipAddr
                  )
                elsif iRet == 13
                  errMsg2 = Builtins.sformat(
                    _("The NetBIOS name already exists in the subnet:%1"),
                    netbios
                  )
                elsif iRet == 19
                  errMsg2 = Builtins.sformat(
                    _("NetBIOS name '%1' is not supported."),
                    netbios
                  )
                end

                Popup.Error(errMsg2)

                next if iRet == 5 || iRet == 19
              end
            end
          end

          ret = :xaddc if domain_type == "controller"


          tree_type = Ops.get_string(
            Edirectory.EdirSettings,
            "CONFIG_EDIR_TREE_TYPE",
            ""
          )
          # Make sure we are not adding a second forest to an existing tree.
          if domain_type == "forest" && tree_type == "existing"
            replica_address2 = Ops.get_string(
              Edirectory.EdirSettings,
              "CONFIG_EDIR_REPLICA_SERVER",
              ""
            )

            Ops.set(
              NovellLDAP.Settings,
              "CONFIG_LDAP_ADMIN_PASSWORD",
              Ops.get_string(
                Edirectory.EdirSettings,
                "XAD_LDAP_ADMIN_PASSWORD",
                ""
              )
            )
            iRet = Edirectory.CheckForExistingForest(
              Builtins.tolower(domain_name),
              replica_address2
            )
            if iRet != 0
              errMsg2 = Builtins.sformat(
                _("Unknown error while checking for existence of forest:%1"),
                iRet
              )
              if iRet == 4
                errMsg2 = Builtins.sformat(
                  _("A forest already exists in the tree you are joining:%1"),
                  replica_address2
                )
              elsif iRet == 1
                errMsg2 = _(
                  "Missing parameter in call for check of existence of forest."
                )
              elsif iRet == 2
                errMsg2 = Builtins.sformat(
                  _(
                    "Server was unreachable during check for existence of forest:%1"
                  ),
                  replica_address2
                )
              end

              Popup.Error(errMsg2)

              next if iRet == 4
            end
          end

          tree_type = Ops.get_string(
            Edirectory.EdirSettings,
            "CONFIG_EDIR_TREE_TYPE",
            ""
          )
          ret = :ntp if domain_type == "forest" && tree_type == "new"

          replica_address = Ops.get_string(
            Edirectory.EdirSettings,
            "CONFIG_EDIR_REPLICA_SERVER",
            ""
          )

          # if we are installing an ADC, then find out what object name to use
          if domain_type == "controller"
            if Edirectory.ContainerIsDefault == false
              Edirectory.oesContext = "ou=novell"
            end
          end

          if Edirectory.xadTestMode == false
            if config_dns && Package.Installed("bind") == false
              Package.InstallAll(["bind"])
            end
          end

          Ops.set(
            Edirectory.EdirSettings,
            "XAD_NETBIOS",
            Builtins.toupper(netbios)
          ) # NetBIOS should be uppercase
          Ops.set(
            Edirectory.EdirSettings,
            "XAD_DOMAIN_NAME",
            Builtins.tolower(domain_name)
          ) # domain names look better in lowercase ;-)
          Ops.set(
            Edirectory.EdirSettings,
            "XAD_CONFIG_DNS",
            config_dns ? "yes" : "no"
          )
          Ops.set(
            Edirectory.EdirSettings,
            "XAD_WINS_SERVER",
            wins_server2 ? "yes" : "no"
          )
          Ops.set(Edirectory.EdirSettings, "XAD_SITE_NAME", site_subnet)
          if domain_type == "domain"
            ret_val = XadNetBIOSDialog()

            if ret_val == :continue
              next
            else
              ret = ret_val
            end
          end

          xad_settings = Edirectory.ProposeXadContextSettings(
            Ops.get_string(Edirectory.EdirSettings, "XAD_DOMAIN_TYPE", ""),
            Ops.get_string(Edirectory.EdirSettings, "XAD_DOMAIN_NAME", ""),
            Ops.get_string(Edirectory.EdirSettings, "XAD_FOREST_ROOT", "")
          )
          Ops.set(
            NovellLDAP.Settings,
            "CONFIG_LDAP_ADMIN_CONTEXT",
            Ops.get_string(xad_settings, "CONFIG_LDAP_ADMIN_CONTEXT", "")
          )
          break
        elsif ret == :browse_sitesubnets
          cmd = ""
          instType = "child"
          if Ops.get_string(Edirectory.EdirSettings, "XAD_DOMAIN_TYPE", "") != "domain"
            instType = "adc"
          end
          forest_root_domain = Edirectory.GetForestRoot(instType)
          cmd = Builtins.sformat(
            "/opt/novell/xad/share/dcinit/provisionTools.sh get-site-list -d %1",
            forest_root_domain
          )
          mret = Convert.to_map(SCR.Execute(path(".target.bash_output"), cmd))
          Builtins.y2milestone("Executing cmd : %1", cmd)
          Builtins.y2milestone("map return is : %1", mret)
          exit = Ops.get_integer(mret, "exit", -1)
          if exit != 0
            Report.Error(
              Builtins.sformat("%1", Ops.get_string(mret, "stdout", ""))
            )
            next
          else
            site_subnets_list = Builtins.splitstring(
              Ops.get_string(mret, "stdout", ""),
              " "
            )

            UI.OpenDialog(
              MinWidth(
                50,
                VBox(
                  SelectionBox(
                    Id(:selected_item),
                    "Site name selection",
                    site_subnets_list
                  ),
                  HBox(
                    PushButton(Id(:ok), "&Ok"),
                    PushButton(Id(:cancel), "&Cancel")
                  )
                )
              )
            )

            ret2 = nil
            while true
              ret2 = Convert.to_symbol(UI.UserInput)

              if ret2 == :cancel
                UI.CloseDialog

                break
              elsif ret2 == :ok
                selected_item = Convert.to_string(
                  UI.QueryWidget(Id(:selected_item), :Value)
                )
                UI.CloseDialog

                UI.ChangeWidget(Id(:site_subnet), :Value, selected_item)
                break
              else
                next
              end
            end
          end
        else
          Builtins.y2error("unexpected retcode: %1", ret)
          next
        end
      end
      ret
    end


    def ValidateNameMapContextLength(container)
      ret = true

      containerSize = Builtins.size(container)
      tree_name_length = Builtins.size(
        Ops.get_string(NovellLDAP.Settings, "CONFIG_LDAP_TREE_NAME", "")
      )

      # Max length of a FQDN name: 255
      # Max eDirectory's DN size (including Typed Tree Name eg. .T=EXAMPLE-TREE (length = 3+12)): 255
      # The size of longest default object in aquila tree: [144 + Size of longest DC Name in the domain]
      # The DC Name need not to be equal to Host Name. Also max length of DC Name can be of 15 characters.
      # Max size of Mapped Container ldap name: [255 - (144 + 15 (Max length of DC Name) + 3 (Typed chars of Tree Name) +
      # Length of Actual Tree Name)] = [93 - Length of Actual Tree Name]
      #

      maxSize = Ops.subtract(93, tree_name_length)

      Builtins.y2milestone(
        "edirectory.ValidateNameMapContextLength:container size %1, max size %2, Tree Name length %3",
        containerSize,
        maxSize,
        tree_name_length
      )

      Builtins.y2milestone(
        "edirectory.ValidateNameMapContextLength:about to compare %1 to %2",
        containerSize,
        maxSize
      )
      if Ops.greater_than(containerSize, maxSize)
        erMsg = Builtins.sformat(
          _(
            "The length of the name of the container to be mapped cannot exceed %1 characters"
          ),
          maxSize
        )
        Popup.Error(erMsg)
        ret = false
      end
      Builtins.y2milestone(
        "edirectory.ValidateNameMapContextLength:returning %1",
        ret
      )
      ret
    end

    # XAD New Domain Admin Dialog (new forest or new domain in an existing forest)
    # Only used in new DC case
    #
    # @return dialog result
    def XadDomainAdminDialog
      Builtins.y2milestone("Entering Edirectory XadDomainAdminDialog()")
      # Edirectory  XadDomainAdminDialog caption
      caption = _("eDirectory Configuration - Domain Services for Windows")

      forest_root = Edirectory.GetForestRoot("adc")

      # Edirectory XadDomainAdminDialog contents
      domain = Ops.get_string(Edirectory.EdirSettings, "XAD_DOMAIN_NAME", "")

      adminName = Edirectory.GetDomainAdministrator(domain)
      adminPassword = Ops.get_string(
        NovellLDAP.Settings,
        "CONFIG_LDAP_ADMIN_PASSWORD",
        ""
      )

      contents = HVSquash(
        MinWidth(
          50,
          VBox(
            TextEntry(
              Id(:adminName),
              _("Existing &domain administrator name"),
              adminName
            ),
            Left(
              Password(
                Id(:pw1),
                _("Enter Administrator &Password"),
                adminPassword
              )
            )
          )
        )
      )

      Wizard.SetContentsButtons(
        caption,
        contents,
        Ops.get_string(@HELPS, "eDir_conf_ndsw_administrator_pw", ""),
        Label.BackButton,
        Label.NextButton
      )

      UI.ChangeWidget(Id(:adminName), :Enabled, false) # NOTE: XAD cannot allow modification to admin name.  Must be based on the DNS domain name

      ret = nil
      while true
        ret = UI.UserInput
        adminName = Convert.to_string(UI.QueryWidget(Id(:adminName), :Value))
        adminPassword = Convert.to_string(UI.QueryWidget(Id(:pw1), :Value))

        # abort?
        if ret == :abort || ret == :cancel
          if ReallyAbort()
            break
          else
            next
          end
        elsif ret == :next
          #	    forest_root = (string)UI::QueryWidget(`id(`forest_root), `Value);
          if forest_root == nil || forest_root == ""
            Popup.Error(
              _(
                "The forest root domain is unavailable. Ensure that the DNS server and eDirectory on the Primary Domain Controller is up and running."
              )
            )
            next
          end
          pos = Builtins.search(forest_root, ".")
          if pos == nil || Ops.less_than(pos, 0)
            Popup.Error(_("Forest root domain must have a period in it."))
            next
          end
          if Ops.greater_than(Builtins.size(forest_root), 120)
            Popup.Error(_("Forest root domain must be 120 characters or less."))
            next
          end
          if Hostname.CheckDomain(forest_root) == false
            Popup.Error(Hostname.ValidDomain)
            next
          end

          # First make sure the forest root domain is reachable.
          cmd = Builtins.sformat(
            "/opt/novell/xad/sbin/provision -q --locate-dc %1",
            forest_root
          )
          Builtins.y2milestone("Executing: %1", cmd)
          retmap = Convert.to_map(SCR.Execute(path(".target.bash_output"), cmd))
          Builtins.y2milestone("retmap = %1", retmap)
          if Ops.get_integer(retmap, "exit", -1) != 0
            errmsg = _(
              "Possible causes are:\n" +
                "\n" +
                "1) DNS server is not reachable.\n" +
                "2) DNS server does not have the SRV record for the existing domain controller.\n" +
                "3) Firewall is blocking the packets of the current server.\n" +
                "\n"
            )
            goon = Popup.ContinueCancelHeadline(
              _("Cannot Locate Existing Domain Controller"),
              errmsg
            )
            next if !goon
          end
          # Now make sure the forest exists and the forest root domain is correct.
          replica_address = Ops.get_string(
            Edirectory.EdirSettings,
            "CONFIG_EDIR_REPLICA_SERVER",
            ""
          )
          tree = Ops.get_string(
            NovellLDAP.Settings,
            "CONFIG_LDAP_TREE_NAME",
            ""
          )
          admin = Ops.get_string(
            Edirectory.EdirSettings,
            "XAD_LDAP_ADMIN_CONTEXT",
            ""
          )
          admPassword = Ops.get_string(
            Edirectory.EdirSettings,
            "XAD_LDAP_ADMIN_PASSWORD",
            ""
          )
          domain2 = Ops.get_string(
            Edirectory.EdirSettings,
            "XAD_DOMAIN_NAME",
            ""
          )

          cmd = Builtins.sformat(
            "TREE_NAME=%1 /opt/novell/xad/share/dcinit/provisionTools.sh forest-query -d %2 -a '%3' -p %4",
            tree,
            domain2,
            NovellUtils.Ldap2Nds(admin),
            replica_address
          )
          Builtins.y2milestone("Edirectory:executing:%1", cmd)
          cmd = Builtins.sformat("ADM_PASSWD='%1' %2", admPassword, cmd)
          if Edirectory.xadTestMode
            Builtins.y2milestone("xad.executing:%1", cmd)
          end

          val = Convert.to_map(SCR.Execute(path(".target.bash_output"), cmd))
          iRet = Ops.get_integer(val, "exit", -1)
          Builtins.y2milestone("Edirectory:return values:%1", val)

          popUpMsg = true
          errMsg = Builtins.sformat(
            _(
              "Unknown error while validating forest root domain:%1. Continue anyway?"
            ),
            iRet
          )
          if iRet == 0
            errMsg = Builtins.sformat(
              _(
                "No forest can be found in the tree you are joining:%1. Continue anyway?"
              ),
              replica_address
            )
          elsif iRet == 1
            errMsg = _(
              "Missing parameter in call for check of forest root domain. Continue anyway?"
            )
          elsif iRet == 2
            errMsg = Builtins.sformat(
              _(
                "Server was unreachable during check forest root domain:%1. Continue anyway?"
              ),
              replica_address
            )
          elsif iRet == 4
            # strip off the line feed on the output from the script file.
            returnedFRD = NovellUtils.CleanUpString(
              Ops.get_string(val, "stdout", "")
            )

            Builtins.y2milestone(
              "Edirectory:forest found comparing frd with user entered frd: %1 %2",
              returnedFRD,
              forest_root
            )
            if Builtins.toupper(forest_root) != Builtins.toupper(returnedFRD)
              errMsg = Builtins.sformat(
                _(
                  "The forest root domain in the tree '%1' does not match the entered forest root domain '%2' Continue anyway?"
                ),
                returnedFRD,
                forest_root
              )
            else
              popUpMsg = false
            end
          end
          next if Popup.ContinueCancel(errMsg) == false if popUpMsg

          pw1 = adminPassword

          if !NovellValidators.ValidatePasswords(pw1, pw1)
            UI.ChangeWidget(Id(:pw1), :Value, "")
            UI.SetFocus(Id(:pw1))
            next
          end
          if EdirUtils.isLDAPdn(adminName)
            adminName = NovellUtils.Ldap2Nds(adminName)
          end

          if !NovellValidators.ValidateFDN(adminName, false)
            UI.SetFocus(Id(:adminName))
            next
          end

          remote_server = NovellLDAP.GetAddressServer(
            Ops.get_string(
              Edirectory.EdirSettings,
              "CONFIG_EDIR_REPLICA_SERVER",
              ""
            ),
            nil
          )
          secure_port = Ops.get_integer(
            remote_server,
            "CONFIG_LDAP_SECURE_PORT",
            636
          )
          if secure_port == nil || Ops.less_or_equal(secure_port, 0)
            secure_port = 636
          end
          replica_address = Ops.get_string(
            Edirectory.EdirSettings,
            "CONFIG_EDIR_REPLICA_SERVER",
            ""
          )
          iVal = NovellValidators.ValidateCredentials(
            adminName,
            adminPassword,
            replica_address,
            secure_port,
            true
          )
          Builtins.y2milestone(
            "edirectory:validating creds. name %1, pass ****, ip %2, port %3",
            adminName,
            replica_address,
            secure_port
          )
          if iVal != 0
            Builtins.y2milestone("ValidateCredentials() returned %1", iVal)
            if iVal == -666
              err = _(
                "The attempt to perform a secure LDAP bind did not respond in 2 minutes\n" +
                  "This may indicate a problem with LDAP on the target server.\n" +
                  "If you are confident that your credentials are correct you may continue,\n" +
                  "otherwise please determine if LDAP is running correctly on the target system\n" +
                  "Do you want to continue?"
              )
              yes = Popup.YesNoHeadline(_("LDAP secure bind timeout"), err)
              next if !yes
            else
              err = Builtins.sformat(
                _(
                  "User credentials failed to validate Using:\n" +
                    "      Server: %1\n" +
                    "      User: %2\n" +
                    "      LDAP port: %3\n" +
                    "Do you want to continue anyway?"
                ),
                replica_address,
                adminName,
                secure_port
              )
              yes = Popup.YesNoHeadline(_("Credentials Failed"), err)
              next if !yes
            end
          end

          # Calculate the server context for the domain controller case
          serverContext = Edirectory.GetXadServerContext(
            Ops.get_string(Edirectory.EdirSettings, "XAD_DOMAIN_TYPE", ""),
            Ops.get_string(Edirectory.EdirSettings, "XAD_DOMAIN_NAME", ""),
            Ops.get_string(
              Edirectory.EdirSettings,
              "XAD_LDAP_ADMIN_CONTEXT",
              ""
            ),
            Ops.get_string(
              Edirectory.EdirSettings,
              "XAD_LDAP_ADMIN_PASSWORD",
              ""
            )
          )

          #1165214
          xad_domain_type = Ops.get_string(Edirectory.EdirSettings, "XAD_DOMAIN_TYPE", "")
          if ExecuteComparetoPdcScript(
            xad_domain_type, 
            adminName, 
            adminPassword) == :continue
            next
          end
          # Save the data
          Ops.set(
            Edirectory.EdirSettings,
            "CONFIG_EDIR_SERVER_CONTEXT",
            serverContext
          )
          Ops.set(
            Edirectory.EdirSettings,
            "XAD_FOREST_ROOT",
            Builtins.tolower(forest_root)
          ) # DNS names look better in lower case
          Ops.set(NovellLDAP.Settings, "CONFIG_LDAP_ADMIN_CONTEXT", adminName)
          Ops.set(
            NovellLDAP.Settings,
            "CONFIG_LDAP_ADMIN_PASSWORD",
            adminPassword
          )

          break
        elsif ret == :back
          break
        else
          Builtins.y2error("unexpected retcode: %1", ret)
          next
        end
      end
      deep_copy(ret)
    end

    # XAD Parent Domain Dialog (only need for new domain in an existing forest)
    #
    # This function is to diplay the XadDomainAdminDialog widget only
    #
    # @return dialog widget

    def XadNameMappingDialog
      Builtins.y2milestone("Entering Edirectory XadNameMappingDialog()")
      # Edirectory  XadNameMappingDialog caption
      caption = _("eDirectory Configuration - Domain Services for Windows")

      # container/partition name that
      # they want to convert to a Domain.  Once they provide an existing
      # container/partition root, we apply name mapping

      # Edirectory XadNameMappingDialog contents
      domain_type = Ops.get_string(
        Edirectory.EdirSettings,
        "XAD_DOMAIN_TYPE",
        ""
      )
      root_server = Ops.get_string(
        Edirectory.EdirSettings,
        "CONFIG_EDIR_REPLICA_SERVER",
        ""
      )
      Ops.set(Edirectory.EdirSettings, "XAD_CONVERT_EXISTING_CONTAINER", "yes")
      convert = Builtins.tolower(
        Ops.get_string(
          Edirectory.EdirSettings,
          "XAD_CONVERT_EXISTING_CONTAINER",
          "no"
        )
      ) != "no"
      serverContext = Ops.get_string(
        Edirectory.EdirSettings,
        "CONFIG_EDIR_SERVER_CONTEXT",
        ""
      )

      container = Ops.get_string(
        Edirectory.EdirSettings,
        "XAD_EXISTING_CONTAINER",
        ""
      )
      container = "" if container == nil

      domainName = Ops.get_string(
        Edirectory.EdirSettings,
        "XAD_DOMAIN_NAME",
        ""
      )
      existingContainerString = Builtins.sformat(
        _(
          "Enter the FDN of the container that needs to be mapped as %1 (e.g. ou=domain,o=microfocus)"
        ),
        domainName
      )

      retainPolicies = false
      retain_policies = Ops.get_string(
        Edirectory.EdirSettings,
        "XAD_RETAIN_POLICIES",
        "no"
      )
      retainPolicies = true if retain_policies == "yes"

      contents = VBox(
        MinWidth(
          45,
          HBox(
            TextEntry(Id(:container), existingContainerString, container),
            VBox(Label(""), PushButton(Id(:browse_container), _("Browse")))
          )
        ),
        VSpacing(1),
        VBox(
          Left(
            CheckBox(
              Id(:policies),
              Opt(:notify),
              _("R&etain existing NMAS password policies"),
              retainPolicies
            )
          )
        )
      )
      #    Wizard::SetContentsButtons(caption, contents, HELPS["eDir_conf_ndsw_namemap"]:"", Label::BackButton(), Label::NextButton());

      deep_copy(contents)
    end

    # XadNameMappingDialog() is removed into two parts, XadNameMappingDialog() contains the widget part
    # XadNameMappingNextButton () contins the validation code when next button is clicked in
    # XadParentDomainDialog () and ExistingTreeNewForestAdminDialog () screens
    # @return dialog result

    def XadNameMappingNextButton(convert, container, domain_type, retainPolicies)
      root_server = Ops.get_string(
        Edirectory.EdirSettings,
        "CONFIG_EDIR_REPLICA_SERVER",
        ""
      )
      serverContext = Ops.get_string(
        Edirectory.EdirSettings,
        "CONFIG_EDIR_SERVER_CONTEXT",
        ""
      )
      container = NovellUtils.StripTrailing(container, " ")
      if convert
        if EdirUtils.isLDAPdn(container)
          container = NovellUtils.Ldap2Nds(container)
        end
        return :continue if !NovellValidators.ValidateContext(container)
        domainName = Ops.get_string(
          Edirectory.EdirSettings,
          "XAD_DOMAIN_NAME",
          ""
        )
        if !ValidateNameMapContextLength(container)
          return :continue if !Edirectory.xadTestMode
        end

        iRet = Edirectory.CheckContainerPartitioning(container)
        if iRet != 0
          erMsg = Builtins.sformat(
            _("Error while checking to see if container %1 is partitioned:%2"),
            container,
            iRet
          )
          if iRet == 3
            erMsg = Builtins.sformat(
              _(
                "Container %1 is not partitioned. Container must be partitioned for install to work."
              ),
              container
            )
          elsif iRet == 2
            erMsg = Builtins.sformat(
              _(
                "Error while checking to see if container %1 is partitioned. Either server is not reachable or specified container does not exist."
              ),
              container
            )
          elsif iRet == 1
            erMsg = Builtins.sformat(
              _(
                "Error while checking to see if container %1 is partitioned. Missing parameter"
              ),
              container
            )
          end
          Report.Error(erMsg)

          return :continue if !Edirectory.xadTestMode
        end
        useValues = Popup.YesNoHeadline(
          _("Container Mapping"),
          Builtins.sformat(
            _(
              "The container once mapped to a Domain name cannot be reversed.\nWould you like to map the container %1 to domain %2?"
            ),
            container,
            domainName
          )
        )
        return :continue if useValues == false

        if domain_type == "domain"
          # Validate the new domain and the resulting hierarchy.
          ipAddress = Ops.get_string(
            Edirectory.EdirSettings,
            "XAD_PARENT_DOMAIN_ADDRESS",
            ""
          )
          iRet2 = Edirectory.CheckNameMapContainer(container, ipAddress)

          splitFQ = Hostname.SplitFQ(domainName)
          parent_name = Ops.get(splitFQ, 1, "")
          Builtins.y2milestone("parent name: %1", parent_name)

          if iRet2 != 0
            errMsg = Builtins.sformat(
              _(
                "Unknown Error while checking container hierarchy for containter %1. Error %2"
              ),
              container,
              iRet2
            )
            if iRet2 == 1
              errMsg = _(
                "Error checking container hierarchy. Missing parameter"
              )
            elsif iRet2 == 2
              errMsg = _(
                "Error while checking container hierarchy. Server is not reachable."
              )
            elsif iRet2 == 3
              errMsg = _(
                "Server is not reachable using the given IP address / hostname."
              )
            elsif iRet2 == 9
              errMsg = _("LDAP search failed.")
            elsif iRet2 == 14
              errMsg = _("Invalid container DN.")
            elsif iRet2 == 17
              errMsg = _("Certificate is not present.")
            elsif iRet2 == 21
              errMsg = Builtins.sformat(
                _("Parent Domain %1 does not exists."),
                parent_name
              )
            elsif iRet2 == 22
              errMsg = _(
                "The partition being mapped is extending into the existing domain."
              )
            end

            Builtins.y2milestone(
              "edirectory:Error checking container hierarchy: %1",
              errMsg
            )

            Popup.Error(errMsg)
            return :continue if !Edirectory.xadTestMode
          end
        end
        if domain_type == "forest" &&
            Ops.get_string(Edirectory.EdirSettings, "CONFIG_EDIR_TREE_TYPE", "") == "existing"
          # Call to see if the schema has been extended
          retSch = Edirectory.DoXadVersionCheck(root_server)
          if retSch != 0
            errMsg = Builtins.sformat(
              _(
                "Unknown Error while validating schema version (checking for required patch):%1"
              ),
              retSch
            )
            if retSch == 1
              errMsg = _(
                "Patch required for 64 bit syntax is not applied to the given server.\n" +
                  "The version of eDir on the server you are pointing to is not new enough.\n" +
                  "Version 8.8 sp2 is required"
              )
            elsif retSch == 2
              errMsg = _(
                "The given server does not have a read/write or master replica of the root partition."
              )
            elsif retSch == 3
              errMsg = _(
                "Server is not reachable using the given IP address / hostname."
              )
            elsif retSch == 4
              errMsg = _(
                "Server's major/minor version number could not be obtained using the given IP address / hostname."
              )
            end

            Builtins.y2milestone(
              "edirectory:Error checking to see if schema has been extended: %1",
              errMsg
            )

            Report.Error(errMsg)
            return :continue if Edirectory.xadTestMode == false
          end
        end
        Ops.set(Edirectory.EdirSettings, "XAD_EXISTING_CONTAINER", container)
      end

      # Save the data
      Ops.set(
        Edirectory.EdirSettings,
        "XAD_CONVERT_EXISTING_CONTAINER",
        convert ? "yes" : "no"
      )
      Ops.set(
        Edirectory.EdirSettings,
        "XAD_RETAIN_POLICIES",
        retainPolicies ? "yes" : "no"
      )

      if Ops.get_string(Edirectory.EdirSettings, "XAD_RETAIN_POLICIES", "") == "yes"
        adminDn = NovellUtils.Nds2Ldap(
          Ops.get_string(Edirectory.EdirSettings, "XAD_LDAP_ADMIN_CONTEXT", "")
        )
        adminPassword = Ops.get_string(
          NovellLDAP.Settings,
          "CONFIG_LDAP_ADMIN_PASSWORD",
          ""
        )
        edir_ip_Address = Ops.get_string(
          Edirectory.EdirSettings,
          "CONFIG_EDIR_REPLICA_SERVER",
          ""
        )
        fmt_container = NovellUtils.Nds2Ldap(container)

        cmd = Builtins.sformat(
          "/opt/novell/xad/sbin/checkunivpwd -i %1 -c '/etc/opt/novell/certs/SSCert.der' -a '%2' -w '%3' -o '%4'",
          edir_ip_Address,
          adminDn,
          adminPassword,
          fmt_container
        )

        Builtins.y2milestone(
          "Executing: /opt/novell/xad/sbin/checkunivpwd -i %1 -c '/etc/opt/novell/certs/SSCert.der' -a '%2' -w 'xxxxxx' -o '%3'",
          edir_ip_Address,
          adminDn,
          fmt_container
        )
        retmap = Convert.to_map(SCR.Execute(path(".target.bash_output"), cmd))

        if Ops.get_integer(retmap, "exit", -1) == 255
          Popup.Message(
            _(
              "Universal Password Policy is not enabled. Ensure that all users that\nwill be part of this domain have the Universal Password Policy enabled."
            )
          )
        end
      end

      # At this point,we have enough information to get the server context if joining a tree.
      if Ops.get_string(Edirectory.EdirSettings, "CONFIG_EDIR_TREE_TYPE", "") == "existing" # server context already calculated for new tree.
        if Ops.get_string(Edirectory.EdirSettings, "XAD_DOMAIN_TYPE", "") == "forest"
          if Ops.get_string(
              Edirectory.EdirSettings,
              "XAD_CONVERT_EXISTING_CONTAINER",
              "no"
            ) == "yes"
            # Modify the server context based on name mapping
            serverContext = Ops.add(
              Ops.add(Edirectory.oesContext, "."),
              NovellUtils.Ldap2Nds(
                Ops.get_string(
                  Edirectory.EdirSettings,
                  "XAD_EXISTING_CONTAINER",
                  ""
                )
              )
            )
          end
        elsif Ops.get_string(Edirectory.EdirSettings, "XAD_DOMAIN_TYPE", "") == "domain"
          if Ops.get_string(
              Edirectory.EdirSettings,
              "XAD_CONVERT_EXISTING_CONTAINER",
              "no"
            ) == "yes"
            # Modify the server context based on name mapping
            serverContext = Ops.add(
              Ops.add(Edirectory.oesContext, "."),
              NovellUtils.Ldap2Nds(
                Ops.get_string(
                  Edirectory.EdirSettings,
                  "XAD_EXISTING_CONTAINER",
                  ""
                )
              )
            )
          else
            serverContext = Edirectory.GetXadServerContext(
              Ops.get_string(Edirectory.EdirSettings, "XAD_DOMAIN_TYPE", ""),
              Ops.get_string(Edirectory.EdirSettings, "XAD_DOMAIN_NAME", ""),
              Ops.get_string(
                Edirectory.EdirSettings,
                "XAD_LDAP_ADMIN_CONTEXT",
                ""
              ),
              Ops.get_string(
                Edirectory.EdirSettings,
                "XAD_LDAP_ADMIN_PASSWORD",
                ""
              )
            )
          end
        end
        if EdirUtils.isLDAPdn(serverContext)
          serverContext = NovellUtils.Ldap2Nds(serverContext)
        end

        if !NovellValidators.ValidateContext(serverContext)
          Builtins.y2milestone(
            "Edirectory.xadNameMappingDialog:error validating server context: %1",
            serverContext
          )
        end
        Ops.set(
          Edirectory.EdirSettings,
          "CONFIG_EDIR_SERVER_CONTEXT",
          serverContext
        )
      end

      nil
    end

    # XAD Parent Domain Dialog (only need for new domain in an existing forest)
    #
    # @return dialog result
    def XadParentDomainDialog
      Builtins.y2milestone("Entering Edirectory XadParentDomainDialog()")
      # Edirectory  XadParentDomainDialog caption
      caption = _("eDirectory Configuration - Domain Services for Windows")

      # Edirectory XadNameMappingDialog contents
      domain_type = Ops.get_string(
        Edirectory.EdirSettings,
        "XAD_DOMAIN_TYPE",
        ""
      )
      convert = Builtins.tolower(
        Ops.get_string(
          Edirectory.EdirSettings,
          "XAD_CONVERT_EXISTING_CONTAINER",
          "no"
        )
      ) != "no"

      retainPolicies = false
      retain_policies = Ops.get_string(
        Edirectory.EdirSettings,
        "XAD_RETAIN_POLICIES",
        "no"
      )
      retainPolicies = true if retain_policies == "yes"

      adminName = Ops.get_string(
        NovellLDAP.Settings,
        "CONFIG_LDAP_ADMIN_CONTEXT",
        ""
      )
      adminPassword = Ops.get_string(
        NovellLDAP.Settings,
        "CONFIG_LDAP_ADMIN_PASSWORD",
        ""
      )
      adminPassword2 = adminPassword

      domainTypeController = false
      adminNamePrompt = _("New &Domain Administrator Name")
      if Ops.get_string(Edirectory.EdirSettings, "XAD_DOMAIN_TYPE", "") == "controller"
        adminNamePrompt = _("Existing &domain administrator name")
        domainTypeController = true
      end

      # Edirectory XadParentDomainDialog contents
      parentAddress = Ops.get_string(
        Edirectory.EdirSettings,
        "XAD_PARENT_DOMAIN_ADDRESS",
        ""
      )
      if parentAddress == nil || parentAddress == ""
        parentAddress = Edirectory.GetParentDomainIP
      end

      parentDomain = Ops.get_string(
        Edirectory.EdirSettings,
        "XAD_PARENT_DOMAIN",
        ""
      )
      parentName = Edirectory.GetDomainAdministrator(parentDomain)
      parentPassword = Ops.get_string(
        Edirectory.EdirSettings,
        "XAD_PARENT_DOMAIN_ADMIN_PASSWORD",
        ""
      )
      securePort = 636

      if parentName == nil || parentName == ""
        # generate the parentName...
        xad_settings = Edirectory.ProposeXadContextSettings(
          Ops.get_string(Edirectory.EdirSettings, "XAD_DOMAIN_TYPE", ""),
          Ops.get_string(Edirectory.EdirSettings, "XAD_PARENT_DOMAIN", ""),
          Ops.get_string(Edirectory.EdirSettings, "XAD_FOREST_ROOT", "")
        )
        parentName = Ops.get_string(
          xad_settings,
          "CONFIG_LDAP_ADMIN_CONTEXT",
          ""
        )
      end

      contents = VBox(
        MinWidth(
          50,
          TextEntry(
            Id(:parentName),
            _("Parent &Domain Administrator Name"),
            parentName
          )
        ),
        Left(
          Password(Id(:pw0), _("Enter Administrator &Password"), parentPassword)
        ),
        VSpacing(1),
        TextEntry(Id(:adminName), adminNamePrompt, adminName),
        Left(
          Password(
            Id(:pw1),
            _("Specify Administrator &Password"),
            adminPassword
          )
        ),
        domainTypeController == false ?
          Left(
            Password(
              Id(:pw2),
              _("&Verify Administrator Password"),
              adminPassword2
            )
          ) :
          Empty()
      )

      # to find whether its a name mapped or non name-mapped
      if Ops.get_string(Edirectory.EdirSettings, "XAD_DOMAIN_TYPE", "") == "domain"
        Edirectory.nameMapCheck = false
        retNM = Edirectory.IsParentDomainMapped(parentDomain)
        Edirectory.nameMapCheck = true if retNM == 1 # we are name-mapped so we must show the screen and enable and gray out the name map check box
        # else  -- we operate as we always have and let the user decide.
      end

      helps = Ops.get_string(@HELPS, "eDir_conf_ndsw_ip_parent_domain", "")
      if Edirectory.nameMapCheck
        # Combining XadParentDomainDialog() with current screen
        contents = HVSquash(VBox(contents, XadNameMappingDialog()))
        helps = Ops.add(
          helps,
          Ops.get_string(@HELPS, "eDir_conf_ndsw_namemap", "")
        )
      else
        # Combining XadParentDomainDialog() with current screen
        contents = HVSquash(VBox(contents))
      end

      Wizard.SetContentsButtons(
        caption,
        contents,
        helps,
        Label.BackButton,
        Label.NextButton
      )

      UI.ChangeWidget(Id(:parentName), :Enabled, false)
      UI.SetFocus(Id(:pw0))

      UI.ChangeWidget(Id(:adminName), :Enabled, false) # NOTE: XAD cannot allow modification to admin name.  Must be based on the DNS domain name

      if Edirectory.nameMapCheck
        if domain_type == "forest"
          UI.ChangeWidget(Id(:container), :Enabled, true)
          UI.ChangeWidget(Id(:policies), :Enabled, true)
          UI.ChangeWidget(Id(:policies), :Value, retainPolicies)
        else
          UI.ChangeWidget(Id(:container), :Enabled, true)
          UI.ChangeWidget(Id(:policies), :Enabled, true)
          if convert
            UI.ChangeWidget(Id(:policies), :Value, retainPolicies)
          else
            UI.ChangeWidget(Id(:policies), :Value, false)
          end
        end
      end

      primary_server = NovellLDAP.BrowseButtonLdapServer(nil)
      ldap_servers = Ops.get_string(primary_server, "CONFIG_LDAP_SERVER_IP", "")
      ldap_sport = Ops.get_integer(
        primary_server,
        "CONFIG_LDAP_SECURE_PORT",
        636
      )
      if NovellLDAP.IsLocalLDAPRunning != 0
        UI.ChangeWidget(Id(:browse_container), :Enabled, false)
      end

      if !(NovellLDAP.IsLocalLDAPRunning == 0 ||
          Ops.get_string(Edirectory.EdirSettings, "CONFIG_EDIR_TREE_TYPE", "") == "existing")
        UI.ChangeWidget(Id(:browse_container), :Enabled, false)
      else
        UI.ChangeWidget(Id(:browse_container), :Enabled, true)
      end

      ret = nil
      while true
        ret = UI.UserInput
        parentName = Convert.to_string(UI.QueryWidget(Id(:parentName), :Value))
        parentPassword = Convert.to_string(UI.QueryWidget(Id(:pw0), :Value))
        adminName = Convert.to_string(UI.QueryWidget(Id(:adminName), :Value))
        adminPassword = Convert.to_string(UI.QueryWidget(Id(:pw1), :Value))

        # abort?
        if ret == :abort || ret == :cancel
          if ReallyAbort()
            break
          else
            next
          end
        elsif ret == :next
          if !Address.Check4(parentAddress)
            if parentAddress != ""
              Popup.Error(Address.Valid4)
            else
              Popup.Error(
                _(
                  "Parent Domain IP address / hostname is unavailable. Ensure that the DNS server is up and running."
                )
              )
            end
            next
          end
          if !NovellUtils.Ping_IP(parentAddress)
            erMsg = Builtins.sformat(
              _(
                "The specified IP address / hostname (%1) is either not reachable or unresolvable.\nDo you want to continue anyway?"
              ),
              parentAddress
            )

            next if Popup.ContinueCancel(erMsg) == false
          end


          if !NovellValidators.ValidatePassword(parentPassword)
            UI.ChangeWidget(Id(:pw0), :Value, "")
            UI.SetFocus(Id(:pw0))
            next
          end
          if EdirUtils.isLDAPdn(parentName)
            parentName = NovellUtils.Ldap2Nds(parentName)
          end

          if !NovellValidators.ValidateFDN(parentName, false)
            UI.SetFocus(Id(:parentName))
            next
          end

          val = 0
          if Edirectory.xadTestMode == false
            val = NovellValidators.ValidateCredentials(
              parentName,
              parentPassword,
              parentAddress,
              securePort,
              true
            )
          end

          Builtins.y2milestone(
            "Edirectory:ValidateCredentials (parent domain):parentName:%1, parentAddress:%2, secure port:%3",
            parentName,
            parentAddress,
            securePort
          )

          if val != 0
            Builtins.y2milestone("ValidateCredentials() returned %1", val)
            if val == -666
              err = _(
                "The attempt to perform a secure LDAP bind did not respond in 2 minutes\n" +
                  "This may indicate a problem with LDAP on the target server.\n" +
                  "If you are confident that your credentials are correct you may continue,\n" +
                  "otherwise please determine if LDAP is running correctly on the target system\n" +
                  "Do you want to continue?"
              )
              yes = Popup.YesNoHeadline(_("LDAP secure bind timeout"), err)
              next if !yes
            else
              err = Builtins.sformat(
                _(
                  "User credentials failed to validate Using:\n" +
                    "      Server: %1\n" +
                    "      User: %2\n" +
                    "      LDAP port: %3\n" +
                    "Do you want to continue anyway?"
                ),
                parentAddress,
                parentName,
                securePort
              )
              yes = Popup.YesNoHeadline(_("Credentials Failed"), err)
              next if !yes
            end
          end
          pw1 = adminPassword
          pw2 = ""
          if domainTypeController
            pw2 = pw1
          else
            pw2 = Convert.to_string(UI.QueryWidget(Id(:pw2), :Value))
          end

          if !NovellValidators.ValidatePasswords(pw1, pw2)
            UI.ChangeWidget(Id(:pw1), :Value, "")
            if domainTypeController == false
              UI.ChangeWidget(Id(:pw2), :Value, "")
            end
            UI.SetFocus(Id(:pw1))
            next
          end
          if EdirUtils.isLDAPdn(adminName)
            adminName = NovellUtils.Ldap2Nds(adminName)
          end

          if !NovellValidators.ValidateFDN(adminName, false)
            UI.SetFocus(Id(:adminName))
            next
          end

          if Ops.get_string(Edirectory.EdirSettings, "XAD_DOMAIN_TYPE", "") == "controller"
            remote_server = NovellLDAP.GetAddressServer(
              Ops.get_string(
                Edirectory.EdirSettings,
                "CONFIG_EDIR_REPLICA_SERVER",
                ""
              ),
              nil
            )
            secure_port = Ops.get_integer(
              remote_server,
              "CONFIG_LDAP_SECURE_PORT",
              636
            )
            if secure_port == nil || Ops.less_or_equal(secure_port, 0)
              secure_port = 636
            end
            replica_address = Ops.get_string(
              Edirectory.EdirSettings,
              "CONFIG_EDIR_REPLICA_SERVER",
              ""
            )
            val2 = NovellValidators.ValidateCredentials(
              adminName,
              adminPassword,
              replica_address,
              secure_port,
              true
            )
            Builtins.y2milestone(
              "edirectory:validating creds. name %1, pass ****, ip %2, port %3",
              adminName,
              replica_address,
              secure_port
            )
            if val2 != 0
              Builtins.y2milestone("ValidateCredentials() returned %1", val2)
              if val2 == -666
                err = _(
                  "The attempt to perform a secure LDAP bind did not respond in 2 minutes\n" +
                    "This may indicate a problem with LDAP on the target server.\n" +
                    "If you are confident that your credentials are correct you may continue,\n" +
                    "otherwise please determine if LDAP is running correctly on the target system\n" +
                    "Do you want to continue?"
                )
                yes = Popup.YesNoHeadline(_("LDAP secure bind timeout"), err)
                next if !yes
              else
                err = Builtins.sformat(
                  _(
                    "User credentials failed to validate Using:\n" +
                      "      Server: %1\n" +
                      "      User: %2\n" +
                      "      LDAP port: %3\n" +
                      "Do you want to continue anyway?"
                  ),
                  replica_address,
                  adminName,
                  secure_port
                )
                yes = Popup.YesNoHeadline(_("Credentials Failed"), err)
                next if !yes
              end
            end
          end

          #1165214
          xad_domain_type = Ops.get_string(Edirectory.EdirSettings, "XAD_DOMAIN_TYPE", "")
          if ExecuteComparetoPdcScript(
            xad_domain_type,
            parentName,
            parentPassword) == :continue
            next
          end

          # Save the data
          Ops.set(
            Edirectory.EdirSettings,
            "XAD_PARENT_DOMAIN_ADMIN_CONTEXT",
            parentName
          )
          Ops.set(
            Edirectory.EdirSettings,
            "XAD_PARENT_DOMAIN_ADMIN_PASSWORD",
            parentPassword
          )
          Ops.set(
            Edirectory.EdirSettings,
            "XAD_PARENT_DOMAIN_ADDRESS",
            parentAddress
          )
          Ops.set(NovellLDAP.Settings, "CONFIG_LDAP_ADMIN_CONTEXT", adminName)
          Ops.set(
            NovellLDAP.Settings,
            "CONFIG_LDAP_ADMIN_PASSWORD",
            adminPassword
          )

          if Edirectory.nameMapCheck
            container = Convert.to_string(
              UI.QueryWidget(Id(:container), :Value)
            )
            retainPolicies2 = Convert.to_boolean(
              UI.QueryWidget(Id(:policies), :Value)
            )
            convert2 = Builtins.tolower(
              Ops.get_string(
                Edirectory.EdirSettings,
                "XAD_CONVERT_EXISTING_CONTAINER",
                "no"
              )
            ) != "no"
            domain_type2 = Ops.get_string(
              Edirectory.EdirSettings,
              "XAD_DOMAIN_TYPE",
              ""
            )

            if XadNameMappingNextButton(
                convert2,
                container,
                domain_type2,
                retainPolicies2
              ) == :continue
              next
            end
          end
          break
        elsif ret == :browse_container
          primary_server2 = NovellLDAP.BrowseButtonLdapServer(nil)
          ldap_servers2 = Ops.get_string(
            primary_server2,
            "CONFIG_LDAP_SERVER_IP",
            ""
          )
          ldap_sport2 = Ops.get_integer(
            primary_server2,
            "CONFIG_LDAP_SECURE_PORT",
            636
          )

          adminDn = Ops.get_string(
            NovellLDAP.Settings,
            "CONFIG_LDAP_ADMIN_CONTEXT",
            ""
          )
          adminPassword2 = Ops.get_string(
            NovellLDAP.Settings,
            "CONFIG_LDAP_ADMIN_PASSWORD",
            ""
          )
          if Edirectory.xad_packages_installed
            xad_tree_admin_context = Ops.get_string(
              NovellLDAP.Settings,
              "XAD_TREE_ADMIN_CONTEXT",
              ""
            )
            Builtins.y2milestone(
              "eDirectory:XAD_TREE_ADMIN_CONTEXT:%1",
              xad_tree_admin_context
            )
            if xad_tree_admin_context != nil && xad_tree_admin_context != ""
              adminDn = NovellUtils.Nds2Ldap(xad_tree_admin_context)
              adminPassword2 = Ops.get_string(
                NovellLDAP.Settings,
                "XAD_TREE_ADMIN_PASSWORD",
                ""
              )
            end
          end
          adminDn = NovellUtils.Nds2Ldap(adminDn)
          Builtins.y2milestone("eDirectory:admin:%1", adminDn)
          container = NovellLdapBrowser.LdapBrowser(
            ldap_servers2,
            ldap_sport2,
            true,
            adminDn,
            adminPassword2,
            "",
            "(|(ObjectClass=Organization)(ObjectClass=OrganizationalUnit)(ObjectClass=Domain)(ObjectClass=Locality)(ObjectClass=Country))",
            _("Browse for container")
          )

          Builtins.y2milestone(
            Builtins.sformat(
              "dialogs.ycp.NewOrExistingDialog:container from browse is: '%1'",
              container
            )
          )
          if container != nil && container != ""
            container = NovellUtils.Nds2Ldap(container)
            UI.ChangeWidget(Id(:container), :Value, container)
          end
        elsif ret == :back
          break
        else
          Builtins.y2error("unexpected retcode: %1", ret)
          next
        end
      end
      deep_copy(ret)
    end

    #1165214
    def ExecuteComparetoPdcScript(xad_domain_type, adminName, adminPassword)
      adminUsername = ""
      if Edirectory.xad_packages_installed
        name = NovellUtils.Ldap2Nds(adminName)
        split = Builtins.splitstring(name, ".")
        Builtins.foreach(split) do |testLine|
          if Builtins.issubstring(testLine, "cn=")
            adminUsername = testLine[3,testLine.size]
            break
          end
        end
        if xad_domain_type == "domain"
          cmd = Builtins.sformat("/opt/novell/xad/share/dcinit/compareToPdcOes.pl --forCdc %1 '%2'",adminUsername, adminPassword)
        elsif xad_domain_type == "controller"
          cmd = Builtins.sformat("/opt/novell/xad/share/dcinit/compareToPdcOes.pl --forAdc %1 '%2'",adminUsername, adminPassword)
        end
        retmap = Convert.to_map(SCR.Execute(path(".target.bash_output"), cmd))
        Builtins.y2milestone("For executing /opt/novell/xad/share/dcinit/compareToPdcOes.pl :retmap = %1", retmap)
        stdout = NovellUtils.CleanUpString(Ops.get_string(retmap, "stdout", ""))
        if Ops.get_integer(retmap, "exit", -1) == 1
          if Builtins.contains(stdout, "ndsdcinit")
            Report.Error(Builtins.sformat(_("The Domain Controllers must have the same version as the OES server.\nUpgrade the Domain Controllers listed in the log file and then continue with the installation.\nTo view the list of Domain Controllers, refer to the %1 file."),stdout))
          else
            Report.Error(Builtins.sformat(_("The Domain Controllers must have the same version as the OES server.\nUpgrade the following Domain Controllers and then continue with the installation:\n%1"),stdout))
          end
          return :continue
        elsif Ops.get_integer(retmap, "exit", -1) == 2
          if Builtins.contains(stdout, "ndsdcinit")
            warning_msg = _("Few of the Domain Controllers are not reachable. Before proceeding with the\ninstallation,it is recommended to make the Domain Controllers listed in the log file available.\n%1")
          else
            warning_msg = _("Few of the Domain Controllers are not reachable. Before proceeding with the\ninstallation, it is recommended to make the following Domain Controllers available:\n%1")
          end
          whatnext = Popup.AnyQuestion(
            _("Warning"),
             Builtins.sformat((warning_msg),stdout),
            _("Continue"),
            _("Cancel"),
            :focus_no
          )
          return :continue if !whatnext
          end
      end
     nil
    end

   def ValidateNameMapContainer(domainName, container)
      ret = true

      if domainName == nil || domainName == "" || container == nil ||
          container == ""
        Builtins.y2milestone("Edirectory.ValidateContainer:invalid parameter.")
        return false
      end

      Builtins.y2milestone(
        "Edirectory.ValidateNameMapContainer:domain name: %1, container: %2",
        domainName,
        container
      )

      # get first element of each name to compare
      split = Builtins.splitstring(domainName, ".")
      firstDomainNameElement = Ops.get(split, 0, "")
      Builtins.y2milestone(
        "Edirectory.ValidateContainer:first elemement of domain name is: %1",
        firstDomainNameElement
      )

      container = NovellUtils.Ldap2Nds(container)
      split = Builtins.splitstring(container, ".")
      wrkStr = Ops.get(split, 0, "")
      split = Builtins.splitstring(wrkStr, "=")
      firstContainerElement = Ops.get(split, 1, "")
      Builtins.y2milestone(
        "Edirectory.ValidateContainer:first elemement of container name is: %1",
        firstContainerElement
      )

      if Builtins.toupper(firstDomainNameElement) !=
          Builtins.toupper(firstContainerElement)
        Builtins.y2milestone(
          "Edirectory.ValidateNameMapContainer:first elements are different. Returning false."
        )
        ret = false
      end

      ret
    end

    # New Tree Dialog
    # @return dialog result
    def NewTreeDialog
      Builtins.y2milestone("Entering Edirectory NewTreeDialog()")
      # Edirectory  NewTreeDialog caption
      caption = _("eDirectory Configuration - New Tree Information")
      tmpSettings = {}

      #skip execution for EDIR express install
      if Ops.get_string(Edirectory.EdirSettings, "EDIR_QUICK_INSTALL", "no") == "yes"
        return :next
      end

      if Ops.get_string(Edirectory.EdirSettings, "XAD_SERVICE_CONFIGURED", "") == "yes"
        # This is the New Tree, New Forest case
        Ops.set(Edirectory.EdirSettings, "XAD_DOMAIN_TYPE", "forest")

        splitFQ = Hostname.SplitFQ(NovellUtils.GetDNSname)
        Ops.set(
          Edirectory.EdirSettings,
          "XAD_DOMAIN_NAME",
          Builtins.tolower(Ops.get(splitFQ, 1, ""))
        )
        Ops.set(
          Edirectory.EdirSettings,
          "XAD_FOREST_ROOT",
          Ops.get_string(Edirectory.EdirSettings, "XAD_DOMAIN_NAME", "")
        )

        xad_settings = Edirectory.ProposeXadContextSettings(
          "forest",
          Ops.get_string(Edirectory.EdirSettings, "XAD_DOMAIN_NAME", ""),
          Ops.get_string(Edirectory.EdirSettings, "XAD_FOREST_ROOT", "")
        )
        Ops.set(
          Edirectory.EdirSettings,
          "CONFIG_EDIR_SERVER_CONTEXT",
          Ops.get_string(xad_settings, "CONFIG_EDIR_SERVER_CONTEXT", "")
        )
        Ops.set(
          NovellLDAP.Settings,
          "CONFIG_LDAP_ADMIN_CONTEXT",
          Ops.get_string(xad_settings, "CONFIG_LDAP_ADMIN_CONTEXT", "")
        )
        Ops.set(
          Edirectory.EdirSettings,
          "XAD_LDAP_ADMIN_CONTEXT",
          Ops.get_string(xad_settings, "XAD_LDAP_ADMIN_CONTEXT", "")
        )
      end

      # Edirectory NewTreeDialog contents
      adminName = Ops.get_string(
        NovellLDAP.Settings,
        "CONFIG_LDAP_ADMIN_CONTEXT",
        ""
      )
      adminPassword = Ops.get_string(
        NovellLDAP.Settings,
        "CONFIG_LDAP_ADMIN_PASSWORD",
        ""
      )
      adminPassword2 = adminPassword

      contents = HVSquash(
        VBox(
          TextEntry(
            Id(:adminName),
            _("&FDN of the tree administrator (e.g. cn=admin,o=microfocus)"),
            adminName
          ),
          Left(Password(Id(:pw1), _("Admin &Password"), adminPassword)),
          Left(Password(Id(:pw2), _("&Verify Admin Password"), adminPassword2))
        )
      )

      helps = Ops.get_string(@HELPS, "new_tree", "")

      Wizard.SetContentsButtons(
        caption,
        contents,
        helps,
        Label.BackButton,
        Label.NextButton
      )

      if Ops.get_string(Edirectory.EdirSettings, "XAD_SERVICE_CONFIGURED", "") == "yes"
        UI.ChangeWidget(Id(:adminName), :Enabled, false) # NOTE: XAD cannot allow modification to admin name.  Must be based on the DNS domain name
        UI.SetFocus(Id(:pw1))
      else
        UI.SetFocus(Id(:adminName))
      end

      ret = nil
      while true
        ret = UI.UserInput
        adminName = Convert.to_string(UI.QueryWidget(Id(:adminName), :Value))
        adminPassword = Convert.to_string(UI.QueryWidget(Id(:pw1), :Value))
        # abort?

        if ret == :abort || ret == :cancel
          if ReallyAbort()
            break
          else
            next
          end
        elsif ret == :next
          pw1 = adminPassword
          pw2 = Convert.to_string(UI.QueryWidget(Id(:pw2), :Value))

          if !NovellValidators.ValidatePasswords(pw1, pw2)
            UI.ChangeWidget(Id(:pw1), :Value, "")
            UI.ChangeWidget(Id(:pw2), :Value, "")
            UI.SetFocus(Id(:pw1))
            next
          end
          if EdirUtils.isLDAPdn(adminName)
            adminName = NovellUtils.Ldap2Nds(adminName)
          end

          if !NovellValidators.ValidateFDN(adminName, false)
            UI.SetFocus(Id(:adminName))
            next
          end

          # Save the data
          Ops.set(NovellLDAP.Settings, "CONFIG_LDAP_ADMIN_CONTEXT", adminName)
          Ops.set(
            NovellLDAP.Settings,
            "CONFIG_LDAP_ADMIN_PASSWORD",
            adminPassword
          )
          Ops.set(NovellLDAP.Settings, "XAD_TREE_ADMIN_CONTEXT", "")
          Ops.set(NovellLDAP.Settings, "XAD_TREE_ADMIN_PASSWORD", "")

          if Ops.get_string(
              Edirectory.EdirSettings,
              "XAD_SERVICE_CONFIGURED",
              "no"
            ) == "yes"
            ret = :xad
          end

          break
        elsif ret == :back
          break
        else
          Builtins.y2error("unexpected retcode: %1", ret)
          next
        end
      end
      deep_copy(ret)
    end


    # New Tree Dialog
    # @return dialog result
    def ExistingTreeNewForestAdminDialog
      Builtins.y2milestone(
        "Entering Edirectory ExistingTreeNewForestAdminDialog()"
      )
      # Edirectory  ExistingTreeNewForestAdminDialog caption
      caption = _("eDirectory Configuration - New Domain Information")
      tmpSettings = {}

      # This is the Existing Tree, New Forest case
      xad_settings = Edirectory.ProposeXadContextSettings(
        "forest",
        Ops.get_string(Edirectory.EdirSettings, "XAD_DOMAIN_NAME", ""),
        Ops.get_string(Edirectory.EdirSettings, "XAD_FOREST_ROOT", "")
      )

      domain_type = Ops.get_string(
        Edirectory.EdirSettings,
        "XAD_DOMAIN_TYPE",
        ""
      )

      # Edirectory NewTreeDialog contents
      adminName = Ops.get_string(xad_settings, "CONFIG_LDAP_ADMIN_CONTEXT", "")
      adminPassword = Ops.get_string(
        Edirectory.EdirSettings,
        "DOMAIN_PASSWORD_BACK",
        ""
      )
      adminPassword2 = adminPassword

      convert = Builtins.tolower(
        Ops.get_string(
          Edirectory.EdirSettings,
          "XAD_CONVERT_EXISTING_CONTAINER",
          "yes"
        )
      ) != "no"
      retainPolicies = false
      retain_policies = Ops.get_string(
        Edirectory.EdirSettings,
        "XAD_RETAIN_POLICIES",
        "no"
      )
      retainPolicies = true if retain_policies == "yes"


      contents = VBox(
        TextEntry(
          Id(:adminName),
          _("New &Domain Administrator Name"),
          adminName
        ),
        Left(
          Password(
            Id(:pw1),
            _("Specify Administrator &Password"),
            adminPassword
          )
        ),
        Left(
          Password(
            Id(:pw2),
            _("&Verify Administrator Password"),
            adminPassword2
          )
        )
      )

      helps = Ops.add(
        Ops.get_string(@HELPS, "exist_tree_new_forest", ""),
        Ops.get_string(@HELPS, "eDir_conf_ndsw_namemap", "")
      )
      contents = HVSquash(VBox(contents, XadNameMappingDialog()))
      Wizard.SetContentsButtons(
        caption,
        contents,
        helps,
        Label.BackButton,
        Label.NextButton
      )
      if domain_type == "forest"
        UI.ChangeWidget(Id(:container), :Enabled, true)
        UI.ChangeWidget(Id(:policies), :Enabled, true)
        UI.ChangeWidget(Id(:policies), :Value, retainPolicies)
      else
        UI.ChangeWidget(Id(:container), :Enabled, true)
        UI.ChangeWidget(Id(:policies), :Enabled, true)
        if convert
          UI.ChangeWidget(Id(:policies), :Value, retainPolicies)
        else
          UI.ChangeWidget(Id(:policies), :Value, false)
        end
      end
      if Edirectory.nameMapCheck
        UI.ChangeWidget(Id(:container), :Enabled, true)
        UI.ChangeWidget(Id(:policies), :Enabled, true)
        UI.ChangeWidget(Id(:policies), :Value, retainPolicies)
      end

      primary_server = NovellLDAP.BrowseButtonLdapServer(nil)
      ldap_servers = Ops.get_string(primary_server, "CONFIG_LDAP_SERVER_IP", "")
      ldap_sport = Ops.get_integer(
        primary_server,
        "CONFIG_LDAP_SECURE_PORT",
        636
      )
      if NovellLDAP.IsLocalLDAPRunning != 0
        UI.ChangeWidget(Id(:browse_container), :Enabled, false)
      end

      if !(NovellLDAP.IsLocalLDAPRunning == 0 ||
          Ops.get_string(Edirectory.EdirSettings, "CONFIG_EDIR_TREE_TYPE", "") == "existing")
        UI.ChangeWidget(Id(:browse_container), :Enabled, false)
      else
        UI.ChangeWidget(Id(:browse_container), :Enabled, true)
      end

      UI.ChangeWidget(Id(:adminName), :Enabled, false) # NOTE: XAD cannot allow modification to admin name.  Must be based on the DNS domain name
      UI.SetFocus(Id(:pw1))

      ret = nil
      while true
        ret = UI.UserInput
        adminName = Convert.to_string(UI.QueryWidget(Id(:adminName), :Value))
        adminPassword = Convert.to_string(UI.QueryWidget(Id(:pw1), :Value))
        # abort?
        container = Convert.to_string(UI.QueryWidget(Id(:container), :Value))
        retainPolicies2 = Convert.to_boolean(
          UI.QueryWidget(Id(:policies), :Value)
        )

        if ret == :abort || ret == :cancel
          if ReallyAbort()
            break
          else
            next
          end
        elsif ret == :next
          pw1 = adminPassword
          pw2 = Convert.to_string(UI.QueryWidget(Id(:pw2), :Value))

          if !NovellValidators.ValidatePasswords(pw1, pw2)
            UI.ChangeWidget(Id(:pw1), :Value, "")
            UI.ChangeWidget(Id(:pw2), :Value, "")
            UI.SetFocus(Id(:pw1))
            next
          end

          # Save the data
          Ops.set(Edirectory.EdirSettings, "XAD_ADMIN_PASSWORD", adminPassword)
          Ops.set(
            Edirectory.EdirSettings,
            "DOMAIN_PASSWORD_BACK",
            adminPassword
          )
          if XadNameMappingNextButton(
              convert,
              container,
              domain_type,
              retainPolicies2
            ) == :continue
            next
          end
          break
        elsif ret == :browse_container
          primary_server2 = NovellLDAP.BrowseButtonLdapServer(nil)
          ldap_servers2 = Ops.get_string(
            primary_server2,
            "CONFIG_LDAP_SERVER_IP",
            ""
          )
          ldap_sport2 = Ops.get_integer(
            primary_server2,
            "CONFIG_LDAP_SECURE_PORT",
            636
          )

          adminDn = Ops.get_string(
            NovellLDAP.Settings,
            "CONFIG_LDAP_ADMIN_CONTEXT",
            ""
          )
          adminPassword2 = Ops.get_string(
            NovellLDAP.Settings,
            "CONFIG_LDAP_ADMIN_PASSWORD",
            ""
          )
          if Edirectory.xad_packages_installed
            xad_tree_admin_context = Ops.get_string(
              NovellLDAP.Settings,
              "XAD_TREE_ADMIN_CONTEXT",
              ""
            )
            Builtins.y2milestone(
              "eDirectory:XAD_TREE_ADMIN_CONTEXT:%1",
              xad_tree_admin_context
            )
            if xad_tree_admin_context != nil && xad_tree_admin_context != ""
              adminDn = NovellUtils.Nds2Ldap(xad_tree_admin_context)
              adminPassword2 = Ops.get_string(
                NovellLDAP.Settings,
                "XAD_TREE_ADMIN_PASSWORD",
                ""
              )
            end
          end
          adminDn = NovellUtils.Nds2Ldap(adminDn)
          Builtins.y2milestone("eDirectory:admin:%1", adminDn)
          container2 = NovellLdapBrowser.LdapBrowser(
            ldap_servers2,
            ldap_sport2,
            true,
            adminDn,
            adminPassword2,
            "",
            "(|(ObjectClass=Organization)(ObjectClass=OrganizationalUnit)(ObjectClass=Domain)(ObjectClass=Locality)(ObjectClass=Country))",
            _("Browse for container")
          )

          Builtins.y2milestone(
            Builtins.sformat(
              "dialogs.ycp.NewOrExistingDialog:container from browse is: '%1'",
              container2
            )
          )
          if container2 != nil && container2 != ""
            container2 = NovellUtils.Nds2Ldap(container2)
            UI.ChangeWidget(Id(:container), :Value, container2)
          end
        elsif ret == :back
          break
        else
          Builtins.y2error("unexpected retcode: %1", ret)
          next
        end
      end
      deep_copy(ret)
    end

    # Existing Tree dialog
    # @return dialog result
    def ExistingTreeDialog
      Builtins.y2milestone("Entering Edirectory Existing Tree Dialog()")
      # Edirectory  ExistingTreeDialog caption
      caption = _("eDirectory Configuration - Existing Tree Information")

      # Edirectory ExsitingTreeDialog contents
      adminName = Ops.get_string(
        NovellLDAP.Settings,
        "CONFIG_LDAP_ADMIN_CONTEXT",
        ""
      )
      adminPassword = Ops.get_string(
        NovellLDAP.Settings,
        "CONFIG_LDAP_ADMIN_PASSWORD",
        ""
      )

      serverStr = _(
        "&IP Address / Hostname of an existing eDirectory server with a replica"
      )

      if Ops.get_string(Edirectory.EdirSettings, "XAD_SERVICE_CONFIGURED", "no") == "yes"
        adminName = Ops.get_string(
          Edirectory.EdirSettings,
          "XAD_LDAP_ADMIN_CONTEXT",
          ""
        )
        adminPassword = Ops.get_string(
          Edirectory.EdirSettings,
          "XAD_LDAP_ADMIN_PASSWORD",
          ""
        )
      end

      adminPassword2 = adminPassword
      replica_address = Ops.get_string(
        Edirectory.EdirSettings,
        "CONFIG_EDIR_REPLICA_SERVER",
        ""
      )

      installType = "adc"
      if replica_address == nil || replica_address == ""
        if Ops.get_string(
            Edirectory.EdirSettings,
            "XAD_SERVICE_CONFIGURED",
            "no"
          ) == "yes"
          if Ops.get_string(Edirectory.EdirSettings, "XAD_DOMAIN_TYPE", "") == "controller" ||
              Ops.get_string(Edirectory.EdirSettings, "XAD_DOMAIN_TYPE", "") == "domain"
            if Ops.get_string(Edirectory.EdirSettings, "XAD_DOMAIN_TYPE", "") == "domain"
              installType = "child"
            end
            replica_address = Edirectory.GetServerIP(installType)
          end
        end
      end

      server_list = Ops.get_list(
        NovellLDAP.Settings,
        "CONFIG_LDAP_SERVERS_LIST",
        []
      )
      replica_server = NovellLDAP.GetAddressServer(replica_address, server_list)
      port = Ops.get_integer(replica_server, "CONFIG_LDAP_PORT", 389)
      port = 389 if port == nil || Ops.less_or_equal(port, 0)
      secure_port = Ops.get_integer(
        replica_server,
        "CONFIG_LDAP_SECURE_PORT",
        636
      )
      if secure_port == nil || Ops.less_or_equal(secure_port, 0)
        secure_port = 636
      end
      ncpport = Builtins.tointeger(
        Ops.get_integer(
          Edirectory.EdirSettings,
          "CONFIG_EDIR_EXISTING_NCP_PORT",
          524
        )
      )
      ncpport = 524 if ncpport == nil || Ops.less_or_equal(ncpport, 0)

      contents = HVSquash(
        VBox(
          HBox(
            TextEntry(Id(:replica_address), serverStr, replica_address),
            VBox(Label(""), PushButton(Id(:test), _("&Validate")))
          ),
          IntField(
            Id(:ncpport),
            _("Enter N&CP Port on the existing server"),
            1,
            65535,
            ncpport
          ),
          IntField(
            Id(:port),
            _("Enter &LDAP Port on the existing server"),
            1,
            65535,
            port
          ),
          IntField(
            Id(:secure_port),
            _("Enter &Secure LDAP Port on the existing server"),
            1,
            65535,
            secure_port
          ),
          VBox(
            VSpacing(1),
            TextEntry(
              Id(:adminName),
              _("&FDN of the tree administrator (e.g. cn=admin,o=microfocus)"),
              adminName
            ),
            Left(Password(Id(:pw1), _("Admin &Password"), adminPassword))
          )
        )
      )

      help_section = "existing_tree_a"
      if Ops.get_string(Edirectory.EdirSettings, "XAD_SERVICE_CONFIGURED", "no") == "yes"
        help_section = "existing_tree_dsfw_a"
      end

      Wizard.SetContentsButtons(
        caption,
        contents,
        Ops.add(
          Ops.get_string(@HELPS, help_section, ""),
          Ops.get_string(@HELPS, "existing_tree", "")
        ),
        Label.BackButton,
        Label.NextButton
      )

      if replica_address == nil || replica_address == ""
        UI.SetFocus(Id(:replica_address))
      else
        UI.SetFocus(Id(:adminName))
      end

      if Ops.get_string(Edirectory.EdirSettings, "XAD_SERVICE_CONFIGURED", "no") == "yes"
        UI.ChangeWidget(Id(:migrate), :Value, false)
        UI.ChangeWidget(Id(:migrate), :Enabled, false)
      end

      ret = nil
      while true
        ret = UI.UserInput

        # Get the data
        replica_address = Convert.to_string(
          UI.QueryWidget(Id(:replica_address), :Value)
        )
        ncpport = Convert.to_integer(UI.QueryWidget(Id(:ncpport), :Value))
        port = Convert.to_integer(UI.QueryWidget(Id(:port), :Value))
        secure_port = Convert.to_integer(
          UI.QueryWidget(Id(:secure_port), :Value)
        )
        adminName = Convert.to_string(UI.QueryWidget(Id(:adminName), :Value))
        adminPassword = Convert.to_string(UI.QueryWidget(Id(:pw1), :Value))

        # abort?
        if ret == :abort || ret == :cancel
          if ReallyAbort()
            break
          else
            next
          end
        # Next clicked
        elsif ret == :next
          pw1 = adminPassword
          if EdirUtils.isLDAPdn(adminName)
            adminName = NovellUtils.Ldap2Nds(adminName)
          end

          next if !NovellValidators.ValidateFDN(adminName, false)

          # Check IP address
          if !Address.Check4(replica_address)
            if replica_address != ""
              Popup.Error(Address.Valid4)
            else
              Popup.Error(
                _(
                  "Enter the IP address / hostname of an existing server in the tree."
                )
              )
            end
            next
          else
            local_addresses = Convert.convert(
              NovellUtils.GetAllStaticIPAddrs,
              :from => "list",
              :to   => "list <string>"
            )
            found = 0
            found = 1 if Builtins.contains(local_addresses, replica_address)
            if replica_address == NovellUtils.GetHostname ||
                replica_address == NovellUtils.GetDNSname
              found = 1
            end
            if found == 1
              Report.Error(
                _(
                  "The replica server IP address / hostname must be a remote (non-local) address."
                )
              )
              replica_address = ""
              UI.ChangeWidget(Id(:replica_address), :Value, replica_address)
              UI.SetFocus(Id(:replica_address))
              next
            end
          end
          if !NovellUtils.Ping_IP(replica_address)
            erMsg = Builtins.sformat(
              _(
                "The specified IP address / hostname (%1) is either not reachable or unresolvable.\nDo you want to continue anyway?"
              ),
              replica_address
            )

            next if Popup.ContinueCancel(erMsg) == false
          end

          # Validate that the existing server is part of the
          # expected tree
          if Edirectory.autoyast_tool == false
            givenTreeName = Builtins.toupper(
              Ops.get_string(NovellLDAP.Settings, "CONFIG_LDAP_TREE_NAME", "")
            )
            foundTree = Edirectory.GetTreeName(replica_address, ncpport)
            foundTree = Builtins.substring(
              foundTree,
              0,
              Ops.subtract(Builtins.size(foundTree), 1)
            )
            if foundTree != givenTreeName
              goon = Popup.AnyQuestion(
                _("Tree names do not match"),
                Builtins.sformat(
                  _(
                    "At the address specified the \"%1\" tree responded.\nThe name of the tree that you requested to join is: %2"
                  ),
                  foundTree,
                  givenTreeName
                ),
                _("Continue"),
                _("Cancel"),
                :focus_no
              )

              next if !goon
            end

            # Validate the credentails against the Existing Tree
            if Edirectory.xadTestMode == false
              val = NovellValidators.ValidateCredentials(
                adminName,
                adminPassword,
                replica_address,
                secure_port,
                true
              )
              if val != 0
                Builtins.y2milestone("ValidateCredentials() returned %1", val)
                if val == -666
                  err = _(
                    "The attempt to perform a secure LDAP bind did not respond in 2 minutes\n" +
                      "This may indicate a problem with LDAP on the target server.\n" +
                      "If you are confident that your credentials are correct you may continue,\n" +
                      "otherwise please determine if LDAP is running correctly on the target system\n" +
                      "Do you want to continue?"
                  )
                  yes = Popup.YesNoHeadline(_("LDAP secure bind timeout"), err)
                  next if !yes
                else
                  err = Builtins.sformat(
                    _(
                      "User credentials failed to validate Using:\n" +
                        "      Server: %1\n" +
                        "      User: %2\n" +
                        "      LDAP port: %3\n" +
                        "Do you want to continue anyway?"
                    ),
                    replica_address,
                    adminName,
                    secure_port
                  )
                  yes = Popup.YesNoHeadline(_("Credentials Failed"), err)
                  next if !yes
                end
              end

              if Ops.get_string(
                  Edirectory.EdirSettings,
                  "XAD_SERVICE_CONFIGURED",
                  "no"
                ) == "yes"
                val = Edirectory.ValidateTreeRootRights(
                  adminName,
                  adminPassword,
                  replica_address,
                  givenTreeName
                )
                if val != 0
                  Builtins.y2milestone(
                    "The admin validation failed with error code %1",
                    val
                  )
                  if val == 253
                    if Popup.ContinueCancel(Edirectory.adminWarning) == false
                      next
                    end
                  end
                  if val == 254
                    Report.Error(
                      Builtins.sformat(
                        _(
                          "The admin %1 doesn't have right on the [root] partition"
                        ),
                        adminName
                      )
                    )
                    next
                  end
                else
                  Builtins.y2milestone(
                    "The validation of the admin %1 passed ",
                    adminName
                  )
                end
              end
            end
            cmd = Builtins.sformat(
              "ldapsearch  -H ldaps://%1:%2 -D '%3' -w '%4' -s base -b '%5'",
              replica_address,
              secure_port,
              NovellUtils.Nds2Ldap(adminName),
              adminPassword,
              NovellUtils.Nds2Ldap(NovellUtils.GetContextNDS(adminName))
            )
            rmap = Convert.to_map(SCR.Execute(path(".target.bash_output"), cmd))

            if Ops.get_integer(rmap, "exit", -1) != 0
              msg = Builtins.sformat(
                _(
                  "The specified IP address / hostname (%1) is not reachable, unresolvable or\nthe hostname is not part of the server certificate."
                ),
                replica_address
              )
              next if Popup.ContinueCancel(msg) == false
            end
          end
          server_list = NovellLDAP.RemoveServersByAddress(
            [Ops.get_string(replica_server, "CONFIG_LDAP_SERVER_IP", "")],
            server_list
          )
          replica_server = {
            "CONFIG_LDAP_SERVER_IP"   => replica_address,
            "CONFIG_LDAP_PORT"        => port,
            "CONFIG_LDAP_SECURE_PORT" => secure_port
          }
          server_list = Builtins.add(server_list, replica_server)

          # Save the data
          Ops.set(
            Edirectory.EdirSettings,
            "CONFIG_EDIR_REPLICA_SERVER",
            replica_address
          )
          Ops.set(
            Edirectory.EdirSettings,
            "CONFIG_EDIR_EXISTING_NCP_PORT",
            ncpport
          )
          Ops.set(NovellLDAP.Settings, "CONFIG_LDAP_SERVERS_LIST", server_list)

          if Ops.get_string(
              Edirectory.EdirSettings,
              "XAD_SERVICE_CONFIGURED",
              "no"
            ) == "yes"
            Ops.set(
              Edirectory.EdirSettings,
              "XAD_LDAP_ADMIN_CONTEXT",
              adminName
            )
            Ops.set(
              Edirectory.EdirSettings,
              "XAD_LDAP_ADMIN_PASSWORD",
              adminPassword
            )
            Ops.set(NovellLDAP.Settings, "XAD_TREE_ADMIN_CONTEXT", adminName)
            Ops.set(
              NovellLDAP.Settings,
              "XAD_TREE_ADMIN_PASSWORD",
              adminPassword
            )

            if Ops.get_string(
                Edirectory.EdirSettings,
                "CONFIG_EDIR_TREE_TYPE",
                ""
              ) == "existing" &&
                Ops.get_string(Edirectory.EdirSettings, "XAD_DOMAIN_TYPE", "") == "forest"
              Ops.set(
                NovellLDAP.Settings,
                "CONFIG_LDAP_ADMIN_PASSWORD",
                Ops.get_string(
                  Edirectory.EdirSettings,
                  "XAD_LDAP_ADMIN_PASSWORD",
                  ""
                )
              )
            end
          else
            Ops.set(NovellLDAP.Settings, "CONFIG_LDAP_ADMIN_CONTEXT", adminName)
            Ops.set(
              NovellLDAP.Settings,
              "CONFIG_LDAP_ADMIN_PASSWORD",
              adminPassword
            )
          end

          if Ops.get_string(
              Edirectory.EdirSettings,
              "XAD_SERVICE_CONFIGURED",
              ""
            ) == "yes"
            domain_type = Ops.get_string(
              Edirectory.EdirSettings,
              "XAD_DOMAIN_TYPE",
              ""
            )
            ret = :xad

            xad_settings = Edirectory.ProposeXadContextSettings(
              Ops.get_string(Edirectory.EdirSettings, "XAD_DOMAIN_TYPE", ""),
              Ops.get_string(Edirectory.EdirSettings, "XAD_DOMAIN_NAME", ""),
              Ops.get_string(Edirectory.EdirSettings, "XAD_FOREST_ROOT", "")
            )
            Ops.set(
              NovellLDAP.Settings,
              "CONFIG_LDAP_ADMIN_CONTEXT",
              Ops.get_string(xad_settings, "CONFIG_LDAP_ADMIN_CONTEXT", "")
            )
          end

          break
        elsif ret == :test
          replicaAddress = Convert.to_string(
            UI.QueryWidget(Id(:replica_address), :Value)
          )
          NovellUtils.ServerIseDirServer(replicaAddress)
        elsif ret == :back
          break
        else
          Builtins.y2error("unexpected retcode: %1", ret)
          next
        end
      end

      deep_copy(ret)
    end


    # ContextAndPorts Dialog
    # @return dialog result
    def ContextAndPortsDialog
      ret = nil
      Builtins.y2milestone("Entering Edirectory ContextandPortsDialog()")

      if Ops.get_string(Edirectory.EdirSettings, "XAD_QUICK_INSTALL", "yes") == "yes"
        if Ops.get_string(
            Edirectory.EdirSettings,
            "BACK_DURING_QUICK_INSTALL",
            ""
          ) == "yes"
          return :back
        end
      end

      # Edirectory ContentAndPorts Dialog caption
      caption = _("eDirectory Configuration - Local Server Configuration")

      doServerContextValidation = true
      tree = Ops.get_string(NovellLDAP.Settings, "CONFIG_LDAP_TREE_NAME", "")
      admin = Ops.get_string(
        NovellLDAP.Settings,
        "CONFIG_LDAP_ADMIN_CONTEXT",
        ""
      )
      adminPassword = Ops.get_string(
        NovellLDAP.Settings,
        "CONFIG_LDAP_ADMIN_PASSWORD",
        ""
      )
      ip = Ops.get_string(
        Edirectory.EdirSettings,
        "CONFIG_EDIR_REPLICA_SERVER",
        ""
      )
      serverContext = Ops.get_string(
        Edirectory.EdirSettings,
        "CONFIG_EDIR_SERVER_CONTEXT",
        ""
      )
      backServerContext = Ops.get_string(
        Edirectory.EdirSettings,
        "BACK_CONFIG_EDIR_SERVER_CONTEXT",
        ""
      )
      backServerContext = "" if backServerContext == nil

      if Ops.get_string(Edirectory.EdirSettings, "EDIR_QUICK_INSTALL", "no") == "no"
        if backServerContext != ""
          serverContext = backServerContext
        else
          if Ops.get_string(
              Edirectory.EdirSettings,
              "XAD_SERVICE_CONFIGURED",
              "no"
            ) != "yes" # only do this check if we are not doing xad
            tree_type = Ops.get_string(
              Edirectory.EdirSettings,
              "CONFIG_EDIR_TREE_TYPE",
              ""
            )
            if tree_type == "existing"
              server_list2 = Ops.get_list(
                NovellLDAP.Settings,
                "CONFIG_LDAP_SERVERS_LIST",
                []
              )
              replica_server = NovellLDAP.GetAddressServer(ip, server_list2)
              port = Ops.get_integer(replica_server, "CONFIG_LDAP_PORT", 389)
              port = 389 if port == nil || Ops.less_or_equal(port, 0)
              secure_port = Ops.get_integer(
                replica_server,
                "CONFIG_LDAP_SECURE_PORT",
                636
              )
              if secure_port == nil || Ops.less_or_equal(secure_port, 0)
                secure_port = 636
              end
              defaultServerContext = NovellUtils.GetServerContext(
                tree,
                admin,
                adminPassword,
                ip,
                port,
                secure_port
              )
              serverContext = defaultServerContext if defaultServerContext != ""
            end
          end
        end
      end

      dibLocation = Ops.get_string(
        Edirectory.EdirSettings,
        "CONFIG_EDIR_DIB_LOCATION",
        "/var/opt/novell/eDirectory/data/dib"
      )

      local_address = Ops.get(
        Convert.convert(
          NovellUtils.GetAllStaticIPAddrs,
          :from => "list",
          :to   => "list <string>"
        ),
        0,
        ""
      )
      server_list = Ops.get_list(
        NovellLDAP.Settings,
        "CONFIG_LDAP_SERVERS_LIST",
        []
      )
      # verify that at least one local address exists in the list
      # this applies to both new and existing trees
      if !NovellLDAP.LocalAddressExists(server_list)
        local_server2 = {
          "CONFIG_LDAP_SERVER_IP"   => local_address,
          "CONFIG_LDAP_PORT"        => 389,
          "CONFIG_LDAP_SECURE_PORT" => 636
        }
        server_list = Builtins.add(server_list, local_server2)
      end

      local_server = NovellLDAP.GetAddressServer(local_address, server_list)
      ldapPort = Ops.get_integer(local_server, "CONFIG_LDAP_PORT", 389)
      ldapPort = 389 if ldapPort == nil || Ops.less_or_equal(ldapPort, 0)
      ldapSPort = Ops.get_integer(local_server, "CONFIG_LDAP_SECURE_PORT", 636)
      ldapSPort = 636 if ldapSPort == nil || Ops.less_or_equal(ldapSPort, 0)

      if Ops.get_string(Edirectory.EdirSettings, "XAD_SERVICE_CONFIGURED", "no") == "yes"
        # bugzilla #252941 - MS apps only use ldap 389 and 636
        ldapPort = 389
        ldapSPort = 636
      end

      iMonitorPort = Ops.get_integer(
        Edirectory.EdirSettings,
        "CONFIG_EDIR_HTTP_PORT",
        8028
      )
      iMonitorSPort = Ops.get_integer(
        Edirectory.EdirSettings,
        "CONFIG_EDIR_HTTPS_PORT",
        8030
      )

      Builtins.y2milestone("DIB LOCATION = %1", dibLocation)

      serverContextPrompt = _("Enter Server &Context")

      if Ops.get_string(Edirectory.EdirSettings, "XAD_SERVICE_CONFIGURED", "no") == "yes"
        serverContextPrompt = _("Server Context")
      end

      if Ops.get_string(Edirectory.EdirSettings, "EDIR_QUICK_INSTALL", "no") == "yes"
        Builtins.foreach(
          Convert.convert(
            NovellUtils.GetAllStaticIPAddrs,
            :from => "list",
            :to   => "list <string>"
          )
        ) do |local_address2|
          local_server = NovellLDAP.GetAddressServer(
            local_address2,
            server_list
          )
          if local_server != nil &&
              Ops.greater_than(Builtins.size(local_server), 0)
            server_list = NovellLDAP.RemoveServersByAddress(
              [Ops.get_string(local_server, "CONFIG_LDAP_SERVER_IP", "")],
              server_list
            )
          end
          local_server = {
            "CONFIG_LDAP_SERVER_IP"   => local_address2,
            "CONFIG_LDAP_PORT"        => ldapPort,
            "CONFIG_LDAP_SECURE_PORT" => ldapSPort
          }
          server_list = Builtins.add(server_list, local_server)
        end

        Ops.set(
          Edirectory.EdirSettings,
          "CONFIG_EDIR_SERVER_CONTEXT",
          serverContext
        )
        Ops.set(
          Edirectory.EdirSettings,
          "BACK_CONFIG_EDIR_SERVER_CONTEXT",
          serverContext
        )
        Ops.set(
          Edirectory.EdirSettings,
          "CONFIG_EDIR_DIB_LOCATION",
          dibLocation
        )
        Ops.set(NovellLDAP.Settings, "CONFIG_LDAP_SERVERS_LIST", server_list)
        Ops.set(Edirectory.EdirSettings, "CONFIG_EDIR_HTTP_PORT", iMonitorPort)
        Ops.set(
          Edirectory.EdirSettings,
          "CONFIG_EDIR_HTTPS_PORT",
          iMonitorSPort
        )

        #puts password into log file
        Builtins.y2debug(
          "Edirectory::EdirSettings: %1",
          Edirectory.EdirSettings
        )

        return :edir
      end

      # Skipping dialog for dsfw express install
      if Ops.get_string(Edirectory.EdirSettings, "XAD_SERVICE_CONFIGURED", "no") == "yes" &&
          Ops.get_string(Edirectory.EdirSettings, "XAD_QUICK_INSTALL", "yes") == "yes"
        Builtins.foreach(
          Convert.convert(
            NovellUtils.GetAllStaticIPAddrs,
            :from => "list",
            :to   => "list <string>"
          )
        ) do |local_address2|
          local_server = NovellLDAP.GetAddressServer(
            local_address2,
            server_list
          )
          if local_server != nil &&
              Ops.greater_than(Builtins.size(local_server), 0)
            server_list = NovellLDAP.RemoveServersByAddress(
              [Ops.get_string(local_server, "CONFIG_LDAP_SERVER_IP", "")],
              server_list
            )
          end
          local_server = {
            "CONFIG_LDAP_SERVER_IP"   => local_address2,
            "CONFIG_LDAP_PORT"        => ldapPort,
            "CONFIG_LDAP_SECURE_PORT" => ldapSPort
          }
          server_list = Builtins.add(server_list, local_server)
        end

        Ops.set(
          Edirectory.EdirSettings,
          "CONFIG_EDIR_SERVER_CONTEXT",
          serverContext
        )
        Ops.set(
          Edirectory.EdirSettings,
          "BACK_CONFIG_EDIR_SERVER_CONTEXT",
          serverContext
        )
        Ops.set(
          Edirectory.EdirSettings,
          "CONFIG_EDIR_DIB_LOCATION",
          dibLocation
        )
        Ops.set(NovellLDAP.Settings, "CONFIG_LDAP_SERVERS_LIST", server_list)
        Ops.set(Edirectory.EdirSettings, "CONFIG_EDIR_HTTP_PORT", iMonitorPort)
        Ops.set(
          Edirectory.EdirSettings,
          "CONFIG_EDIR_HTTPS_PORT",
          iMonitorSPort
        )

        #puts password into log file
        Builtins.y2debug(
          "Edirectory::EdirSettings: %1",
          Edirectory.EdirSettings
        )

        if Ops.get_string(
            Edirectory.EdirSettings,
            "XAD_SERVICE_CONFIGURED",
            "no"
          ) == "yes"
          ret = :xad
        end

        return deep_copy(ret)
      end

      contents = HVSquash(
        MinWidth(
          60,
          VBox(
            MinWidth(
              60,
              HBox(
                TextEntry(
                  Id(:serverContext),
                  serverContextPrompt,
                  serverContext
                ),
                VBox(Label(""), PushButton(Id(:browse), _("Browse")))
              )
            ),
            TextEntry(
              Id(:dibLoc),
              _("&Directory Information Base (DIB) Location"),
              dibLocation
            ),
            VSpacing(2),
            IntField(Id(:ldapPort), _("Enter &LDAP Port"), 1, 65535, ldapPort),
            IntField(
              Id(:ldapSPort),
              _("Enter &Secure LDAP Port"),
              1,
              65535,
              ldapSPort
            ),
            IntField(
              Id(:iMonitorPort),
              _("Enter &iMonitor Port"),
              1,
              65535,
              iMonitorPort
            ),
            IntField(
              Id(:iMonitorSPort),
              _("Enter Secure i&Monitor Port"),
              1,
              65535,
              iMonitorSPort
            )
          )
        )
      )


      helps = Ops.get_string(@HELPS, "contextAndPorts", "")
      if Ops.get_string(Edirectory.EdirSettings, "XAD_SERVICE_CONFIGURED", "no") == "yes"
        helps = Ops.get_string(@HELPS, "contextAndPorts_ndsw", "")
      end

      Wizard.SetContentsButtons(
        caption,
        contents,
        helps,
        Label.BackButton,
        Label.NextButton
      )
      UI.SetFocus(Id(:serverContext))

      UI.ChangeWidget(
        Id(:serverContext),
        :Enabled,
        Ops.get_string(Edirectory.EdirSettings, "XAD_SERVICE_CONFIGURED", "no") != "yes"
      ) # NOTE: Special case! XAD cannot allow modification to server context.  Must be based on the DNS domain name
      UI.ChangeWidget(
        Id(:browse),
        :Enabled,
        Ops.get_string(Edirectory.EdirSettings, "XAD_SERVICE_CONFIGURED", "no") != "yes"
      ) # MS apps only use 636 ldap
      UI.ChangeWidget(
        Id(:ldapPort),
        :Enabled,
        Ops.get_string(Edirectory.EdirSettings, "XAD_SERVICE_CONFIGURED", "no") != "yes"
      ) # MS apps only use 389 ldap
      UI.ChangeWidget(
        Id(:ldapSPort),
        :Enabled,
        Ops.get_string(Edirectory.EdirSettings, "XAD_SERVICE_CONFIGURED", "no") != "yes"
      ) # MS apps only use 636 ldap


      if serverContext == nil || serverContext == ""
        adminName = Ops.get_string(
          NovellLDAP.Settings,
          "CONFIG_LDAP_ADMIN_CONTEXT",
          ""
        )
        tmp = NovellUtils.GetContextNDS(adminName)
        UI.ChangeWidget(Id(:serverContext), :Value, tmp)
      end

      while true
        # For new tree server context browse is disabled
        if Ops.get_string(Edirectory.EdirSettings, "CONFIG_EDIR_TREE_TYPE", "") == "new"
          UI.ChangeWidget(Id(:browse), :Enabled, false)
        end
        ret = UI.UserInput

        # Read the data back from the dialog
        serverContext2 = Convert.to_string(
          UI.QueryWidget(Id(:serverContext), :Value)
        )
        dibLocation2 = Convert.to_string(UI.QueryWidget(Id(:dibLoc), :Value))
        ldapPort2 = Convert.to_integer(UI.QueryWidget(Id(:ldapPort), :Value))
        ldapSPort2 = Convert.to_integer(UI.QueryWidget(Id(:ldapSPort), :Value))
        iMonitorPort2 = Convert.to_integer(
          UI.QueryWidget(Id(:iMonitorPort), :Value)
        )
        iMonitorSPort2 = Convert.to_integer(
          UI.QueryWidget(Id(:iMonitorSPort), :Value)
        )

        # abort?
        if ret == :abort || ret == :cancel
          if ReallyAbort()
            break
          else
            next
          end
        elsif ret == :next
          if doServerContextValidation
            if EdirUtils.isLDAPdn(serverContext2)
              serverContext2 = NovellUtils.Ldap2Nds(serverContext2)
            end

            next if !NovellValidators.ValidateContext(serverContext2)
          end

          next if !NovellValidators.ValidatePathname(dibLocation2, true)
	  if dibLocation2 == ""
             Popup.Error(_("The DIB location field cannot be empty"))
	     next
	  end
	  
	  dib = dibLocation2
	  found=false
          begin
            if FileUtils.Exists(dib)
              cmd = "/usr/bin/stat \-f \-\-printf=\"%T\" "
              cmd = Ops.add(cmd,dib)
              val = Convert.to_map(SCR.Execute(path(".target.bash_output"), cmd))
              stdout = NovellUtils.CleanUpString(Ops.get_string(val, "stdout", ""))
              if stdout == "btrfs"
                found=true
                break
	      else
		 break
              end
            else
              cmd=Builtins.sformat("/usr/bin/dirname %1",dib)
              val = Convert.to_map(SCR.Execute(path(".target.bash_output"), cmd))
              dib = NovellUtils.CleanUpString(Ops.get_string(val, "stdout", ""))
            end
          end until dib == "/" &&  Builtins.size(dib) >= 1

          if found
            Popup.Error(_("eDirectory does not support Btrfs file system. Specify the\n
EXT4, EXT3, or XFS path in the Directory Information Base (DIB)\nLocation field.\n\nIf a new partition needs to be created, you must abort this\nconfiguration. If the default path needs to be modified,\nchange the path of the eDirectory DIB in the OES eDirectory\nConfiguration page."))
            next
          end

          dib = dibLocation2
          ext = Builtins.regexpmatch(dib, "data/dib$")
	  if ext
	    num=0
	    while num < 2
              cmd=Builtins.sformat("/usr/bin/dirname %1",dib)
              val = Convert.to_map(SCR.Execute(path(".target.bash_output"), cmd))
              dib = NovellUtils.CleanUpString(Ops.get_string(val, "stdout", ""))
	      num = num +1	
	    end
          end
          if !FileUtils.Exists(dib)
            Popup.Error(Builtins.sformat(_("%1 directory does not exist"),dib))
            next
          end

          Builtins.foreach(
            Convert.convert(
              NovellUtils.GetAllStaticIPAddrs,
              :from => "list",
              :to   => "list <string>"
            )
          ) do |local_address2|
            local_server = NovellLDAP.GetAddressServer(
              local_address2,
              server_list
            )
            if local_server != nil &&
                Ops.greater_than(Builtins.size(local_server), 0)
              server_list = NovellLDAP.RemoveServersByAddress(
                [Ops.get_string(local_server, "CONFIG_LDAP_SERVER_IP", "")],
                server_list
              )
            end
            local_server = {
              "CONFIG_LDAP_SERVER_IP"   => local_address2,
              "CONFIG_LDAP_PORT"        => ldapPort2,
              "CONFIG_LDAP_SECURE_PORT" => ldapSPort2
            }
            server_list = Builtins.add(server_list, local_server)
          end

          Ops.set(
            Edirectory.EdirSettings,
            "CONFIG_EDIR_SERVER_CONTEXT",
            serverContext2
          )
          Ops.set(
            Edirectory.EdirSettings,
            "BACK_CONFIG_EDIR_SERVER_CONTEXT",
            serverContext2
          )
          Ops.set(
            Edirectory.EdirSettings,
            "CONFIG_EDIR_DIB_LOCATION",
            dibLocation2
          )
          Ops.set(NovellLDAP.Settings, "CONFIG_LDAP_SERVERS_LIST", server_list)
          Ops.set(
            Edirectory.EdirSettings,
            "CONFIG_EDIR_HTTP_PORT",
            iMonitorPort2
          )
          Ops.set(
            Edirectory.EdirSettings,
            "CONFIG_EDIR_HTTPS_PORT",
            iMonitorSPort2
          )

          #puts password into log file
          Builtins.y2debug(
            "Edirectory::EdirSettings: %1",
            Edirectory.EdirSettings
          )

          if Ops.get_string(
              Edirectory.EdirSettings,
              "XAD_SERVICE_CONFIGURED",
              "no"
            ) == "yes"
            ret = :xad
          end

          ret = :edir if !Edirectory.xad_packages_installed

          break
        elsif ret == :browse
          uName = Ops.get_string(
            NovellLDAP.Settings,
            "CONFIG_LDAP_ADMIN_CONTEXT",
            ""
          )
          uPassword = Ops.get_string(
            NovellLDAP.Settings,
            "CONFIG_LDAP_ADMIN_PASSWORD",
            ""
          )

          if Ops.get_string(
              Edirectory.EdirSettings,
              "XAD_SERVICE_CONFIGURED",
              "no"
            ) == "yes"
            uName = Ops.get_string(
              Edirectory.EdirSettings,
              "XAD_LDAP_ADMIN_CONTEXT",
              ""
            )
            uPassword = Ops.get_string(
              Edirectory.EdirSettings,
              "XAD_LDAP_ADMIN_PASSWORD",
              ""
            )
          end

          replica_address = Ops.get_string(
            Edirectory.EdirSettings,
            "CONFIG_EDIR_REPLICA_SERVER",
            ""
          )
          server_list2 = Ops.get_list(
            NovellLDAP.Settings,
            "CONFIG_LDAP_SERVERS_LIST",
            []
          )
          replica_server = NovellLDAP.GetAddressServer(
            replica_address,
            server_list2
          )
          port = Ops.get_integer(replica_server, "CONFIG_LDAP_PORT", 389)
          port = 389 if port == nil || Ops.less_or_equal(port, 0)
          secure_port = Ops.get_integer(
            replica_server,
            "CONFIG_LDAP_SECURE_PORT",
            636
          )
          if secure_port == nil || Ops.less_or_equal(secure_port, 0)
            secure_port = 636
          end

          uName = NovellUtils.Nds2Ldap(uName)

          wrkContainer = NovellLdapBrowser.LdapBrowser(
            Ops.get_string(
              Edirectory.EdirSettings,
              "CONFIG_EDIR_REPLICA_SERVER",
              ""
            ),
            secure_port,
            true,
            uName,
            uPassword,
            "",
            "",
            _("Browse for container")
          )
          Builtins.y2milestone(
            Builtins.sformat(
              "Edirectory.dialogs: server context from browse is: '%1'",
              wrkContainer
            )
          )
          if wrkContainer != nil && wrkContainer != ""
            wrkContainer = NovellUtils.Nds2Ldap(wrkContainer)
            UI.ChangeWidget(Id(:serverContext), :Value, wrkContainer)
          end
        elsif ret == :back
          break
        else
          Builtins.y2error("unexpected retcode: %1", ret)
          next
        end
      end

      deep_copy(ret)
    end

    # NTPDialog
    # @return dialog result
    def NTPDialog
      Builtins.y2milestone("Entering Edirectory NTPDialog()")
      # Edirectory NTPDialog caption
      caption = _("eDirectory Configuration - NTP")

      Ops.set(Edirectory.EdirSettings, "BACK_DURING_QUICK_INSTALL", "no")

      return :back if Edirectory.quickInstallBackButtonClicked
      if Ops.get_string(Edirectory.EdirSettings, "EDIR_QUICK_INSTALL", "no") == "yes"
        return :edir
      end

      # Edirectory NTPDialog contents

      # IP or DNS of a Valid NTP time server
      timeServers = Ops.get_list(
        Edirectory.EdirSettings,
        "CONFIG_EDIR_NTP_SERVERS",
        []
      )

      use_local_clock = true
      useLocalClock = Ops.get_string(
        Edirectory.EdirSettings,
        "CONFIG_EDIR_NTP_USE_LOCAL_CLOCK",
        ""
      )
      useLocalClock = "no" if useLocalClock == nil || useLocalClock == ""
      use_local_clock = false if Builtins.tolower(useLocalClock) != "yes"

      # Create the table of time servers for GUI display
      id_num_t = 0
      time_table_items = []
      Builtins.foreach(timeServers) do |s|
        item = Item(Id(id_num_t), s)
        time_table_items = Builtins.add(time_table_items, item)
        id_num_t = Ops.add(id_num_t, 1)
      end
      Builtins.y2milestone(
        "GUI table built time servers in table = %1",
        time_table_items
      )

      contents = HVSquash(
        VBox(
          Label(_("Network Time Protocol (NTP) Servers")),
          HBox(
            VSpacing(4),
            Table(
              Id(:timeserver),
              Opt(:notify, :immediate),
              Header(
                # table header
                _("Time Servers")
              ),
              #Table Items
              time_table_items
            )
          ),
          HBox(
            PushButton(Id(:add_time), _("&Add")),
            PushButton(Id(:del_time), _("&Delete"))
          ),
          Left(CheckBox(Id(:useLocalClock), Opt(:notify), _("Use local clock")))
        )
      )

      Wizard.SetContentsButtons(
        caption,
        contents,
        Ops.get_string(@HELPS, "NTP", ""),
        Label.BackButton,
        Label.NextButton
      )
      UI.SetFocus(Id(:timeserver))

      ret = nil

      if use_local_clock
        UI.ChangeWidget(Id(:useLocalClock), :Value, true)
        UI.ChangeWidget(Id(:timeserver), :Enabled, false)
        UI.ChangeWidget(Id(:add_time), :Enabled, false)
        UI.ChangeWidget(Id(:del_time), :Enabled, false)
      else
        UI.ChangeWidget(Id(:useLocalClock), :Value, false)
        UI.ChangeWidget(Id(:timeserver), :Enabled, true)
        UI.ChangeWidget(Id(:add_time), :Enabled, true)
        UI.ChangeWidget(Id(:del_time), :Enabled, true)
      end

      while true
        ret = UI.UserInput
        Builtins.y2milestone("GUI returned %1", ret)

        if ret == :add_time
          newip = ""
          contents2 = HVSquash(
            VBox(
              TextEntry(Id(:serverip_t), _("Time &Server")),
              HBox(
                Left(PushButton(Id(:add_t), Opt(:default, :key_F3), _("&Add"))),
                Left(PushButton(Id(:cancel_t), Opt(:key_F4), _("&Cancel")))
              )
            )
          )
          UI.OpenDialog(Opt(:decorated), contents2)
          UI.SetFocus(Id(:serverip_t))
          while true
            ret2 = UI.UserInput
            if ret2 == :cancel_t
              UI.CloseDialog
              break
            elsif ret2 == :add_t
              newip = Convert.to_string(UI.QueryWidget(Id(:serverip_t), :Value))
              if !NovellValidators.ValidateDNSorIP(newip)
                # The validator has its own error message
                next
              end
              if Builtins.contains(timeServers, newip)
                Report.Error(
                  Builtins.sformat(
                    _("An entry for the server %1 already exists."),
                    newip
                  )
                )
                next
              end
              UI.CloseDialog
              # Add the new ip to the servers in table list
              timeServers = Builtins.add(timeServers, newip)
              new_item = Item(Id(id_num_t), newip)
              Builtins.y2milestone(
                "Adding %1 as to list as item %2",
                new_item,
                id_num_t
              )
              time_table_items = Builtins.add(time_table_items, new_item)
              id_num_t = Ops.add(id_num_t, 1)
              UI.ChangeWidget(Id(:timeserver), :Items, time_table_items)
              break
            end
          end
        elsif ret == :del_time
          num = -1
          num = Convert.to_integer(
            UI.QueryWidget(Id(:timeserver), :CurrentItem)
          )
          Builtins.y2milestone("Entry to delete num = %1", num)
          next if num == nil
          if Ops.greater_or_equal(num, 0)
            timeServers = Builtins.remove(timeServers, num)
            time_table_items = Builtins.remove(time_table_items, num)
            #Recompress the table
            id_num_t = 0
            new_table = []
            Builtins.foreach(time_table_items) do |t|
              item = Item(Id(id_num_t), Ops.get_string(t, 1, ""))
              new_table = Builtins.add(new_table, item)
              id_num_t = Ops.add(id_num_t, 1)
            end
            time_table_items = deep_copy(new_table)
            UI.ChangeWidget(Id(:timeserver), :Items, time_table_items)
            Builtins.y2milestone(
              "time_table_items after delete = %1",
              time_table_items
            )
            next
          end
        # abort?
        elsif ret == :abort || ret == :cancel
          if ReallyAbort()
            break
          else
            next
          end
        elsif ret == :next
          # Read Values from dialog
          use_local_clock = Convert.to_boolean(
            UI.QueryWidget(Id(:useLocalClock), :Value)
          )
          if use_local_clock
            Ops.set(
              Edirectory.EdirSettings,
              "CONFIG_EDIR_NTP_USE_LOCAL_CLOCK",
              "yes"
            )
          else
            Ops.set(
              Edirectory.EdirSettings,
              "CONFIG_EDIR_NTP_USE_LOCAL_CLOCK",
              "no"
            )
          end

          # Perform VALIDATION
          if use_local_clock == false && Builtins.size(timeServers) == 0
            err = _(
              "You have not specified a time server.\n" +
                " Time synchronization is critical for eDirectory.\n" +
                "If you are joining an existing tree the lack of time\n" +
                "synchronization will cause eDirectory configuration to fail.\n" +
                "If you are creating a new tree you may click the \"Use local clock\" check box to specify the machine's clock"
            )
            Popup.Error(err)
            next
          end
          if use_local_clock
            goOn = true
            Builtins.foreach(timeServers) do |timeServer|
              if !NovellValidators.ValidateDNSorIP(timeServer)
                err = Builtins.sformat(
                  _(
                    "The specification for the NTP time server (%1) is not a valid IP address or DNS name"
                  ),
                  timeServer
                )
                next
              end
              # ntpdate will not work if ntp is running so we stop the service
              Service.Stop("ntpd")
              if !NovellValidators.ValidateNTPServer(timeServer)
                err = Builtins.sformat(
                  _(
                    "The server %1 did not respond\n" +
                      "to an ntpdate request. This may indicate that\n" +
                      "it is not an NTP server."
                  ),
                  timeServer
                )
                goOn = Popup.YesNoHeadline(err, _("Continue anyway?"))
                raise Break if !goOn
              end
            end
            next if !goOn
          end

          # Validation complete save data
          Ops.set(
            Edirectory.EdirSettings,
            "CONFIG_EDIR_NTP_SERVERS",
            timeServers
          )
          Builtins.y2debug(
            "Final data for eDirectory: %1",
            Edirectory.EdirSettings
          )

          if Ops.get_string(
              Edirectory.EdirSettings,
              "XAD_SERVICE_CONFIGURED",
              "no"
            ) == "yes"
            ret = :xad
          end

          ret = :edir if !Edirectory.xad_packages_installed

          break
        elsif ret == :useLocalClock
          if Convert.to_boolean(UI.QueryWidget(Id(:useLocalClock), :Value))
            UI.ChangeWidget(Id(:timeserver), :Value, "")
            UI.ChangeWidget(Id(:timeserver), :Enabled, false)
            UI.ChangeWidget(Id(:add_time), :Enabled, false)
            UI.ChangeWidget(Id(:del_time), :Enabled, false)
          else
            UI.ChangeWidget(Id(:timeserver), :Enabled, true)
            UI.ChangeWidget(Id(:add_time), :Enabled, true)
            UI.ChangeWidget(Id(:del_time), :Enabled, true)
            UI.SetFocus(Id(:add_time))
          end
          next
        elsif ret == :back
          # Save current data
          Ops.set(
            Edirectory.EdirSettings,
            "CONFIG_EDIR_NTP_SERVERS",
            timeServers
          )

          use_local_clock = Convert.to_boolean(
            UI.QueryWidget(Id(:useLocalClock), :Value)
          )
          if use_local_clock
            Ops.set(
              Edirectory.EdirSettings,
              "CONFIG_EDIR_NTP_USE_LOCAL_CLOCK",
              "yes"
            )
          else
            Ops.set(
              Edirectory.EdirSettings,
              "CONFIG_EDIR_NTP_USE_LOCAL_CLOCK",
              "no"
            )
          end

          break
        else
          Builtins.y2error("unexpected retcode: %1", ret)
          next
        end
      end
      deep_copy(ret)
    end

    # SLPDialog
    # @return dialog result
    def SLPDialog
      Builtins.y2milestone("Entering Edirectory SLPDialog()")

      if Ops.get_string(Edirectory.EdirSettings, "XAD_QUICK_INSTALL", "yes") == "yes"
        if Ops.get_string(
            Edirectory.EdirSettings,
            "BACK_DURING_QUICK_INSTALL",
            ""
          ) == "yes"
          return :back
        end
      end

      if Edirectory.quickInstallBackButtonClicked
        Edirectory.quickInstallBackButtonClicked = false
        return :back
      end

      # Skipping dialog for edir express install and default values are calculated in the dialog itself.
      if NovellUtils.edir_quick_install
        Ops.set(Edirectory.EdirSettings, "EDIR_QUICK_INSTALL", "yes")
      else
        Ops.set(Edirectory.EdirSettings, "EDIR_QUICK_INSTALL", "no")
      end
      if Ops.get_string(Edirectory.EdirSettings, "EDIR_QUICK_INSTALL", "no") == "yes"
        return :edir
      end

      # Edirectory SLPDialog caption
      caption = _("eDirectory Configuration - SLP")

      # Edirectory SLPDialog contents

      # Supported modes
      # "none"      - don't use SLP
      # "multicast" - use SLP with multicast enabled
      # "da"        - use SLP with a Directory Agent SPecification
      # "da_server" - become a DA server
      slpMode = Ops.get_string(
        Edirectory.EdirSettings,
        "CONFIG_EDIR_SLP_MODE",
        "none"
      )
      backupInterval = Builtins.tointeger(
        Ops.get_string(
          Edirectory.EdirSettings,
          "CONFIG_EDIR_SLP_BACKUP_INTERVAL",
          "900"
        )
      )
      do_backup = Ops.get_string(
        Edirectory.EdirSettings,
        "CONFIG_EDIR_SLP_BACKUP",
        "yes"
      )
      doDASyncReg = Ops.get_string(
        Edirectory.EdirSettings,
        "CONFIG_EDIR_DASYNC",
        "no"
      )

      doSync = false
      doSync = true if doDASyncReg == "yes"

      doBackup = true
      doBackup = false if do_backup == "no"

      # Address or DNS of a valid SLP DA
      slpDA = Ops.get_list(Edirectory.EdirSettings, "CONFIG_EDIR_SLP_DA", [])
      # SLP scopes to accept
      slpScopes = Ops.get_string(
        Edirectory.EdirSettings,
        "CONFIG_EDIR_SLP_SCOPES",
        "DEFAULT"
      )

      # Create the table of SLP DA servers for GUI display
      id_num = 0
      table_items = []
      Builtins.foreach(slpDA) do |s|
        item = Item(Id(id_num), s)
        table_items = Builtins.add(table_items, item)
        id_num = Ops.add(id_num, 1)
      end
      Builtins.y2milestone("GUI table built SLPDA's in table = %1", table_items)
      slpconf_DAString = Convert.to_string(
        SCR.Read(path(".oes.slp.value.\"net.slp.DAAddresses\""))
      )
      readOk = Convert.to_string(
        SCR.Read(path(".oes.slp.value.\"net.slp.isDA\""))
      )

      # Skipping dialog for dsfw express install
      if Ops.get_string(Edirectory.EdirSettings, "XAD_SERVICE_CONFIGURED", "no") == "yes" &&
          Ops.get_string(Edirectory.EdirSettings, "XAD_QUICK_INSTALL", "yes") == "yes"
        Ops.set(Edirectory.EdirSettings, "CONFIG_EDIR_SLP_MODE", "multicast")
        if readOk == "true" || slpMode == "da_server"
          Ops.set(Edirectory.EdirSettings, "CONFIG_EDIR_SLP_MODE", "da_server")
        elsif !(slpconf_DAString == nil || slpconf_DAString == "") ||
            slpMode == "da"
          Ops.set(Edirectory.EdirSettings, "CONFIG_EDIR_SLP_MODE", "da")
        elsif slpMode == "multicast"
          Ops.set(Edirectory.EdirSettings, "CONFIG_EDIR_SLP_MODE", "multicast")
        end
        return :next
      end


      # If not previously specified set slpMode to none
      sm = :multicast
      if readOk == "true" || slpMode == "da_server"
        sm = :da_server
      elsif !(slpconf_DAString == nil || slpconf_DAString == "") ||
          slpMode == "da"
        sm = :da
      elsif slpMode == "multicast"
        sm = :multicast
      end

      contents = HVSquash(
        VBox(
          RadioButtonGroup(
            Id(:slpmode),
            Opt(:notify),
            VBox(
              Left(
                RadioButton(
                  Id(:multicast),
                  Opt(:notify),
                  _("Use &multicast to access SLP"),
                  sm == :multicast
                )
              ),
              Left(
                RadioButton(
                  Id(:da),
                  Opt(:notify),
                  _("Configure &SLP to use an existing Directory Agent"),
                  sm == :da
                )
              ),
              Left(
                RadioButton(
                  Id(:da_server),
                  Opt(:notify),
                  _("&Configure as Directory Agent"),
                  sm == :da_server
                )
              ),
              Left(
                HBox(
                  HSpacing(3),
                  CheckBox(Id(:daSync), Opt(:notify), _("S&ynchronize Service Registrations with other Directory Agents"), doSync)
                )
              ),
              Left(
                HBox(
                  HSpacing(3),
                  CheckBox(
                    Id(:doBackup),
                    Opt(:notify),
                    _("Backup SLP Registrations"),
                    doBackup
                  )
                )
              ),
              Left(
                HBox(
                  HSpacing(6),
                  IntField(
                    Id(:backupInterval),
                    _("Backup Interval in Seconds"),
                    1,
                    65535,
                    backupInterval
                  )
                )
              )
            )
          ),
          TextEntry(
            Id(:slpScopes),
            _("Service Location &Protocol Scopes"),
            slpScopes
          ),
          Label(_("Configured SLP Directory Agents")),
          HBox(
            VSpacing(4),
            Table(
              Id(:slpDA),
              Opt(:notify, :immediate),
              Header(
                # table header
                _("SLP Directory Agents")
              ),
              #Table Items
              table_items
            )
          ),
          HBox(
            PushButton(Id(:add), _("&Add")),
            PushButton(Id(:del), _("&Delete"))
          )
        )
      )

      Wizard.SetContentsButtons(
        caption,
        contents,
        Ops.get_string(@HELPS, "SLP", ""),
        Label.BackButton,
        Label.NextButton
      )
      UI.SetFocus(Id(:slpmode))

      ret = nil

      if sm == :da_server
        UI.ChangeWidget(Id(:slpScopes), :Enabled, true)
        UI.ChangeWidget(Id(:daSync), :Enabled, true)
        UI.ChangeWidget(Id(:daSync), :Value, true)
        UI.ChangeWidget(Id(:slpDA), :Enabled, true)
        UI.ChangeWidget(Id(:add), :Enabled, true)
        UI.ChangeWidget(Id(:del), :Enabled, true)
        UI.ChangeWidget(Id(:doBackup), :Enabled, true)
        if Convert.to_boolean(UI.QueryWidget(Id(:doBackup), :Value))
          UI.ChangeWidget(Id(:backupInterval), :Enabled, true)
        else
          UI.ChangeWidget(Id(:backupInterval), :Enabled, false)
        end
      elsif sm == :multicast
        UI.ChangeWidget(Id(:slpScopes), :Enabled, true)
        UI.ChangeWidget(Id(:slpDA), :Enabled, false)
        UI.ChangeWidget(Id(:add), :Enabled, false)
        UI.ChangeWidget(Id(:del), :Enabled, false)
        UI.ChangeWidget(Id(:daSync), :Enabled, false)
        UI.ChangeWidget(Id(:doBackup), :Enabled, false)
        UI.ChangeWidget(Id(:backupInterval), :Enabled, false)
      else
        UI.ChangeWidget(Id(:slpScopes), :Enabled, true)
        UI.ChangeWidget(Id(:slpDA), :Enabled, true)
        UI.ChangeWidget(Id(:add), :Enabled, true)
        UI.ChangeWidget(Id(:del), :Enabled, true)
        UI.ChangeWidget(Id(:daSync), :Enabled, false)
        UI.ChangeWidget(Id(:doBackup), :Enabled, false)
        UI.ChangeWidget(Id(:backupInterval), :Enabled, false)
      end

      while true
        ret = UI.UserInput
        Builtins.y2milestone("GUI returned %1", ret)

        if ret == :multicast || ret == :da || ret == :da_server ||
            ret == :doBackup ||
            ret == :daSync
          if ret == :da_server
            UI.ChangeWidget(Id(:daSync), :Enabled, true)
            UI.ChangeWidget(Id(:daSync), :Value, true)
            UI.ChangeWidget(Id(:slpDA), :Enabled, true)
            UI.ChangeWidget(Id(:add), :Enabled, true)
            UI.ChangeWidget(Id(:del), :Enabled, true)
            UI.ChangeWidget(Id(:slpScopes), :Enabled, true)
            UI.ChangeWidget(Id(:doBackup), :Enabled, true)
            if Convert.to_boolean(UI.QueryWidget(Id(:doBackup), :Value))
              UI.ChangeWidget(Id(:backupInterval), :Enabled, true)
            else
              UI.ChangeWidget(Id(:backupInterval), :Enabled, false)
            end
          elsif ret == :multicast
            UI.ChangeWidget(Id(:slpScopes), :Enabled, true)
            UI.ChangeWidget(Id(:slpDA), :Enabled, false)
            UI.ChangeWidget(Id(:add), :Enabled, false)
            UI.ChangeWidget(Id(:del), :Enabled, false)
            UI.ChangeWidget(Id(:daSync), :Enabled, false)
            UI.ChangeWidget(Id(:doBackup), :Enabled, false)
            UI.ChangeWidget(Id(:backupInterval), :Enabled, false)
          elsif ret == :da
            UI.ChangeWidget(Id(:slpScopes), :Enabled, true)
            UI.ChangeWidget(Id(:slpDA), :Enabled, true)
            UI.ChangeWidget(Id(:add), :Enabled, true)
            UI.ChangeWidget(Id(:del), :Enabled, true)
            UI.ChangeWidget(Id(:daSync), :Enabled, false)
            UI.ChangeWidget(Id(:doBackup), :Enabled, false)
            UI.ChangeWidget(Id(:backupInterval), :Enabled, false)
          elsif ret == :doBackup
            if Convert.to_boolean(UI.QueryWidget(Id(:doBackup), :Value))
              UI.ChangeWidget(Id(:backupInterval), :Enabled, true)
            else
              UI.ChangeWidget(Id(:backupInterval), :Enabled, false)
            end
          elsif ret == :daSync
            UI.ChangeWidget(Id(:slpDA), :Enabled, true)
            UI.ChangeWidget(Id(:add), :Enabled, true)
            UI.ChangeWidget(Id(:del), :Enabled, true)
          end
        elsif ret == :add
          newip = ""
          contents2 = HVSquash(
            VBox(
              TextEntry(Id(:serverip), _("SLP DA &Server")),
              HBox(
                Left(PushButton(Id(:add), Opt(:default, :key_F3), _("&Add"))),
                Left(PushButton(Id(:cancel), Opt(:key_F4), _("&Cancel")))
              )
            )
          )
          UI.OpenDialog(Opt(:decorated), contents2)
          UI.SetFocus(Id(:serverip))
          while true
            ret2 = UI.UserInput
            if ret2 == :cancel
              UI.CloseDialog
              break
            elsif ret2 == :add
              newip = Convert.to_string(UI.QueryWidget(Id(:serverip), :Value))
              if !NovellValidators.ValidateDNSorIP(newip)
                # The validator has its own error message
                next
              end
              if Builtins.contains(slpDA, newip)
                Report.Error(
                  Builtins.sformat(
                    _("An entry for the server %1 already exists."),
                    newip
                  )
                )
                next
              end
              UI.CloseDialog
              # Add the new ip to the servers in table list
              slpDA = Builtins.add(slpDA, newip)
              new_item = Item(Id(id_num), newip)
              Builtins.y2milestone(
                "Adding %1 as to list as item %2",
                new_item,
                id_num
              )
              table_items = Builtins.add(table_items, new_item)
              id_num = Ops.add(id_num, 1)
              UI.ChangeWidget(Id(:slpDA), :Items, table_items)
              break
            end
          end
        elsif ret == :del
          num = -1
          num = Convert.to_integer(UI.QueryWidget(Id(:slpDA), :CurrentItem))
          Builtins.y2milestone("Entry to delete num = %1", num)
          next if num == nil
          if Ops.greater_or_equal(num, 0)
            slpDA = Builtins.remove(slpDA, num)
            table_items = Builtins.remove(table_items, num)
            #Recompress the table
            id_num = 0
            new_table = []
            Builtins.foreach(table_items) do |t|
              item = Item(Id(id_num), Ops.get_string(t, 1, ""))
              new_table = Builtins.add(new_table, item)
              id_num = Ops.add(id_num, 1)
            end
            table_items = deep_copy(new_table)
            UI.ChangeWidget(Id(:slpDA), :Items, table_items)
            Builtins.y2milestone("table_items after delete = %1", table_items)
            next
          end
        # abort?
        elsif ret == :abort || ret == :cancel
          if ReallyAbort()
            break
          else
            next
          end
        elsif ret == :next
          # Read Values from dialog
          sm = Convert.to_symbol(UI.QueryWidget(Id(:slpmode), :CurrentButton))

          slpScopes = Convert.to_string(UI.QueryWidget(Id(:slpScopes), :Value))

          # Start SLP validation
          if sm == :multicast
            goon = Popup.YesNoHeadline(
              _("SLP Configuration"),
              _(
                "For multicast to function properly, you must adjust the firewall.\nDo you want to keep this option?"
              )
            )
            next if !goon
          end

          if sm == :da
            allIP = Convert.convert(
              NovellUtils.GetAllStaticIPAddrs,
              :from => "list",
              :to   => "list <string>"
            )
            Builtins.foreach(allIP) do |local_ip|
              if Builtins.contains(slpDA, local_ip)
                Popup.Error(
                  _(
                    "You cannot specify a local IP address / hostname for the SLP DA."
                  )
                )
                next
              end
            end
          end
          # Validation complete save data
          Ops.set(Edirectory.EdirSettings, "CONFIG_EDIR_SLP_DA", slpDA)
          Ops.set(Edirectory.EdirSettings, "CONFIG_EDIR_SLP_SCOPES", slpScopes)
          if sm == :da
            Ops.set(Edirectory.EdirSettings, "CONFIG_EDIR_SLP_MODE", "da")
          elsif sm == :da_server
            Ops.set(
              Edirectory.EdirSettings,
              "CONFIG_EDIR_SLP_MODE",
              "da_server"
            )
            doDASyncReg = "no"
            doSync = Convert.to_boolean(UI.QueryWidget(Id(:daSync), :Value))
            doDASyncReg = "yes" if doSync

            do_backup = "no"
            doBackup = Convert.to_boolean(UI.QueryWidget(Id(:doBackup), :Value))
            do_backup = "yes" if doBackup

            backupInterval = Convert.to_integer(
              UI.QueryWidget(Id(:backupInterval), :Value)
            )

            Ops.set(Edirectory.EdirSettings, "CONFIG_EDIR_DASYNC", doDASyncReg)
            Ops.set(Edirectory.EdirSettings, "CONFIG_EDIR_SLP_DA", slpDA)
            Ops.set(
              Edirectory.EdirSettings,
              "CONFIG_EDIR_SLP_BACKUP",
              do_backup
            )
            Ops.set(
              Edirectory.EdirSettings,
              "CONFIG_EDIR_SLP_BACKUP_INTERVAL",
              Builtins.sformat("%1", backupInterval)
            )
          elsif sm == :multicast
            Ops.set(
              Edirectory.EdirSettings,
              "CONFIG_EDIR_SLP_MODE",
              "multicast"
            )
          end

          Builtins.y2debug(
            "Final data for eDirectory: %1",
            Edirectory.EdirSettings
          )
          ret = :edir if !Edirectory.xad_packages_installed

          break
        elsif ret == :back
          # Read Values from dialog
          sm = Convert.to_symbol(UI.QueryWidget(Id(:slpmode), :CurrentButton))
          slpScopes = Convert.to_string(UI.QueryWidget(Id(:slpScopes), :Value))

          # Save current data
          Ops.set(Edirectory.EdirSettings, "CONFIG_EDIR_SLP_DA", slpDA)
          Ops.set(Edirectory.EdirSettings, "CONFIG_EDIR_SLP_SCOPES", slpScopes)

          if sm == :da
            Ops.set(Edirectory.EdirSettings, "CONFIG_EDIR_SLP_MODE", "da")
          elsif sm == :da_server
            Ops.set(
              Edirectory.EdirSettings,
              "CONFIG_EDIR_SLP_MODE",
              "da_server"
            )
          elsif sm == :multicast
            Ops.set(
              Edirectory.EdirSettings,
              "CONFIG_EDIR_SLP_MODE",
              "multicast"
            )
          end
          Edirectory.backButtonClicked = true # Tell the DoXadorEdirDialogs() that back was hit.
          break
        else
          Builtins.y2error("unexpected retcode: %1", ret)
          next
        end
      end
      if !Edirectory.xad_packages_installed
        stepOK = false
        stepOK = Edirectory.ConfigureAndStartSLP
        if !stepOK
          err = _("Error configuring and starting SLP")
          Report.Error(err)
        end
      end
      deep_copy(ret)
    end

    # UpgradeServerDialog
    #
    # Used when eDir is upgraded from a prior version.
    # The DIB is not removed in this case.
    #
    # @return dialog result
    def UpgradeServerDialog
      # Edirectory::upgradeMode == true means we are upgrading from
      # OES 1.0 to Cypress or from cypress to oes 2 sp1..
      Builtins.y2milestone("Entering UpgradeServerDialog()")

      # Edirectory  UpgradeServerDialog caption
      caption = _("eDirectory Upgrade - Existing Server Information")

      replicaAddress = Ops.get_string(
        Edirectory.EdirSettings,
        "CONFIG_EDIR_REPLICA_SERVER",
        ""
      )
      tree_type = Ops.get_string(
        Edirectory.EdirSettings,
        "CONFIG_EDIR_TREE_TYPE",
        ""
      )
      missingReplicaIP = false
      isExistingTree = false
      if tree_type == "existing"
        isExistingTree = true
        if replicaAddress == nil || replicaAddress == ""
          missingReplicaIP = true
          Builtins.y2milestone(
            "Edirectory:UpgradeServerDialog:CONFIG_EDIR_REPLICA_SERVER value was missing. Asking for it in the upgrade dialog."
          )
        end 
        # We have decided due to bug #710600 to always display this value and allow the user to change it.
        #	missingReplicaIP = true;
      else
        Builtins.y2milestone(
          "Edirectory:UpgradeServerDialog:tree type was 'new'."
        )
      end

      # Edirectory UpgradeServerDialog contents
      adminName = Ops.get_string(
        NovellLDAP.Settings,
        "CONFIG_LDAP_ADMIN_CONTEXT",
        ""
      )
      domainAdminName = adminName
      adminPassword = Ops.get_string(
        NovellLDAP.Settings,
        "CONFIG_LDAP_ADMIN_PASSWORD",
        ""
      )
      doxad = false
      # boolean doDomainAdmin = false;

      if Ops.get_string(Edirectory.EdirSettings, "XAD_SERVICE_CONFIGURED", "") == "yes"
        if Ops.get_string(Edirectory.EdirSettings, "CONFIG_EDIR_TREE_TYPE", "") == "existing"
          adminName = Ops.get_string(
            NovellLDAP.Settings,
            "XAD_TREE_ADMIN_CONTEXT",
            ""
          )
          adminPassword = Ops.get_string(
            NovellLDAP.Settings,
            "XAD_TREE_ADMIN_PASSWORD",
            ""
          )
          doxad = true
        end 
        #	if( Edirectory::EdirSettings["XAD_DOMAIN_TYPE"]:"" != "forest" )
        #	    doDomainAdmin = true;
      end

      Builtins.y2milestone(
        "Edirectory:UpgradeServerDialog:adminName from ldap:%1",
        adminName
      )

      confMsg = _("&Path to nds.conf file (e.g. /etc/nds.conf)")
      if Mode.update || Mode.autoupgrade
        confMsg = _(
          "&Path to nds.conf file (e.g. /etc/opt/novell/eDirectory/conf/nds.conf)"
        )
      end

      confPath = Ops.get_string(
        Edirectory.EdirSettings,
        "CONFIG_EDIR_OLD_NDSCONF_FILE",
        ""
      )
      if confPath == nil || confPath == ""
        confPath = "/etc/nds.conf"
        if Mode.update || Mode.autoupgrade
          confPath = "/etc/opt/novell/eDirectory/conf/nds.conf"
        end
      end

      overwrite_certs = false
      overWriteCerts = Ops.get_string(
        Edirectory.EdirSettings,
        "CONFIG_EDIR_OVERWRITE_CERT_FILES",
        "no"
      )
      if overWriteCerts == nil || overWriteCerts == ""
        overwrite_certs = false
      else
        overwrite_certs = true if Builtins.tolower(overWriteCerts) == "yes"
      end

      contents = HVSquash(
        VBox(
          isExistingTree ?
            missingReplicaIP ?
              HBox(
                TextEntry(
                  Id(:replicaIP),
                  _(
                    "Specify the IP address / hostname of an eDirectory server that holds a \n" +
                      "writable replica of the context for the server you are upgrading. \n" +
                      "The upgrade will fail on specifying a wrong IP / hostname."
                  ),
                  replicaAddress
                ),
                VBox(Label(""), PushButton(Id(:test), _("&Validate")))
              ) :
              HBox(
                TextEntry(
                  Id(:replicaIP),
                  _(
                    "Please verify that this is the &IP address / hostname of an eDirectory server\n" +
                      "that holds a writable replica of the context for the server\n" +
                      "you are upgrading. If required change this address\n" +
                      "before you proceed, otherwise the upgrade will fail."
                  ),
                  replicaAddress
                ),
                VBox(Label(""), PushButton(Id(:test), _("&Validate")))
              ) :
            Empty(),
          TextEntry(
            Id(:adminName),
            _("&FDN admin name with context (e.g. cn=admin,o=microfocus)"),
            adminName
          ),
          Left(Password(Id(:pw1), _("Admin &Password"), adminPassword)),
          Left(
            MinWidth(
              45,
              HBox(
                TextEntry(Id(:ndsConf), confMsg, confPath),
                VBox(Label(""), PushButton(Id(:browse), _("Browse")))
              )
            )
          ),
          VSpacing(1),
          Left(
            CheckBox(
              Id(:overwrite),
              _("&Use eDirectory Certificates for HTTPS Services"),
              overwrite_certs
            )
          ),
          VSpacing(1),
          #		    (doDomainAdmin) ?
          #			`VBox(
          #				`TextEntry(`id(`dAdminName), _("Domain Admin Context (e.g. cn=admin,o=novell)"), domainAdminName)
          #			)
          #		    :
          #		     `Empty(),
          doxad ?
            VBox(
              Left(
                Password(
                  Id(:pw2),
                  _("&Domain Admin Password"),
                  ""
                )
              )
            ) :
            Empty()
        )
      )

      helps = ""
      if missingReplicaIP
        helps = Ops.get_string(@HELPS, "existing_local_no_replica", "")
      end

      helps = Ops.add(helps, Ops.get_string(@HELPS, "existing_local", ""))
      if doxad
        helps = Ops.add(helps, Ops.get_string(@HELPS, "dsfw_upgrade", ""))
      end

      Wizard.SetContentsButtons(
        caption,
        contents,
        helps,
        Label.BackButton,
        Label.NextButton
      )

      UI.SetFocus(Id(:pw1))

      ret = nil

      while true
        ret = UI.UserInput

        # Get the data
        adminName = Convert.to_string(UI.QueryWidget(Id(:adminName), :Value))
        adminPassword = Convert.to_string(UI.QueryWidget(Id(:pw1), :Value))
        confPath = Convert.to_string(UI.QueryWidget(Id(:ndsConf), :Value))
        if missingReplicaIP || isExistingTree
          replicaAddress = Convert.to_string(
            UI.QueryWidget(Id(:replicaIP), :Value)
          )
        end
        if doxad
          domainAdminPassword = Convert.to_string(
            UI.QueryWidget(Id(:pw2), :Value)
          )
        end
        #	if( doDomainAdmin )
        #	{
        #            domainAdminName = (string)UI::QueryWidget(`id(`dAdminName), `Value);
        #	}

        # abort?
        if ret == :abort || ret == :cancel
          if ReallyAbort()
            break
          else
            next
          end
        # Next clicked
        elsif ret == :next


           #1116991 #1118256
           #Pop-up message required to avoid CDC installation in mixed mode scenario(For Upgrade)
           if Edirectory.xad_packages_installed
             Builtins.y2milestone("XAD Packages are installed")
             xad_type = Convert.to_string(SCR.Read(path(".sysconfig.novell.xad.XAD_DOMAIN_TYPE")))
             if xad_type == "forest" || xad_type == "domain" || xad_type == "controller"
                Report.Warning(
                 _(
                   "All Domain Controllers must have the same version of OES.\nAfter upgrading this Domain Controller, ensure to upgrade\nall the other Domain Controllers in this domain and in\nother domains to the same version of OES."
                  )
                )
             end
           end

          # Validate the replica address if present
          #	    if( missingReplicaIP )
          if isExistingTree
            if !Address.Check4(replicaAddress)
              if replicaAddress != ""
                Popup.Error(Address.Valid4)
              else
                Popup.Error(
                  _(
                    "Enter the IP address / hostname of an existing server with a replica in the tree."
                  )
                )
              end
              next
            else
              local_addresses = Convert.convert(
                NovellUtils.GetAllStaticIPAddrs,
                :from => "list",
                :to   => "list <string>"
              )
              found = 0
              found = 1 if Builtins.contains(local_addresses, replicaAddress)
              if replicaAddress == NovellUtils.GetHostname ||
                  replicaAddress == NovellUtils.GetDNSname
                found = 1
              end
              if found == 1
                Report.Error(
                  _(
                    "The replica server IP address / hostname must be a remote (non-local) address."
                  )
                )
                replicaAddress = ""
                UI.ChangeWidget(Id(:replicaAddress), :Value, replicaAddress)
                UI.SetFocus(Id(:replicaAddress))
                next
              end
            end
            if !NovellUtils.Ping_IP(replicaAddress)
              erMsg = Builtins.sformat(
                _(
                  "The specified IP address / hostname (%1) is either not reachable or unresolvable.\nDo you want to continue anyway?"
                ),
                replicaAddress
              )

              next if Popup.ContinueCancel(erMsg) == false
            end
            Builtins.y2milestone(
              "Edirectory:UpgradeServerDialog:Value from upgrade dialog is %1.",
              replicaAddress
            )
            cmd = Builtins.sformat(
              "ldapsearch  -H ldaps://%1:%2 -D '%3' -w '%4' -s base -b '%5'",
              replicaAddress,
              636,
              NovellUtils.Nds2Ldap(adminName),
              adminPassword,
              NovellUtils.Nds2Ldap(NovellUtils.GetContextNDS(adminName))
            )
            rmap = Convert.to_map(SCR.Execute(path(".target.bash_output"), cmd))
            if Ops.get_integer(rmap, "exit", -1) != 0
              msg = Builtins.sformat(
                _(
                  "The specified IP address / hostname (%1) is not reachable, unresolvable or\nthe hostname is not part of the server certificate."
                ),
                replicaAddress
              )
              next if Popup.ContinueCancel(msg) == false
            end
            Ops.set(
              Edirectory.EdirSettings,
              "CONFIG_EDIR_REPLICA_SERVER",
              replicaAddress
            )
          end
          # Validate the adminName
          if EdirUtils.isLDAPdn(adminName)
            adminName = NovellUtils.Ldap2Nds(adminName)
          end
          next if !NovellValidators.ValidateFDN(adminName, false)

          next if !NovellValidators.ValidatePassword(adminPassword)


          if Ops.get_string(
              Edirectory.EdirSettings,
              "CONFIG_EDIR_TREE_TYPE",
              ""
            ) == "existing"
            remote_server = NovellLDAP.GetAddressServer(
              Ops.get_string(
                Edirectory.EdirSettings,
                "CONFIG_EDIR_REPLICA_SERVER",
                ""
              ),
              nil
            )
            secure_port = Ops.get_integer(
              remote_server,
              "CONFIG_LDAP_SECURE_PORT",
              636
            )
            if secure_port == nil || Ops.less_or_equal(secure_port, 0)
              secure_port = 636
            end
            replica_address = Ops.get_string(
              Edirectory.EdirSettings,
              "CONFIG_EDIR_REPLICA_SERVER",
              ""
            )
            val = NovellValidators.ValidateCredentials(
              adminName,
              adminPassword,
              replica_address,
              secure_port,
              true
            )
            Builtins.y2milestone(
              "edirectory (upgrade) :validating creds. name %1, pass ****, ip %2, port %3",
              adminName,
              replica_address,
              secure_port
            )
            if val != 0
              Builtins.y2milestone("ValidateCredentials() returned %1", val)
              if val == -666
                err = _(
                  "The attempt to perform a secure LDAP bind did not respond in 2 minutes\n" +
                    "This may indicate a problem with LDAP on the target server.\n" +
                    "If you are confident that your credentials are correct you may continue,\n" +
                    "otherwise please determine if LDAP is running correctly on the target system\n" +
                    "Do you want to continue?"
                )
                yes = Popup.YesNoHeadline(_("LDAP secure bind timeout"), err)
                next if !yes
              else
                err = Builtins.sformat(
                  _(
                    "User credentials failed to validate Using:\n" +
                      "      Server: %1\n" +
                      "      User: %2\n" +
                      "      LDAP port: %3\n" +
                      "Do you want to continue anyway?"
                  ),
                  replica_address,
                  adminName,
                  secure_port
                )
                yes = Popup.YesNoHeadline(_("Credentials Failed"), err)
                next if !yes
              end
            end
          end

          if FileUtils.Exists(confPath) == false
            Popup.Error(
              _("The nds.conf file could not be found at the specified path.")
            )
            next
          end

          #            if( doDomainAdmin )
          #	    {
          #               if (!NovellValidators::ValidateFDN( domainAdminName, false ))
          #	        {
          #                    continue;
          #	        }
          #	    }
          if doxad
            next if !NovellValidators.ValidatePassword(domainAdminPassword)
          end

          # Save the data
          overwrite_certs = Convert.to_boolean(
            UI.QueryWidget(Id(:overwrite), :Value)
          )
          if overwrite_certs
            Ops.set(
              Edirectory.EdirSettings,
              "CONFIG_EDIR_OVERWRITE_CERT_FILES",
              "yes"
            )
          else
            Ops.set(
              Edirectory.EdirSettings,
              "CONFIG_EDIR_OVERWRITE_CERT_FILES",
              "no"
            )
          end

          if Ops.get_string(
              Edirectory.EdirSettings,
              "XAD_SERVICE_CONFIGURED",
              ""
            ) == "yes"
            if Ops.get_string(
                Edirectory.EdirSettings,
                "CONFIG_EDIR_TREE_TYPE",
                ""
              ) == "existing"
              Ops.set(NovellLDAP.Settings, "XAD_TREE_ADMIN_CONTEXT", adminName)
              Ops.set(
                NovellLDAP.Settings,
                "XAD_TREE_ADMIN_PASSWORD",
                adminPassword
              )

              Ops.set(
                Edirectory.EdirSettings,
                "XAD_LDAP_ADMIN_CONTEXT",
                adminName
              )
              Ops.set(
                Edirectory.EdirSettings,
                "XAD_LDAP_ADMIN_PASSWORD",
                adminPassword
              )

              if Ops.get_string(Edirectory.EdirSettings, "XAD_DOMAIN_TYPE", "") == "forest"
                Ops.set(
                  Edirectory.EdirSettings,
                  "XAD_ADMIN_PASSWORD",
                  domainAdminPassword
                )
              else
                Ops.set(
                  NovellLDAP.Settings,
                  "CONFIG_LDAP_ADMIN_PASSWORD",
                  domainAdminPassword
                )
              end 

              #		    if( doDomainAdmin )
              #                      NovellLDAP::Settings["CONFIG_LDAP_ADMIN_CONTEXT"] = domainAdminName; # new tree, new forest
            else
              Ops.set(
                NovellLDAP.Settings,
                "CONFIG_LDAP_ADMIN_CONTEXT",
                adminName
              )
              Ops.set(
                NovellLDAP.Settings,
                "CONFIG_LDAP_ADMIN_PASSWORD",
                adminPassword
              )
              Ops.set(
                Edirectory.EdirSettings,
                "XAD_LDAP_ADMIN_CONTEXT",
                adminName
              )
            end
          else
            Ops.set(NovellLDAP.Settings, "CONFIG_LDAP_ADMIN_CONTEXT", adminName)
            Ops.set(
              NovellLDAP.Settings,
              "CONFIG_LDAP_ADMIN_PASSWORD",
              adminPassword
            )
          end
          Ops.set(
            Edirectory.EdirSettings,
            "CONFIG_EDIR_OLD_NDSCONF_FILE",
            confPath
          )
          break
        elsif ret == :browse
          ndsConfPath = Convert.to_string(UI.QueryWidget(Id(:ndsConf), :Value))
          ndsConfPath = UI.AskForExistingFile(
            ndsConfPath,
            "",
            _("Path to nds.conf file")
          )
          UI.ChangeWidget(Id(:ndsConf), :Value, ndsConfPath)
        elsif ret == :test
          replicaAddress = Convert.to_string(
            UI.QueryWidget(Id(:replicaIP), :Value)
          )
          NovellUtils.ServerIseDirServer(replicaAddress)
        elsif ret == :back
          # Save the data
          Ops.set(NovellLDAP.Settings, "CONFIG_LDAP_ADMIN_CONTEXT", adminName)
          Ops.set(
            NovellLDAP.Settings,
            "CONFIG_LDAP_ADMIN_PASSWORD",
            adminPassword
          )
          Ops.set(
            Edirectory.EdirSettings,
            "CONFIG_EDIR_OLD_NDSCONF_FILE",
            confPath
          )
          break
        else
          Builtins.y2error("unexpected retcode: %1", ret)
          next
        end
      end
      deep_copy(ret)
    end

    # NMASOptions dialog
    # @return dialog result
    def NMASOptionsDialog
      if Ops.get_string(Edirectory.EdirSettings, "XAD_QUICK_INSTALL", "yes") == "yes"
        if Ops.get_string(
            Edirectory.EdirSettings,
            "BACK_DURING_QUICK_INSTALL",
            ""
          ) == "yes"
          return :back
        end
      end


      # eDir NMAS login options dialog caption
      caption = _("Novell Modular Authentication Service")


      certMutual = Ops.get_string(
        Edirectory.EdirSettings,
        "CONFIG_EDIR_NMAS_CERTMUTUAL",
        "no"
      )
      certMutual = NovellUtils.Strip(certMutual, " ")
      certMutual = Builtins.tolower(certMutual)
      certMutual = "no" if certMutual == nil || certMutual == ""

      chlg_response = Ops.get_string(
        Edirectory.EdirSettings,
        "CONFIG_EDIR_NMAS_CHLG_RESPONSE",
        "yes"
      )
      chlg_response = NovellUtils.Strip(chlg_response, " ")
      chlg_response = Builtins.tolower(chlg_response)
      chlg_response = "yes" if chlg_response == nil || chlg_response == ""

      digest_md5 = Ops.get_string(
        Edirectory.EdirSettings,
        "CONFIG_EDIR_NMAS_DIGEST_MD5",
        "no"
      )
      digest_md5 = NovellUtils.Strip(digest_md5, " ")
      digest_md5 = Builtins.tolower(digest_md5)
      digest_md5 = "no" if digest_md5 == nil || digest_md5 == ""

      _NDS = Ops.get_string(
        Edirectory.EdirSettings,
        "CONFIG_EDIR_NMAS_NDS",
        "yes"
      )
      _NDS = NovellUtils.Strip(_NDS, " ")
      _NDS = Builtins.tolower(_NDS)
      _NDS = "yes" if _NDS == nil || _NDS == ""

      simpl_password = Ops.get_string(
        Edirectory.EdirSettings,
        "CONFIG_EDIR_NMAS_SIMPWD",
        "no"
      )
      simpl_password = NovellUtils.Strip(simpl_password, " ")
      simpl_password = Builtins.tolower(simpl_password)

      sasl_gssapi = Ops.get_string(
        Edirectory.EdirSettings,
        "CONFIG_EDIR_NMAS_GSSAPI",
        "no"
      )
      sasl_gssapi = NovellUtils.Strip(sasl_gssapi, " ")
      sasl_gssapi = Builtins.tolower(sasl_gssapi)
      sasl_gssapi = "no" if sasl_gssapi == nil || sasl_gssapi == ""

      # Skipping dialog for dsfw express install
      if Ops.get_string(Edirectory.EdirSettings, "XAD_SERVICE_CONFIGURED", "no") == "yes" &&
          Ops.get_string(Edirectory.EdirSettings, "XAD_QUICK_INSTALL", "yes") == "yes"
        Ops.set(Edirectory.EdirSettings, "CONFIG_EDIR_SLP_MODE", "multicast")
        Ops.set(
          Edirectory.EdirSettings,
          "CONFIG_EDIR_NMAS_CERTMUTUAL",
          certMutual
        )
        Ops.set(
          Edirectory.EdirSettings,
          "CONFIG_EDIR_NMAS_CHLG_RESPONSE",
          chlg_response
        )
        Ops.set(
          Edirectory.EdirSettings,
          "CONFIG_EDIR_NMAS_DIGEST_MD5",
          digest_md5
        )
        Ops.set(Edirectory.EdirSettings, "CONFIG_EDIR_NMAS_NDS", _NDS)
        Ops.set(
          Edirectory.EdirSettings,
          "CONFIG_EDIR_NMAS_SIMPWD",
          simpl_password
        )
        Ops.set(Edirectory.EdirSettings, "CONFIG_EDIR_NMAS_GSSAPI", sasl_gssapi)

        return :next
      end
      if Ops.get_string(Edirectory.EdirSettings, "EDIR_QUICK_INSTALL", "no") == "yes"
        Ops.set(
          Edirectory.EdirSettings,
          "CONFIG_EDIR_NMAS_CERTMUTUAL",
          certMutual
        )
        Ops.set(
          Edirectory.EdirSettings,
          "CONFIG_EDIR_NMAS_CHLG_RESPONSE",
          chlg_response
        )
        Ops.set(
          Edirectory.EdirSettings,
          "CONFIG_EDIR_NMAS_DIGEST_MD5",
          digest_md5
        )
        Ops.set(Edirectory.EdirSettings, "CONFIG_EDIR_NMAS_NDS", _NDS)
        Ops.set(
          Edirectory.EdirSettings,
          "CONFIG_EDIR_NMAS_SIMPWD",
          simpl_password
        )
        Ops.set(Edirectory.EdirSettings, "CONFIG_EDIR_NMAS_GSSAPI", sasl_gssapi)

        return :next
      end


      # eDir NMAS dialog contents
      contents = HVSquash(
        VBox(
          Left(Label(_("Select the NMAS Login Methods to Install:"))),
          VSpacing(1.0),
          Left(CheckBox(Id(:certMutual), _("Ce&rtMutual"), certMutual == "yes")),
          Left(
            CheckBox(
              Id(:chlg_response),
              _("Ch&allenge Response"),
              chlg_response == "yes"
            )
          ),
          Left(CheckBox(Id(:digest_md5), _("&DIGEST-MD5"), digest_md5 == "yes")),
          Left(CheckBox(Id(:NDS), _("ND&S"), _NDS == "yes")),
          Left(
            CheckBox(
              Id(:simpl_password),
              _("Simple Pass&word"),
              simpl_password == "yes"
            )
          ),
          Left(
            CheckBox(Id(:sasl_gssapi), _("SAS&L GSSAPI"), sasl_gssapi == "yes")
          ),
          VSpacing(1.0),
          HBox(
            Left(
              PushButton(Id(:allBttn), Opt(:default, :key_F3), _("Sele&ct All"))
            ),
            Left(PushButton(Id(:noneBttn), Opt(:key_F4), _("Deselec&t All")))
          )
        )
      )

      Wizard.SetContentsButtons(
        caption,
        contents,
        Ops.get_string(@HELPS, "nmas_login_methods", ""),
        Label.BackButton,
        Label.NextButton
      )

      ret = nil
      while true
        ret = UI.UserInput

        # abort?
        if ret == :abort || ret == :cancel
          if ReallyAbort()
            break
          else
            next
          end
        elsif ret == :next
          tmp = Convert.to_boolean(UI.QueryWidget(Id(:certMutual), :Value))
          certMutual = tmp == true ? "yes" : "no"
          tmp = Convert.to_boolean(UI.QueryWidget(Id(:chlg_response), :Value))
          chlg_response = tmp == true ? "yes" : "no"
          tmp = Convert.to_boolean(UI.QueryWidget(Id(:digest_md5), :Value))
          digest_md5 = tmp == true ? "yes" : "no"
          tmp = Convert.to_boolean(UI.QueryWidget(Id(:NDS), :Value))
          _NDS = tmp == true ? "yes" : "no"
          tmp = Convert.to_boolean(UI.QueryWidget(Id(:simpl_password), :Value))
          simpl_password = tmp == true ? "yes" : "no"
          tmp = Convert.to_boolean(UI.QueryWidget(Id(:sasl_gssapi), :Value))
          sasl_gssapi = tmp == true ? "yes" : "no"

          Ops.set(
            Edirectory.EdirSettings,
            "CONFIG_EDIR_NMAS_CERTMUTUAL",
            certMutual
          )
          Ops.set(
            Edirectory.EdirSettings,
            "CONFIG_EDIR_NMAS_CHLG_RESPONSE",
            chlg_response
          )
          Ops.set(
            Edirectory.EdirSettings,
            "CONFIG_EDIR_NMAS_DIGEST_MD5",
            digest_md5
          )
          Ops.set(Edirectory.EdirSettings, "CONFIG_EDIR_NMAS_NDS", _NDS)
          Ops.set(
            Edirectory.EdirSettings,
            "CONFIG_EDIR_NMAS_SIMPWD",
            simpl_password
          )
          Ops.set(
            Edirectory.EdirSettings,
            "CONFIG_EDIR_NMAS_GSSAPI",
            sasl_gssapi
          )

          break
        elsif ret == :allBttn
          UI.ChangeWidget(Id(:certMutual), :Value, true)
          UI.ChangeWidget(Id(:chlg_response), :Value, true)
          UI.ChangeWidget(Id(:digest_md5), :Value, true)
          UI.ChangeWidget(Id(:NDS), :Value, true)
          UI.ChangeWidget(Id(:simpl_password), :Value, true)
          UI.ChangeWidget(Id(:sasl_gssapi), :Value, true)
        elsif ret == :noneBttn
          UI.ChangeWidget(Id(:certMutual), :Value, false)
          UI.ChangeWidget(Id(:chlg_response), :Value, false)
          UI.ChangeWidget(Id(:digest_md5), :Value, false)
          UI.ChangeWidget(Id(:NDS), :Value, false)
          UI.ChangeWidget(Id(:simpl_password), :Value, false)
          UI.ChangeWidget(Id(:sasl_gssapi), :Value, false)
        elsif ret == :back
          break
        else
          Builtins.y2error("unexpected retcode: %1", ret)
          next
        end
      end

      deep_copy(ret)
    end

    def validateUserContext(proxyUser)
      ret = true

      Builtins.y2milestone(
        "edirectory.validateUserContext:proxyUser: %1, domain type: %2",
        proxyUser,
        Ops.get_string(Edirectory.EdirSettings, "XAD_DOMAIN_TYPE", "")
      )

      if Ops.get_string(Edirectory.EdirSettings, "XAD_DOMAIN_TYPE", "") == "forest"
        proxyUser = NovellUtils.Ldap2Nds(proxyUser)
        split = Builtins.splitstring(proxyUser, ".")
        ret = false if Builtins.tolower(Ops.get(split, 1, "")) == "cn=users"
      end
      ret
    end

    def UserExists(user)
      ret = false

      # perl /opt/novell/named/bin/dnsdhcp-search-proxy-user.pl -s 137.65.59.48 -p 636 -l 1 -D "cn=admin,o=novell" -u "cn=myuser,o=novell" -t 15

      user = NovellUtils.Nds2Ldap(user)

      remote_server = NovellLDAP.GetAddressServer(
        Ops.get_string(
          Edirectory.EdirSettings,
          "CONFIG_EDIR_REPLICA_SERVER",
          ""
        ),
        nil
      )
      ldapIP = Ops.get_string(
        Edirectory.EdirSettings,
        "CONFIG_EDIR_REPLICA_SERVER",
        ""
      )

      adminDn = NovellUtils.Nds2Ldap(
        Ops.get_string(Edirectory.EdirSettings, "XAD_LDAP_ADMIN_CONTEXT", "")
      )
      adminPassword = Ops.get_string(
        NovellLDAP.Settings,
        "CONFIG_LDAP_ADMIN_PASSWORD",
        ""
      )
      xad_tree_admin_context = Ops.get_string(
        NovellLDAP.Settings,
        "XAD_TREE_ADMIN_CONTEXT",
        ""
      )
      Builtins.y2milestone(
        "edirectory:XAD_TREE_ADMIN_CONTEXT:%1",
        xad_tree_admin_context
      )
      if xad_tree_admin_context != nil && xad_tree_admin_context != ""
        adminPassword = Ops.get_string(
          NovellLDAP.Settings,
          "XAD_TREE_ADMIN_PASSWORD",
          ""
        )
      end

      remoteServerIsDsfw = NovellUtils.ServerIsDsfwServer(ldapIP)
      ldapPort = Builtins.sformat(
        "%1",
        Ops.get_integer(remote_server, "CONFIG_LDAP_SECURE_PORT", 636)
      )
      ldapPort = "1636" if remoteServerIsDsfw

      useSSL = "1"

      cmd = Builtins.sformat(
        "perl /opt/novell/named/bin/dnsdhcp-search-proxy-user.pl -s %1 -p %2 -l %3 -D '%4' -u '%5' -t 15",
        ldapIP,
        ldapPort,
        useSSL,
        adminDn,
        user
      )

      if Edirectory.xadTestMode
        Builtins.y2milestone(
          "Edirectory.UserExists:executing: %1",
          Ops.add(Ops.add(Ops.add("OES_DATA='", adminPassword), "' "), cmd)
        )
      else
        Builtins.y2milestone("Edirectory.UserExists:executing: %1", cmd)
      end

      rmap = Convert.to_map(
        SCR.Execute(
          path(".target.bash_output"),
          Ops.add(Ops.add(Ops.add("OES_DATA='", adminPassword), "' "), cmd)
        )
      )
      ret = true if Ops.get_integer(rmap, "exit", -1) == 0 # proxy user exists

      ret
    end


    # Novelldns dialog
    # @return dialog result
    def XadDnsDialog
      # Novell DNS Services configure dialog caption
      caption = _("OES DNS Services Configuration")

      Builtins.y2milestone("Edirectory:Entering XadDnsDialog.")

      baseDN = Ops.get_string(
        Edirectory.DnsSettings,
        "CONFIG_DNS_LDAP_BASEDN",
        ""
      )
      locator_context = Ops.get_string(
        Edirectory.DnsSettings,
        "CONFIG_DNS_LOCATOR_CONTEXT",
        ""
      )
      group_context = Ops.get_string(
        Edirectory.DnsSettings,
        "CONFIG_DNS_GROUP_CONTEXT",
        ""
      )
      server_context = NovellUtils.Nds2Ldap(
        Ops.get_string(
          Edirectory.EdirSettings,
          "CONFIG_EDIR_SERVER_CONTEXT",
          ""
        )
      )
      existing_address = Ops.get_string(
        Edirectory.DnsSettings,
        "CONFIG_DNS_EXISTING_DNS_IP",
        ""
      )
      gbl_ldap_user = ""

      existing_address = Edirectory.GetNameServer if existing_address == ""

      # We can only default the values for the non name mapped frd
      if Ops.get_string(Edirectory.EdirSettings, "CONFIG_EDIR_TREE_TYPE", "") == "new" &&
          Ops.get_string(Edirectory.EdirSettings, "XAD_DOMAIN_TYPE", "") == "forest"
        baseDN = server_context if baseDN == ""
        locator_context = server_context if locator_context == ""
        group_context = server_context if group_context == ""
      end

      ldap_server = NovellUtils.GetIPAddr # Use local IP

      use_secure_port = "yes"

      storeInOCS = Ops.get_string(
        Edirectory.DnsSettings,
        "CONFIG_DNS_STORE_CREDENTIAL_IN_OCS",
        "yes"
      )

      ldap_user = Ops.get_string(
        Edirectory.DnsSettings,
        "CONFIG_DNS_LDAP_USER_CONTEXT",
        ""
      )
      if ldap_user != nil && ldap_user != ""
        ldap_user = NovellUtils.Nds2Ldap(ldap_user)
      end
      ldap_user_password = Ops.get_string(
        Edirectory.DnsSettings,
        "CONFIG_DNS_LDAP_USER_PASSWORD",
        ""
      )
      verify_ldap_user_password = ldap_user_password

      create_object = "yes"
      createObject = true

      host_name = NovellUtils.GetHostname
      host_name = "" if host_name == nil

      server_object = Ops.add(
        Ops.add(Ops.add("cn=DNS_edir-", host_name), ","),
        NovellUtils.Nds2Ldap(
          Ops.get_string(
            Edirectory.EdirSettings,
            "CONFIG_EDIR_SERVER_CONTEXT",
            ""
          )
        )
      )
      Ops.set(Edirectory.DnsSettings, "CONFIG_DNS_SERVER_OBJECT", server_object)

      domain_name = NovellUtils.GetDomainName
      domain_name = "" if domain_name == nil

      baseDN = "" if baseDN == nil

      full_admin_context = NovellUtils.Ldap2Nds(
        Ops.get_string(Edirectory.EdirSettings, "XAD_LDAP_ADMIN_CONTEXT", "")
      )
      admin_pwd = Ops.get_string(
        NovellLDAP.Settings,
        "CONFIG_LDAP_ADMIN_PASSWORD",
        ""
      )

      if Ops.get_string(Edirectory.EdirSettings, "CONFIG_EDIR_TREE_TYPE", "") != "new"
        admin_pwd = Ops.get_string(
          Edirectory.EdirSettings,
          "XAD_LDAP_ADMIN_PASSWORD",
          ""
        )
      end

      Builtins.y2milestone("NovellDns(edir):admin:%1", full_admin_context)
      if Edirectory.xadTestMode
        Builtins.y2milestone("NovellDns(edir):pword:%1", admin_pwd)
      end

      commonProxyName = ""

      workProxyName = ""

      useCommonProxy = Ops.get_string(
        NovellLDAP.Settings,
        "CONFIG_LDAP_DO_PROXY",
        ""
      )
      Builtins.y2milestone(
        "Edirectory.dnsDialog:useCommonProxy: %1",
        useCommonProxy
      )
      if useCommonProxy == "yes"
        commonProxyName = Ops.get_string(
          NovellLDAP.Settings,
          "CONFIG_LDAP_PROXY_CONTEXT",
          ""
        )
        Builtins.y2milestone(
          "Edirectory.dnsDialog:commonProxyName: '%1'",
          commonProxyName
        )
        commonProxyPassword = Ops.get_string(
          NovellLDAP.Settings,
          "CONFIG_LDAP_PROXY_PASSWORD",
          ""
        )

        if commonProxyName == "" || commonProxyPassword == ""
          Builtins.y2milestone(
            "Edirectory.dns1Dialog:either commonProxyName or commonProxyPassword were empty."
          )
          useCommonProxy = "no"
          workProxyName = ldap_user
          workProxyPassword = ldap_user_password
          workProxyPassword2 = workProxyPassword
        else
          workProxyName = commonProxyName
          workProxyPassword = commonProxyPassword
          workProxyPassword2 = commonProxyPassword
        end
      else
        workProxyName = ldap_user
        workProxyPassword = ldap_user_password
        workProxyPassword2 = workProxyPassword
      end

      Ops.set(Edirectory.DnsSettings, "CONFIG_DNS_LDAP_SERVER", ldap_server)
      Ops.set(
        Edirectory.DnsSettings,
        "CONFIG_DNS_SERVER_CONTEXT",
        NovellUtils.Nds2Ldap(server_context)
      )
      Ops.set(Edirectory.DnsSettings, "CONFIG_DNS_USE_SECURE_PORT", "yes")
      Ops.set(
        Edirectory.DnsSettings,
        "CONFIG_DNS_LDAP_USER_CONTEXT",
        workProxyName
      )
      Ops.set(
        Edirectory.DnsSettings,
        "CONFIG_DNS_LDAP_USER_PASSWORD",
        workProxyPassword
      )
      Ops.set(Edirectory.DnsSettings, "CONFIG_DNS_CREATE_SERVER_OBJECT", "yes")
      Ops.set(Edirectory.DnsSettings, "CONFIG_DNS_HOST_NAME", host_name)
      Ops.set(Edirectory.DnsSettings, "CONFIG_DNS_DOMAIN_NAME", domain_name)
      Ops.set(
        Edirectory.DnsSettings,
        "CONFIG_DNS_STORE_CREDENTIAL_IN_OCS",
        "yes"
      )

      if Ops.get_string(Edirectory.EdirSettings, "XAD_DOMAIN_TYPE", "") == "controller" ||
          Ops.get_string(Edirectory.EdirSettings, "XAD_DOMAIN_TYPE", "") == "domain" # fetch values if DC or child
        # First validate the IP address
        ip = existing_address
        if Address.Check4(ip)
          # Now, try to get the context information.
          contextInfo = Edirectory.GetContextInfo(ip, "2")
          if contextInfo != nil
            locator_context = Ops.get(contextInfo, 0, "")
            locator_context = "" if locator_context == nil

            baseDN = Ops.get(contextInfo, 2, "")
            baseDN = "" if baseDN == nil

            group_context = Ops.get(contextInfo, 1, "")
            group_context = "" if group_context == nil


            if locator_context != ""
              locator_context = NovellUtils.Nds2Ldap(locator_context)
              Ops.set(
                Edirectory.DnsSettings,
                "CONFIG_DNS_LOCATOR_CONTEXT",
                locator_context
              )
            end

            if baseDN != ""
              baseDN = NovellUtils.Nds2Ldap(baseDN)
              Ops.set(Edirectory.DnsSettings, "CONFIG_DNS_LDAP_BASEDN", baseDN)
            end

            if group_context != ""
              group_context = NovellUtils.Nds2Ldap(group_context)
              Ops.set(
                Edirectory.DnsSettings,
                "CONFIG_DNS_GROUP_CONTEXT",
                group_context
              )
            end

            if Ops.get_string(
                Edirectory.EdirSettings,
                "XAD_QUICK_INSTALL",
                "yes"
              ) == "yes"
              # This is the last screen, so turn off quick install so they get all screens if they go through them on the summary screen.
              Ops.set(Edirectory.EdirSettings, "XAD_QUICK_INSTALL", "no")

              if locator_context != "" && baseDN != "" && group_context != "" # We have all the info we need, so we don't need to show screen.
                return :next
              end
            end
          end
        end # This is the new forest case.
      else
        Ops.set(
          Edirectory.DnsSettings,
          "CONFIG_DNS_LDAP_BASEDN",
          server_context
        )
        Ops.set(
          Edirectory.DnsSettings,
          "CONFIG_DNS_LOCATOR_CONTEXT",
          server_context
        )
        Ops.set(
          Edirectory.DnsSettings,
          "CONFIG_DNS_GROUP_CONTEXT",
          server_context
        )
	
	# bug 1102833 fix-------------
        baseDN = Ops.get_string(Edirectory.DnsSettings,"CONFIG_DNS_LDAP_BASEDN","")
        locator_context = Ops.get_string(Edirectory.DnsSettings,"CONFIG_DNS_LOCATOR_CONTEXT","")
        group_context = Ops.get_string(Edirectory.DnsSettings,"CONFIG_DNS_GROUP_CONTEXT","")

        if Ops.get_string(Edirectory.EdirSettings, "XAD_QUICK_INSTALL", "yes") == "yes"
          # This is the last screen, so turn off quick install so they get all screens if they go through them on the summary screen.
          Ops.set(Edirectory.EdirSettings, "XAD_QUICK_INSTALL", "no")
          return :next
        end
      end

      contents = HVSquash(
        VBox(
          Left(
            Frame(
              _("Common DNS Configuration Object Contexts"),
              MarginBox(
                1.5,
                0.2,
                VBox(
                  Left(
                    CheckBox(
                      Id(:get_object),
                      Opt(:notify),
                      _("Get context information from existing DNS server")
                    )
                  ),
                  MinWidth(
                    45,
                    HBox(
                      TextEntry(
                        Id(:existing_ip),
                        _("Existing OES DNS server address:"),
                        existing_address
                      ),
                      VBox(Label(""), PushButton(Id(:rtvBttn), _("&Retrieve")))
                    )
                  ),
                  MinWidth(
                    45,
                    HBox(
                      TextEntry(
                        Id(:locator_context),
                        _(
                          "OES DNS Services Locator Object Context (e.g. ou=dns,o=microfocus):"
                        ),
                        locator_context
                      ),
                      VBox(
                        Label(""),
                        PushButton(Id(:browse_locator_context), _("Browse"))
                      )
                    )
                  ),
                  MinWidth(
                    45,
                    HBox(
                      TextEntry(
                        Id(:baseDN),
                        _(
                          "OES DNS Services Root Server Info Context (e.g. ou=dns,o=microfocus):"
                        ),
                        baseDN
                      ),
                      VBox(
                        Label(""),
                        PushButton(Id(:browse_baseDN), _("Browse"))
                      )
                    )
                  ),
                  MinWidth(
                    45,
                    HBox(
                      TextEntry(
                        Id(:group_context),
                        _(
                          "OES DNS Services Group Object Context (e.g. ou=dns,o=microfocus):"
                        ),
                        group_context
                      ),
                      VBox(
                        Label(""),
                        PushButton(Id(:browse_group_context), _("Browse"))
                      )
                    )
                  )
                )
              )
            )
          ),
          Left(
            Frame(
              _("Proxy User Information"),
              MarginBox(
                1.5,
                0.2,
                VBox(
                  HBox(
                    TextEntry(
                      Id(:ldap_user),
                      Opt(:notify),
                      _(
                        "Proxy User for DNS Management (e.g. cn=myuser,o=microfocus)"
                      ),
                      workProxyName
                    ),
                    VBox(
                      Label(""),
                      PushButton(Id(:browse_ldap_user), _("Browse"))
                    )
                  ),
                  HBox(
                    Left(
                      Password(
                        Id(:ldap_user_password),
                        _("Specify Password for Proxy User"),
                        workProxyPassword
                      )
                    ),
                    Left(
                      Password(
                        Id(:pw2),
                        _("&Verify Password for Proxy User"),
                        workProxyPassword2
                      )
                    )
                  )
                )
              )
            )
          ),
          Left(CheckBox(Id(:use_secure_port), _("Use Secure LDAP Port"))),
          HBox(
            Frame(
              _("Credential Storage Location:"),
              MarginBox(
                1.5,
                0.2,
                RadioButtonGroup(
                  Id(:rb),
                  HBox(
                    Left(RadioButton(Id(0), "OCS")),
                    Left(RadioButton(Id(1), _("Local file based format")))
                  )
                )
              )
            )
          )
        )
      )

      helps = Ops.add(
        Ops.get_string(@HELPS, "configure_dns_0", ""),
        Ops.get_string(@HELPS, "configure_dns", "")
      )
      Wizard.SetContentsButtons(
        caption,
        contents,
        helps,
        Label.BackButton,
        Label.NextButton
      )

      UI.SetFocus(Id(:next))

      primary_server = NovellLDAP.BrowseButtonLdapServer(nil)
      ldap_servers = Ops.get_string(primary_server, "CONFIG_LDAP_SERVER_IP", "")
      ldap_sport = Ops.get_integer(
        primary_server,
        "CONFIG_LDAP_SECURE_PORT",
        636
      )

      if NovellLDAP.IsLocalLDAPRunning != 0
        UI.ChangeWidget(Id(:browse_locator_context), :Enabled, false)
        UI.ChangeWidget(Id(:browse_baseDN), :Enabled, false)
        UI.ChangeWidget(Id(:browse_group_context), :Enabled, false)
        UI.ChangeWidget(Id(:browse_ldap_user), :Enabled, false)
      end

      if !(NovellLDAP.IsLocalLDAPRunning == 0 ||
          Ops.get_string(Edirectory.EdirSettings, "CONFIG_EDIR_TREE_TYPE", "") == "existing")
        UI.ChangeWidget(Id(:browse_locator_context), :Enabled, false)
        UI.ChangeWidget(Id(:browse_baseDN), :Enabled, false)
        UI.ChangeWidget(Id(:browse_group_context), :Enabled, false)
        UI.ChangeWidget(Id(:browse_ldap_user), :Enabled, false)
      else
        UI.ChangeWidget(Id(:browse_locator_context), :Enabled, true)
        UI.ChangeWidget(Id(:browse_baseDN), :Enabled, true)
        UI.ChangeWidget(Id(:browse_group_context), :Enabled, true)
        UI.ChangeWidget(Id(:browse_ldap_user), :Enabled, true)
      end
      if use_secure_port != "no"
        UI.ChangeWidget(Id(:use_secure_port), :Value, true)
      else
        UI.ChangeWidget(Id(:use_secure_port), :Value, false)
      end

      if Ops.get_string(Edirectory.EdirSettings, "CONFIG_EDIR_TREE_TYPE", "") == "new"
        UI.ChangeWidget(Id(:get_object), :Value, false)
        UI.ChangeWidget(Id(:get_object), :Enabled, false)
        UI.ChangeWidget(Id(:existing_ip), :Enabled, false)
        UI.ChangeWidget(Id(:rtvBttn), :Enabled, false)
      else
        UI.ChangeWidget(Id(:get_object), :Enabled, true)
        UI.ChangeWidget(Id(:get_object), :Value, false)
        UI.ChangeWidget(Id(:existing_ip), :Enabled, false)
        UI.ChangeWidget(Id(:rtvBttn), :Enabled, false)
      end

      if storeInOCS == "yes"
        UI.ChangeWidget(Id(:rb), :CurrentButton, 0)
      else
        UI.ChangeWidget(Id(:rb), :CurrentButton, 1)
      end

      if useCommonProxy == "yes" && workProxyName != "" && commonProxyName != "" &&
          Builtins.tolower(workProxyName) == Builtins.tolower(commonProxyName)
        UI.ChangeWidget(Id(:ldap_user_password), :Enabled, false)
        UI.ChangeWidget(Id(:pw2), :Enabled, false)
      else
        UI.ChangeWidget(Id(:ldap_user_password), :Enabled, true)
        UI.ChangeWidget(Id(:pw2), :Enabled, true)
      end

      ret = nil
      while true
        ret = UI.UserInput
        # abort?
        if ret == :abort || ret == :cancel
          if ReallyAbort()
            break
          else
            next
          end
        elsif ret == :next
          Ops.set(Edirectory.DnsSettings, "CONFIG_DNS_LDAP_SERVER", ldap_server)

          baseDN = Convert.to_string(UI.QueryWidget(Id(:baseDN), :Value))
          next if !NovellValidators.ValidateContext(baseDN)

          Ops.set(
            Edirectory.DnsSettings,
            "CONFIG_DNS_LDAP_BASEDN",
            NovellUtils.Nds2Ldap(baseDN)
          )

          Ops.set(
            Edirectory.DnsSettings,
            "CONFIG_DNS_SERVER_CONTEXT",
            NovellUtils.Nds2Ldap(server_context)
          )

          locator_context = Convert.to_string(
            UI.QueryWidget(Id(:locator_context), :Value)
          )
          next if !NovellValidators.ValidateContext(locator_context)

          Ops.set(
            Edirectory.DnsSettings,
            "CONFIG_DNS_LOCATOR_CONTEXT",
            NovellUtils.Nds2Ldap(locator_context)
          )

          group_context = Convert.to_string(
            UI.QueryWidget(Id(:group_context), :Value)
          )
          next if !NovellValidators.ValidateContext(group_context)

          Ops.set(
            Edirectory.DnsSettings,
            "CONFIG_DNS_GROUP_CONTEXT",
            NovellUtils.Nds2Ldap(group_context)
          )

          if Convert.to_boolean(UI.QueryWidget(Id(:use_secure_port), :Value))
            Ops.set(Edirectory.DnsSettings, "CONFIG_DNS_USE_SECURE_PORT", "yes")
          else
            Ops.set(Edirectory.DnsSettings, "CONFIG_DNS_USE_SECURE_PORT", "no")
          end

          ldap_user = Convert.to_string(UI.QueryWidget(Id(:ldap_user), :Value))
          if !NovellValidators.ValidateFDN(ldap_user, false)
            name = ldap_user
            name = NovellUtils.Strip(name, " ")
            if name == nil || name == "" || name == " "
              Popup.Error(_("A valid LDAP user must be entered."))
              next
            end
          end

          if validateUserContext(ldap_user) == false
            Popup.Error(
              _(
                "Invalid context for dns proxy user. New Domain Services for Windows installs cannot have 'cn=users' as part of the user context."
              )
            )
            next
          end

          ldap_user_password = Convert.to_string(
            UI.QueryWidget(Id(:ldap_user_password), :Value)
          )
          verify_ldap_user_password = Convert.to_string(
            UI.QueryWidget(Id(:pw2), :Value)
          )

          if !NovellValidators.ValidatePasswords(
              ldap_user_password,
              verify_ldap_user_password
            )
            UI.SetFocus(Id(:ldap_user_password))
            next
          end

          Builtins.y2milestone(
            "Edirectory:proxy user validation: treeType %1",
            Ops.get_string(Edirectory.EdirSettings, "CONFIG_EDIR_TREE_TYPE", "")
          )

          if Ops.get_string(
              Edirectory.EdirSettings,
              "CONFIG_EDIR_TREE_TYPE",
              ""
            ) != "new" &&
              UserExists(ldap_user)
            remote_server = NovellLDAP.GetAddressServer(
              Ops.get_string(
                Edirectory.EdirSettings,
                "CONFIG_EDIR_REPLICA_SERVER",
                ""
              ),
              nil
            )
            replica_address = Ops.get_string(
              Edirectory.EdirSettings,
              "CONFIG_EDIR_REPLICA_SERVER",
              ""
            )
            secure_port = Ops.get_integer(
              remote_server,
              "CONFIG_LDAP_SECURE_PORT",
              636
            )
            if secure_port == nil || Ops.less_or_equal(secure_port, 0)
              secure_port = 636
            end
            if NovellUtils.ServerIsDsfwServer(replica_address)
              secure_port = 1636
            end

            val = NovellValidators.ValidateCredentials(
              NovellUtils.Ldap2Nds(ldap_user),
              ldap_user_password,
              replica_address,
              secure_port,
              true
            )
            Builtins.y2milestone(
              "edirectory:validating DNS proxy creds. name %1, pass ****, ip %2, port %3",
              ldap_user,
              replica_address,
              secure_port
            )
            if val != 0
              Builtins.y2milestone("ValidateCredentials() returned %1", val)
              if val == -666
                err = _(
                  "The attempt to perform a secure LDAP bind did not respond in 2 minutes\n" +
                    "This may indicate a problem with LDAP on the target server.\n" +
                    "If you are confident that your credentials are correct you may continue,\n" +
                    "otherwise please determine if LDAP is running correctly on the target system\n" +
                    "Do you want to continue?"
                )
                yes = Popup.YesNoHeadline(_("LDAP secure bind timeout"), err)
                next if !yes
              else
                err = Builtins.sformat(
                  _(
                    "User credentials failed to validate Using:\n" +
                      "      Server: %1\n" +
                      "      User: %2\n" +
                      "      LDAP port: %3\n" +
                      "Do you want to continue anyway?"
                  ),
                  replica_address,
                  ldap_user,
                  secure_port
                )
                yes = Popup.YesNoHeadline(_("Credentials Failed"), err)
                next if !yes
              end
            end
          end
          Ops.set(
            Edirectory.DnsSettings,
            "CONFIG_DNS_LDAP_USER_CONTEXT",
            NovellUtils.Nds2Ldap(ldap_user)
          )
          Ops.set(
            Edirectory.DnsSettings,
            "CONFIG_DNS_LDAP_USER_PASSWORD",
            ldap_user_password
          )
          Ops.set(
            Edirectory.DnsSettings,
            "CONFIG_DNS_CREATE_SERVER_OBJECT",
            "yes"
          )
          Ops.set(Edirectory.DnsSettings, "CONFIG_DNS_HOST_NAME", host_name)
          Ops.set(Edirectory.DnsSettings, "CONFIG_DNS_DOMAIN_NAME", domain_name)

          # Save the ocs data
          if Convert.to_integer(UI.QueryWidget(Id(:rb), :CurrentButton)) == 0
            Ops.set(
              Edirectory.DnsSettings,
              "CONFIG_DNS_STORE_CREDENTIAL_IN_OCS",
              "yes"
            )
          else
            Ops.set(
              Edirectory.DnsSettings,
              "CONFIG_DNS_STORE_CREDENTIAL_IN_OCS",
              "no"
            )
          end

          # This is the last screen, so turn off quick install so they get all screens if they go through them on the summary screen.
          Ops.set(Edirectory.EdirSettings, "XAD_QUICK_INSTALL", "no")

          break
        elsif ret == :ldap_user
          ldap_user = NovellUtils.Nds2Ldap(
            Convert.to_string(UI.QueryWidget(Id(:ldap_user), :Value))
          )
          gbl_ldap_user = ldap_user # use for prepending text value to context from browser
          if commonProxyPassword != "" &&
              ldap_user == NovellUtils.Nds2Ldap(commonProxyName)
            UI.ChangeWidget(
              Id(:ldap_user_password),
              :Value,
              commonProxyPassword
            )
            UI.ChangeWidget(Id(:pw2), :Value, commonProxyPassword)
            UI.ChangeWidget(Id(:ldap_user_password), :Enabled, false)
            UI.ChangeWidget(Id(:pw2), :Enabled, false)
          else
            UI.ChangeWidget(Id(:ldap_user_password), :Enabled, true)
            UI.ChangeWidget(Id(:pw2), :Enabled, true)
          end
          next
        elsif ret == :browse_locator_context
          adminDn = Ops.get_string(
            NovellLDAP.Settings,
            "CONFIG_LDAP_ADMIN_CONTEXT",
            ""
          )
          adminPassword = Ops.get_string(
            NovellLDAP.Settings,
            "CONFIG_LDAP_ADMIN_PASSWORD",
            ""
          )
          if Edirectory.xad_packages_installed
            xad_tree_admin_context = Ops.get_string(
              NovellLDAP.Settings,
              "XAD_TREE_ADMIN_CONTEXT",
              ""
            )
            Builtins.y2milestone(
              "eDirectory:XAD_TREE_ADMIN_CONTEXT:%1",
              xad_tree_admin_context
            )
            if xad_tree_admin_context != nil && xad_tree_admin_context != ""
              adminDn = NovellUtils.Nds2Ldap(xad_tree_admin_context)
              adminPassword = Ops.get_string(
                NovellLDAP.Settings,
                "XAD_TREE_ADMIN_PASSWORD",
                ""
              )
            end
          end
          adminDn = NovellUtils.Nds2Ldap(adminDn)
          Builtins.y2milestone("eDirectory:admin:%1", adminDn)
          locator_context2 = NovellLdapBrowser.LdapBrowser(
            ldap_servers,
            ldap_sport,
            true,
            adminDn,
            adminPassword,
            "",
            "(|(ObjectClass=Organization)(ObjectClass=OrganizationalUnit)(ObjectClass=Domain)(ObjectClass=Locality)(ObjectClass=Country))",
            _("Browse for container")
          )
          Builtins.y2milestone(
            Builtins.sformat(
              "dialogs.ycp.NewOrExistingDialog:container from browse is: '%1'",
              locator_context2
            )
          )
          if locator_context2 != nil && locator_context2 != ""
            locator_context2 = NovellUtils.Nds2Ldap(locator_context2)
            UI.ChangeWidget(Id(:locator_context), :Value, locator_context2)
          end
        elsif ret == :browse_baseDN
          adminDn = Ops.get_string(
            NovellLDAP.Settings,
            "CONFIG_LDAP_ADMIN_CONTEXT",
            ""
          )
          adminPassword = Ops.get_string(
            NovellLDAP.Settings,
            "CONFIG_LDAP_ADMIN_PASSWORD",
            ""
          )
          if Edirectory.xad_packages_installed
            xad_tree_admin_context = Ops.get_string(
              NovellLDAP.Settings,
              "XAD_TREE_ADMIN_CONTEXT",
              ""
            )
            Builtins.y2milestone(
              "eDirectory:XAD_TREE_ADMIN_CONTEXT:%1",
              xad_tree_admin_context
            )
            if xad_tree_admin_context != nil && xad_tree_admin_context != ""
              adminDn = NovellUtils.Nds2Ldap(xad_tree_admin_context)
              adminPassword = Ops.get_string(
                NovellLDAP.Settings,
                "XAD_TREE_ADMIN_PASSWORD",
                ""
              )
            end
          end
          adminDn = NovellUtils.Nds2Ldap(adminDn)
          Builtins.y2milestone("eDirectory:admin:%1", adminDn)
          baseDN2 = NovellLdapBrowser.LdapBrowser(
            ldap_servers,
            ldap_sport,
            true,
            adminDn,
            adminPassword,
            "",
            "(|(ObjectClass=Organization)(ObjectClass=OrganizationalUnit)(ObjectClass=Domain)(ObjectClass=Locality)(ObjectClass=Country))",
            _("Browse for container")
          )
          Builtins.y2milestone(
            Builtins.sformat(
              "dialogs.ycp.NewOrExistingDialog:container from browse is: '%1'",
              locator_context
            )
          )
          if baseDN2 != nil && baseDN2 != ""
            baseDN2 = NovellUtils.Nds2Ldap(baseDN2)
            UI.ChangeWidget(Id(:baseDN), :Value, baseDN2)
          end
        elsif ret == :browse_group_context
          adminDn = Ops.get_string(
            NovellLDAP.Settings,
            "CONFIG_LDAP_ADMIN_CONTEXT",
            ""
          )
          adminPassword = Ops.get_string(
            NovellLDAP.Settings,
            "CONFIG_LDAP_ADMIN_PASSWORD",
            ""
          )
          if Edirectory.xad_packages_installed
            xad_tree_admin_context = Ops.get_string(
              NovellLDAP.Settings,
              "XAD_TREE_ADMIN_CONTEXT",
              ""
            )
            Builtins.y2milestone(
              "eDirectory:XAD_TREE_ADMIN_CONTEXT:%1",
              xad_tree_admin_context
            )
            if xad_tree_admin_context != nil && xad_tree_admin_context != ""
              adminDn = NovellUtils.Nds2Ldap(xad_tree_admin_context)
              adminPassword = Ops.get_string(
                NovellLDAP.Settings,
                "XAD_TREE_ADMIN_PASSWORD",
                ""
              )
            end
          end
          adminDn = NovellUtils.Nds2Ldap(adminDn)
          Builtins.y2milestone("eDirectory:admin:%1", adminDn)
          group_context2 = NovellLdapBrowser.LdapBrowser(
            ldap_servers,
            ldap_sport,
            true,
            adminDn,
            adminPassword,
            "",
            "(|(ObjectClass=Organization)(ObjectClass=OrganizationalUnit)(ObjectClass=Domain)(ObjectClass=Locality)(ObjectClass=Country))",
            _("Browse for container")
          )
          Builtins.y2milestone(
            Builtins.sformat(
              "dialogs.ycp.NewOrExistingDialog:container from browse is: '%1'",
              locator_context
            )
          )
          if group_context2 != nil && group_context2 != ""
            group_context2 = NovellUtils.Nds2Ldap(group_context2)
            UI.ChangeWidget(Id(:group_context), :Value, group_context2)
          end
        elsif ret == :browse_ldap_user
          adminDn = Ops.get_string(
            NovellLDAP.Settings,
            "CONFIG_LDAP_ADMIN_CONTEXT",
            ""
          )
          adminPassword = Ops.get_string(
            NovellLDAP.Settings,
            "CONFIG_LDAP_ADMIN_PASSWORD",
            ""
          )
          if Edirectory.xad_packages_installed
            xad_tree_admin_context = Ops.get_string(
              NovellLDAP.Settings,
              "XAD_TREE_ADMIN_CONTEXT",
              ""
            )
            Builtins.y2milestone(
              "eDirectory:XAD_TREE_ADMIN_CONTEXT:%1",
              xad_tree_admin_context
            )
            if xad_tree_admin_context != nil && xad_tree_admin_context != ""
              adminDn = NovellUtils.Nds2Ldap(xad_tree_admin_context)
              adminPassword = Ops.get_string(
                NovellLDAP.Settings,
                "XAD_TREE_ADMIN_PASSWORD",
                ""
              )
            end
          end
          adminDn = NovellUtils.Nds2Ldap(adminDn)
          Builtins.y2milestone("eDirectory:admin:%1", adminDn)

          objFilterWithCN = "(|(ObjectClass=Organization)(ObjectClass=OrganizationalUnit)(ObjectClass=Domain)(ObjectClass=Locality)(ObjectClass=Country)(ObjectClass=User))"
          objFilterWithNoCN = "(|(ObjectClass=Organization)(ObjectClass=OrganizationalUnit)(ObjectClass=Domain)(ObjectClass=Locality)(ObjectClass=Country))"
          objFilter = objFilterWithCN
          if Builtins.substring(gbl_ldap_user, 0, 3) == "cn="
            objFilter = objFilterWithNoCN
          else
            gbl_ldap_user = ""
            objFilter = objFilterWithCN
          end

          ldap_user2 = NovellLdapBrowser.LdapBrowser(
            ldap_servers,
            ldap_sport,
            true,
            adminDn,
            adminPassword,
            "",
            objFilter,
            _("Browse for container")
          )
          Builtins.y2milestone(
            "dialogs.ycp.NewOrExistingDialog:container from browse is: '%1'",
            ldap_user2
          )
          Builtins.y2milestone(
            "dialogs.ycp:proxy user text box value is %1",
            gbl_ldap_user
          )
          if ldap_user2 != nil && ldap_user2 != ""
            ldap_user2 = NovellUtils.Nds2Ldap(ldap_user2)
            if gbl_ldap_user != nil && gbl_ldap_user != ""
              gbl_ldap_user = NovellUtils.Nds2Ldap(gbl_ldap_user)
              ldap_user2 = Ops.add(Ops.add(gbl_ldap_user, ","), ldap_user2)
            end
            UI.ChangeWidget(Id(:ldap_user), :Value, ldap_user2)
          end
        elsif ret == :get_object
          if Convert.to_boolean(UI.QueryWidget(Id(:get_object), :Value))
            UI.ChangeWidget(Id(:existing_ip), :Enabled, true)
            UI.ChangeWidget(Id(:rtvBttn), :Enabled, true)
          else
            UI.ChangeWidget(Id(:existing_ip), :Enabled, false)
            UI.ChangeWidget(Id(:rtvBttn), :Enabled, false)
          end
          next
        elsif ret == :rtvBttn
          # First validate the IP address
          ip = Convert.to_string(UI.QueryWidget(Id(:existing_ip), :Value))
          if !Address.Check4(ip)
            if ip != ""
              Popup.Error(Address.Valid4)
            else
              Popup.Error(
                _(
                  "A valid IP address / hostname of an existing DNS server must be entered."
                )
              )
            end
            next
          end
          if !NovellUtils.Ping_IP(ip)
            erMsg = Builtins.sformat(
              _(
                "The specified IP address / hostname (%1) is either not reachable or unresolvable.\nDo you want to continue anyway?"
              ),
              ip
            )

            next if Popup.ContinueCancel(erMsg) == false
          end

          # Now, try to get the context information.
          contextInfo = Edirectory.GetContextInfo(ip, "2")
          Builtins.y2milestone(
            "Edirectory.XadDnsDialog:context info from call is %1",
            contextInfo
          )
          if contextInfo == nil
            UI.ChangeWidget(Id(:get_object), :Value, false)
            UI.ChangeWidget(Id(:existing_ip), :Enabled, false)
            UI.ChangeWidget(Id(:rtvBttn), :Enabled, false)
            Popup.Message(
              _(
                "The locator, root server, group, and proxy user contexts could not be obtained automatically.\nTry another IP address / hostname or enter the object contexts manually."
              )
            )
          else
            UI.ChangeWidget(
              Id(:locator_context),
              :Value,
              Ops.get(contextInfo, 0, "")
            )
            UI.ChangeWidget(
              Id(:group_context),
              :Value,
              Ops.get(contextInfo, 1, "")
            )
            UI.ChangeWidget(Id(:baseDN), :Value, Ops.get(contextInfo, 2, ""))
          end
          next
        elsif ret == :back
          if Ops.get_string(Edirectory.EdirSettings, "XAD_QUICK_INSTALL", "yes") == "yes"
            Ops.set(Edirectory.EdirSettings, "BACK_DURING_QUICK_INSTALL", "yes")
          end

          break
        else
          Builtins.y2error("unexpected retcode: %1", ret)
          next
        end
      end
      deep_copy(ret)
    end

    # Novelldns remote dialog
    # @return dialog result
    def XadDnsRemoteDialog
      # Novell DNS Services configure dialog caption
      caption = _("OES DNS Services Configuration")

      locator_context = Ops.get_string(
        Edirectory.DnsSettings,
        "CONFIG_DNS_LOCATOR_CONTEXT",
        ""
      )
      group_context = Ops.get_string(
        Edirectory.DnsSettings,
        "CONFIG_DNS_GROUP_CONTEXT",
        ""
      )
      existing_address = Ops.get_string(
        Edirectory.DnsSettings,
        "CONFIG_DNS_EXISTING_DNS_IP",
        ""
      )
      existing_address = Edirectory.GetNameServer if existing_address == ""

      # First validate the IP address
      ip = existing_address
      if Address.Check4(ip)
        # Now, try to get the context information.
        contextInfo = Edirectory.GetContextInfo(ip, "3")
        if contextInfo != nil
          locator_context = Ops.get(contextInfo, 0, "")
          locator_context = "" if locator_context == nil

          group_context = Ops.get(contextInfo, 1, "")
          group_context = "" if group_context == nil

          if locator_context != ""
            locator_context = NovellUtils.Nds2Ldap(locator_context)
            Ops.set(
              Edirectory.DnsSettings,
              "CONFIG_DNS_LOCATOR_CONTEXT",
              locator_context
            )
          end

          if group_context != ""
            group_context = NovellUtils.Nds2Ldap(group_context)
            Ops.set(
              Edirectory.DnsSettings,
              "CONFIG_DNS_GROUP_CONTEXT",
              group_context
            )
          end
          if Ops.get_string(Edirectory.EdirSettings, "XAD_QUICK_INSTALL", "yes") == "yes"
            # This is the last screen, so turn off quick install so they get all screens if they go through them on the summary screen.
            Ops.set(Edirectory.EdirSettings, "XAD_QUICK_INSTALL", "no")
            if locator_context != "" && group_context != "" # We have all the info we need, so we don't need to show screen.
              return :next
            end
          end
        end
      end

      contents = HVSquash(
        VBox(
          Left(
            Frame(
              _("Common DNS Configuration Objects Context"),
              MarginBox(
                1.5,
                0.2,
                VBox(
                  Left(
                    CheckBox(
                      Id(:get_object),
                      Opt(:notify),
                      _("Get context information from existing DNS server")
                    )
                  ),
                  TextEntry(
                    Id(:existing_ip),
                    _("Existing OES DNS server address:"),
                    existing_address
                  ),
                  HBox(Right(PushButton(Id(:rtvBttn), _("&Retrieve")))),
                  TextEntry(
                    Id(:locator_context),
                    _(
                      "OES DNS Services Locator Object Context (e.g. ou=dns,o=microfocus):"
                    ),
                    locator_context
                  ),
                  TextEntry(
                    Id(:group_context),
                    _(
                      "OES DNS Services Group Object Context   (e.g. ou=dns,o=microfocus):"
                    ),
                    group_context
                  )
                )
              )
            )
          )
        )
      )

      Wizard.SetContentsButtons(
        caption,
        contents,
        Ops.get_string(@HELPS, "configure_dns4", ""),
        Label.BackButton,
        Label.NextButton
      )

      UI.SetFocus(Id(:next))

      if Ops.get_string(Edirectory.EdirSettings, "CONFIG_EDIR_TREE_TYPE", "") == "new"
        UI.ChangeWidget(Id(:get_object), :Value, false)
        UI.ChangeWidget(Id(:get_object), :Enabled, false)
        UI.ChangeWidget(Id(:existing_ip), :Enabled, false)
        UI.ChangeWidget(Id(:rtvBttn), :Enabled, false)
      else
        UI.ChangeWidget(Id(:get_object), :Enabled, true)
        UI.ChangeWidget(Id(:get_object), :Value, false)
        UI.ChangeWidget(Id(:existing_ip), :Enabled, false)
        UI.ChangeWidget(Id(:rtvBttn), :Enabled, false)
      end
      ret = nil
      while true
        ret = UI.UserInput

        # abort?
        if ret == :abort || ret == :cancel
          if ReallyAbort()
            break
          else
            next
          end
        elsif ret == :next
          locator_context = Convert.to_string(
            UI.QueryWidget(Id(:locator_context), :Value)
          )
          next if !NovellValidators.ValidateContext(locator_context)

          Ops.set(
            Edirectory.DnsSettings,
            "CONFIG_DNS_LOCATOR_CONTEXT",
            NovellUtils.Nds2Ldap(locator_context)
          )

          group_context = Convert.to_string(
            UI.QueryWidget(Id(:group_context), :Value)
          )
          next if !NovellValidators.ValidateContext(group_context)

          Ops.set(
            Edirectory.DnsSettings,
            "CONFIG_DNS_GROUP_CONTEXT",
            NovellUtils.Nds2Ldap(group_context)
          )

          # This is the last screen, so turn off quick install so they get all screens if they go through them on the summary screen.
          Ops.set(Edirectory.EdirSettings, "XAD_QUICK_INSTALL", "no")

          break
        elsif ret == :get_object
          if Convert.to_boolean(UI.QueryWidget(Id(:get_object), :Value))
            UI.ChangeWidget(Id(:existing_ip), :Enabled, true)
            UI.ChangeWidget(Id(:rtvBttn), :Enabled, true)
          else
            UI.ChangeWidget(Id(:existing_ip), :Enabled, false)
            UI.ChangeWidget(Id(:rtvBttn), :Enabled, false)
          end
          next
        elsif ret == :rtvBttn
          # First validate the IP address
          ip2 = Convert.to_string(UI.QueryWidget(Id(:existing_ip), :Value))
          if !Address.Check4(ip2)
            if ip2 != ""
              Popup.Error(Address.Valid4)
            else
              Popup.Error(
                _(
                  "A valid IP address / hostname of an existing DNS server must be entered."
                )
              )
            end
            next
          end
          if !NovellUtils.Ping_IP(ip2)
            erMsg = Builtins.sformat(
              _(
                "The specified IP address / hostname (%1) is either not reachable or unresolvable.\nDo you want to continue anyway?"
              ),
              ip2
            )

            next if Popup.ContinueCancel(erMsg) == false
          end

          # Now, try to get the context information.
          contextInfo = Edirectory.GetContextInfo(ip2, "3")
          if contextInfo == nil
            UI.ChangeWidget(Id(:get_object), :Value, false)
            UI.ChangeWidget(Id(:existing_ip), :Enabled, false)
            UI.ChangeWidget(Id(:rtvBttn), :Enabled, false)
            Popup.Message(
              _(
                "The locator and group objects could not be obtained automatically.\nTry another IP address / hostname or enter the object contexts manually."
              )
            )
          else
            UI.ChangeWidget(
              Id(:locator_context),
              :Value,
              Ops.get(contextInfo, 0, "")
            )
            UI.ChangeWidget(
              Id(:group_context),
              :Value,
              Ops.get(contextInfo, 1, "")
            )
          end
          next
        elsif ret == :back
          if Ops.get_string(Edirectory.EdirSettings, "XAD_QUICK_INSTALL", "yes") == "yes"
            Ops.set(Edirectory.EdirSettings, "BACK_DURING_QUICK_INSTALL", "yes")
          end

          break
        else
          Builtins.y2error("unexpected retcode: %1", ret)
          next
        end
      end
      deep_copy(ret)
    end

    # Common Proxy User Dialog
    # @return dialog result
    def ProxyUserDialog
      ret = nil
      Builtins.y2milestone("Entering Edirectory ProxyUserDialog()")

      if Ops.get_string(Edirectory.EdirSettings, "XAD_QUICK_INSTALL", "yes") == "yes"
        if Ops.get_string(
            Edirectory.EdirSettings,
            "BACK_DURING_QUICK_INSTALL",
            ""
          ) == "yes"
          return :back
        end
      end

      # Edirectory  Proxy User Dialog caption
      caption = _(
        "eDirectory Configuration - OES Common Proxy User Information"
      )

      proxy_processed = "no"
      doProxy = Ops.get_string(
        NovellLDAP.Settings,
        "CONFIG_LDAP_DO_PROXY",
        "yes"
      )
      Builtins.y2milestone("Edirectory.ProxyUserDialog:doProxy = %1", doProxy)
      do_proxy = true
      #do_proxy = false if doProxy != "yes"

      proxyName = ""
      proxyContext = ""

      # Compute the proxy user context if not already done.
      serverContext = NovellUtils.Nds2Ldap(
        Ops.get_string(
          Edirectory.EdirSettings,
          "CONFIG_EDIR_SERVER_CONTEXT",
          ""
        )
      )
      hostName = NovellUtils.GetHostname
      proxyName = Ops.add("cn=OESCommonProxy_", hostName)
      proxyContext = serverContext
      proxyPassword = NovellUtils.GenerateRandomPassword # generate a random password between 20 and 50 characters
      proxyPassword2 = proxyPassword
      originalPassword = proxyPassword

      assignPolicy = Ops.get_string(
        NovellLDAP.Settings,
        "CONFIG_LDAP_ASSIGN_POLICY",
        "yes"
      )
      assignPolicy = "yes" if assignPolicy == nil || assignPolicy == ""

      assign_policy = false
      assign_policy = true if assignPolicy == "yes"

      if Ops.get_string(Edirectory.EdirSettings, "EDIR_QUICK_INSTALL", "no") == "yes"
        Ops.set(
          NovellLDAP.Settings,
          "CONFIG_LDAP_PROXY_CONTEXT",
          Ops.add(Ops.add(proxyName, ","), proxyContext)
        )
        Ops.set(
          NovellLDAP.Settings,
          "CONFIG_LDAP_PROXY_PASSWORD",
          proxyPassword
        )

        if proxyPassword != originalPassword
          Ops.set(
            Edirectory.EdirSettings,
            "CONFIG_EDIR_USER_ENTERED_PASSWORD",
            "yes"
          )
        end
        Ops.set(NovellLDAP.Settings, "CONFIG_LDAP_ASSIGN_POLICY", assignPolicy)
        Ops.set(NovellLDAP.Settings, "CONFIG_LDAP_DO_PROXY", "yes")
        return :next
      end

      # Skipping dialog for dsfw express install
      if Ops.get_string(Edirectory.EdirSettings, "XAD_SERVICE_CONFIGURED", "no") == "yes" &&
          Ops.get_string(Edirectory.EdirSettings, "XAD_QUICK_INSTALL", "yes") == "yes"
        Ops.set(
          NovellLDAP.Settings,
          "CONFIG_LDAP_PROXY_CONTEXT",
          Ops.add(Ops.add(proxyName, ","), proxyContext)
        )
        Ops.set(
          NovellLDAP.Settings,
          "CONFIG_LDAP_PROXY_PASSWORD",
          proxyPassword
        )

        if proxyPassword != originalPassword
          Ops.set(
            Edirectory.EdirSettings,
            "CONFIG_EDIR_USER_ENTERED_PASSWORD",
            "yes"
          )
        end
        Ops.set(NovellLDAP.Settings, "CONFIG_LDAP_ASSIGN_POLICY", assignPolicy)
        Ops.set(NovellLDAP.Settings, "CONFIG_LDAP_DO_PROXY", "yes")

        if Ops.get_string(Edirectory.EdirSettings, "XAD_CONFIG_DNS", "") != "yes"
          ret = :remote
        else
          ret = :local
        end

        return deep_copy(ret)
      end

      contents = HVSquash(
        VBox(
          VBox(
            VSpacing(1),
            Left(
              CheckBox(
                Id(:do_proxy),
                Opt(:notify),
                _("&Use Common Proxy User as default for OES Products"),
                do_proxy
              )
            )
          ),
          VSpacing(1),
          TextEntry(
            Id(:proxyUserName),
            _("&OES Common Proxy User Name (e.g. cn=OESCommonProxy_hostname)"),
            proxyName
          ),
          MinWidth(
            60,
            HBox(
              TextEntry(
                Id(:proxyUserContext),
                _("OES Common Proxy User Context (e.g. o=microfocus)"),
                proxyContext
              ),
              VBox(Label(""), PushButton(Id(:browse), _("Browse")))
            )
          ),
          Left(
            Password(
              Id(:pw1),
              _("&OES Common Proxy User Password"),
              proxyPassword
            )
          ),
          Left(
            Password(
              Id(:pw2),
              _("&Verify OES Common Proxy User Password"),
              proxyPassword2
            )
          ),
          VBox(
            VSpacing(1),
            Left(
              CheckBox(
                Id(:assign_policy),
                Opt(:notify),
                _("&Assign Common Proxy Password Policy to Proxy User"),
                assign_policy
              )
            )
          )
        )
      )

      helps = Ops.get_string(@HELPS, "proxy_user", "")

      Wizard.SetContentsButtons(
        caption,
        contents,
        helps,
        Label.BackButton,
        Label.NextButton
      )

      UI.SetFocus(Id(:proxyUserContext))

      UI.ChangeWidget(Id(:do_proxy), :Enabled, false)

      UI.ChangeWidget(Id(:proxyUserName), :Enabled, false) # This field is fixed and cannot be changed by the user
      if do_proxy == false
        if proxy_processed == "yes"
          UI.ChangeWidget(Id(:do_proxy), :Enabled, false)
        end
        UI.ChangeWidget(Id(:proxyUserContext), :Enabled, false)
        UI.ChangeWidget(Id(:pw1), :Enabled, false)
        UI.ChangeWidget(Id(:pw2), :Enabled, false)
        UI.ChangeWidget(Id(:assign_policy), :Enabled, false)
        UI.ChangeWidget(Id(:browse), :Enabled, false)
      end

      # For new tree server context browse is disabled
      if Ops.get_string(Edirectory.EdirSettings, "CONFIG_EDIR_TREE_TYPE", "") == "new"
        UI.ChangeWidget(Id(:browse), :Enabled, false)
      end

      while true
        ret = UI.UserInput
        proxyName = Convert.to_string(
          UI.QueryWidget(Id(:proxyUserName), :Value)
        )
        proxyContext = Convert.to_string(
          UI.QueryWidget(Id(:proxyUserContext), :Value)
        )
        proxyPassword = Convert.to_string(UI.QueryWidget(Id(:pw1), :Value))
        proxyPassword2 = Convert.to_string(UI.QueryWidget(Id(:pw2), :Value))
        assign_policy = Convert.to_boolean(
          UI.QueryWidget(Id(:assign_policy), :Value)
        )
        do_proxy = Convert.to_boolean(UI.QueryWidget(Id(:do_proxy), :Value))

        # abort?
        if ret == :abort || ret == :cancel
          if ReallyAbort()
            break
          else
            next
          end
        elsif ret == :next
          if do_proxy
            if !NovellValidators.ValidatePasswords(
                proxyPassword,
                proxyPassword2
              )
              UI.ChangeWidget(Id(:pw1), :Value, "")
              UI.ChangeWidget(Id(:pw2), :Value, "")
              UI.SetFocus(Id(:pw1))
              next
            end
            proxyContext = NovellUtils.Nds2Ldap(proxyContext)
            if !NovellValidators.ValidateContext(proxyContext)
              name = proxyContext
              name = NovellUtils.Strip(name, " ")
              if name == nil || name == "" || name == " "
                Popup.Error(_("A valid LDAP context name must be entered."))
              end

              UI.SetFocus(Id(:proxyUserContext))
              next
            end
            if !assign_policy
              if Popup.ContinueCancel(
                  _(
                    "Not assigning the common proxy password policy might result\n" +
                      "in a policy assignment that causes issues for the common proxy user.\n" +
                      "Continue Anyway?"
                  )
                ) == false
                next
              end
            end
            if assign_policy
              assignPolicy = "yes"
            else
              assignPolicy = "no"
            end

            # Save the data
            Ops.set(
              NovellLDAP.Settings,
              "CONFIG_LDAP_PROXY_CONTEXT",
              Ops.add(Ops.add(proxyName, ","), proxyContext)
            )
            Ops.set(
              NovellLDAP.Settings,
              "CONFIG_LDAP_PROXY_PASSWORD",
              proxyPassword
            )
            Ops.set(
              NovellLDAP.Settings,
              "CONFIG_COMMON_PROXY_CONTEXT",
              proxyContext
            )

            if proxyPassword != originalPassword
              Ops.set(
                Edirectory.EdirSettings,
                "CONFIG_EDIR_USER_ENTERED_PASSWORD",
                "yes"
              )
            end
            Ops.set(
              NovellLDAP.Settings,
              "CONFIG_LDAP_ASSIGN_POLICY",
              assignPolicy
            )
            Ops.set(NovellLDAP.Settings, "CONFIG_LDAP_DO_PROXY", "yes")
          else
            Ops.set(NovellLDAP.Settings, "CONFIG_LDAP_DO_PROXY", "no")
          end
          if Ops.get_string(
              Edirectory.EdirSettings,
              "XAD_SERVICE_CONFIGURED",
              "no"
            ) == "yes"
            if Ops.get_string(Edirectory.EdirSettings, "XAD_CONFIG_DNS", "") != "yes"
              ret = :remote
            else
              ret = :local
            end
          end
          break
        elsif ret == :do_proxy
          do_proxy = Convert.to_boolean(UI.QueryWidget(Id(:do_proxy), :Value))
          if do_proxy == false
            UI.ChangeWidget(Id(:proxyUserName), :Enabled, false)
            UI.ChangeWidget(Id(:proxyUserContext), :Enabled, false)
            UI.ChangeWidget(Id(:pw1), :Enabled, false)
            UI.ChangeWidget(Id(:pw2), :Enabled, false)
            UI.ChangeWidget(Id(:assign_policy), :Enabled, false)
            UI.ChangeWidget(Id(:browse), :Enabled, false)
          else
            UI.ChangeWidget(Id(:proxyUserName), :Enabled, false) # always disabled
            UI.ChangeWidget(Id(:proxyUserContext), :Enabled, true)
            UI.ChangeWidget(Id(:pw1), :Enabled, true)
            UI.ChangeWidget(Id(:pw2), :Enabled, true)
            UI.ChangeWidget(Id(:assign_policy), :Enabled, true)
            if Ops.get_string(
                Edirectory.EdirSettings,
                "CONFIG_EDIR_TREE_TYPE",
                ""
              ) != "new"
              UI.ChangeWidget(Id(:browse), :Enabled, true)
            else
              UI.ChangeWidget(Id(:browse), :Enabled, false)
            end
          end
        elsif ret == :browse
          uName = Ops.get_string(
            NovellLDAP.Settings,
            "CONFIG_LDAP_ADMIN_CONTEXT",
            ""
          )
          uPassword = Ops.get_string(
            NovellLDAP.Settings,
            "CONFIG_LDAP_ADMIN_PASSWORD",
            ""
          )

          if Ops.get_string(
              Edirectory.EdirSettings,
              "XAD_SERVICE_CONFIGURED",
              "no"
            ) == "yes"
            uName = Ops.get_string(
              Edirectory.EdirSettings,
              "XAD_LDAP_ADMIN_CONTEXT",
              ""
            )
            uPassword = Ops.get_string(
              Edirectory.EdirSettings,
              "XAD_LDAP_ADMIN_PASSWORD",
              ""
            )
          end

          replica_address = Ops.get_string(
            Edirectory.EdirSettings,
            "CONFIG_EDIR_REPLICA_SERVER",
            ""
          )
          server_list = Ops.get_list(
            NovellLDAP.Settings,
            "CONFIG_LDAP_SERVERS_LIST",
            []
          )
          replica_server = NovellLDAP.GetAddressServer(
            replica_address,
            server_list
          )
          port = Ops.get_integer(replica_server, "CONFIG_LDAP_PORT", 389)
          port = 389 if port == nil || Ops.less_or_equal(port, 0)
          secure_port = Ops.get_integer(
            replica_server,
            "CONFIG_LDAP_SECURE_PORT",
            636
          )
          if secure_port == nil || Ops.less_or_equal(secure_port, 0)
            secure_port = 636
          end

          uName = NovellUtils.Nds2Ldap(uName)

          wrkContainer = NovellLdapBrowser.LdapBrowser(
            Ops.get_string(
              Edirectory.EdirSettings,
              "CONFIG_EDIR_REPLICA_SERVER",
              ""
            ),
            secure_port,
            true,
            uName,
            uPassword,
            "",
            "(|(ObjectClass=Organization)(ObjectClass=OrganizationalUnit)(ObjectClass=Domain)(ObjectClass=Locality)(ObjectClass=Country))",
            _("Browse for container")
          )
          Builtins.y2milestone(
            Builtins.sformat(
              "Edirectory.dialogs: common proxy user context from browse is: '%1'",
              wrkContainer
            )
          )
          if wrkContainer != nil && wrkContainer != ""
            wrkContainer = NovellUtils.Nds2Ldap(wrkContainer)
            UI.ChangeWidget(Id(:proxyUserContext), :Value, wrkContainer)
          end
        elsif ret == :back
          break
        else
          Builtins.y2error("unexpected retcode: %1", ret)
          next
        end
      end
      deep_copy(ret)
    end
  end
end
